local addonName, MaxDps = ...

LibStub('AceAddon-3.0'):NewAddon(MaxDps, 'MaxDps', 'AceConsole-3.0', 'AceEvent-3.0', 'AceTimer-3.0')

--- @class MaxDps
_G[addonName] = MaxDps

local TableInsert = tinsert
local TableRemove = tremove
local TableContains = tContains
local TableIndexOf = tIndexOf

local UnitIsFriend = UnitIsFriend
local IsPlayerSpell = IsPlayerSpell
local UnitClass = UnitClass
local GetSpecialization = GetSpecialization
local CreateFrame = CreateFrame
local GetAddOnInfo = C_AddOns.GetAddOnInfo
local IsAddOnLoaded = C_AddOns.IsAddOnLoaded
local LoadAddOn = C_AddOns.LoadAddOn

local spellHistoryBlacklist = {
	[75] = true -- Auto shot
}

function MaxDps:OnInitialize()
	self.db = LibStub('AceDB-3.0'):New('MaxDpsOptions', self.defaultOptions)

	self:RegisterChatCommand('maxdps', 'ShowMainWindow')

	if not self.db.global.customRotations then
		self.db.global.customRotations = {}
	end

	self:AddToBlizzardOptions()
end

function MaxDps:IsRetailWow()
    return WOW_PROJECT_ID == WOW_PROJECT_MAINLINE
end

function MaxDps:ShowMainWindow()
	if not self.Window then
		self.Window = self:GetModule('Window')
	end

	self.Window:ShowWindow()
end

function MaxDps:GetTexture()
	if self.db.global.customTexture ~= '' and self.db.global.customTexture ~= nil then
		self.FinalTexture = self.db.global.customTexture
		return self.FinalTexture
	end

	self.FinalTexture = self.db.global.texture
	if self.FinalTexture == '' or self.FinalTexture == nil then
		self.FinalTexture = 'Interface\\Cooldown\\ping4'
	end

	return self.FinalTexture
end

MaxDps.DefaultPrint = MaxDps.Print
function MaxDps:Print(message,level)
	if not level then level = "info" end
	if self.db.global.disabledInfo and self.db.global.disabledInfo == "none" then
		return
	elseif self.db.global.disabledInfo and self.db.global.disabledInfo == "all" then
		MaxDps:DefaultPrint(message)
	elseif self.db.global.disabledInfo and self.db.global.disabledInfo == "errorinfo" then
		if level == "error" or level == "info" then
			MaxDps:DefaultPrint(message)
		end
	elseif self.db.global.disabledInfo and self.db.global.disabledInfo == "error" then
		if level == "error" then
			MaxDps:DefaultPrint(message)
		end
	elseif self.db.global.disabledInfo and self.db.global.disabledInfo == "info" then
		if level == "info" then
			MaxDps:DefaultPrint(message)
		end
	end
end

MaxDps.profilerStatus = 0
function MaxDps:ProfilerStart()
	local profiler = self:GetModule('Profiler')
	profiler:StartProfiler()
	self.profilerStatus = 1
end

function MaxDps:ProfilerStop()
	local profiler = self:GetModule('Profiler')
	profiler:StopProfiler()
	self.profilerStatus = 0
end

function MaxDps:ProfilerToggle()
	if self.profilerStatus == 0 then
		self:ProfilerStart()
	else
		self:ProfilerStop()
	end
end

function MaxDps:EnableRotation()
	if self.NextSpell == nil or self.rotationEnabled then
		self:Print(self.Colors.Error .. 'Failed to enable addon!', "error")
		return
	end

	self:Fetch()
	self:UpdateButtonGlow()

	self:CheckTalents()
	self:GetAzeriteTraits()
	self:GetAzeriteEssences()
	self:GetCovenantInfo()
	self:GetLegendaryEffects()
	self:CheckIsPlayerMelee()
	if self.ModuleOnEnable then
		self.ModuleOnEnable()
	end

	self:EnableRotationTimer()

	self.rotationEnabled = true
end

function MaxDps:EnableRotationTimer()
	self.RotationTimer = self:ScheduleRepeatingTimer('InvokeNextSpell', self.db.global.interval)
end

function MaxDps:DisableRotation()
	if not self.rotationEnabled then
		return
	end

	self:DisableRotationTimer()

	self:DestroyAllOverlays()
	self:Print(self.Colors.Info .. 'Disabling', "info")

	self.Spell = nil
	self.rotationEnabled = false
end

function MaxDps:DisableRotationTimer()
	if self.RotationTimer then
		self:CancelTimer(self.RotationTimer)
	end
end

local talentUpdateEvents = {
	"TRAIT_CONFIG_CREATED",
	"ACTIVE_COMBAT_CONFIG_CHANGED",
	"STARTER_BUILD_ACTIVATION_FAILED",
	"PLAYER_TALENT_UPDATE",
	"AZERITE_ESSENCE_ACTIVATED",
	"TRAIT_CONFIG_DELETED",
	"TRAIT_CONFIG_UPDATED",
	"LOADING_SCREEN_DISABLED",
}

function MaxDps:OnEnable()
	self:RegisterEvent('PLAYER_TARGET_CHANGED')
	self:RegisterEvent('PLAYER_REGEN_DISABLED')
	self:RegisterEvent('PLAYER_REGEN_ENABLED')

	for _, event in pairs(talentUpdateEvents) do
		self:RegisterEvent(event, 'TalentsUpdated')
	end

	self:RegisterEvent('ACTIONBAR_SLOT_CHANGED', 'ButtonFetch')
	self:RegisterEvent('ACTIONBAR_HIDEGRID', 'ButtonFetch')
	self:RegisterEvent('ACTIONBAR_PAGE_CHANGED', 'ButtonFetch')
	self:RegisterEvent('ACTIONBAR_UPDATE_STATE', 'ButtonFetch')
	self:RegisterEvent('UPDATE_BONUS_ACTIONBAR', 'ButtonFetch')
	self:RegisterEvent('LEARNED_SPELL_IN_TAB', 'ButtonFetch')
	self:RegisterEvent('CHARACTER_POINTS_CHANGED', 'ButtonFetch')
	self:RegisterEvent('ACTIVE_TALENT_GROUP_CHANGED', 'ButtonFetch')
	self:RegisterEvent('PLAYER_SPECIALIZATION_CHANGED', 'ButtonFetch')
	self:RegisterEvent('UPDATE_MACROS', 'ButtonFetch')
	self:RegisterEvent('VEHICLE_UPDATE', 'ButtonFetch')
	self:RegisterEvent('UPDATE_STEALTH', 'ButtonFetch')
	self:RegisterEvent('SPELLS_CHANGED', 'ButtonFetch')

	self:RegisterEvent('UNIT_ENTERED_VEHICLE')
	self:RegisterEvent('UNIT_EXITED_VEHICLE')

	self:RegisterEvent('NAME_PLATE_UNIT_ADDED')
	self:RegisterEvent('NAME_PLATE_UNIT_REMOVED')
	--	self:RegisterEvent('PLAYER_REGEN_ENABLED')

	if not self.playerUnitFrame then
		self.spellHistory = {}

		self.playerUnitFrame = CreateFrame('Frame')
		self.playerUnitFrame:RegisterUnitEvent('UNIT_SPELLCAST_SUCCEEDED', 'player')
		self.playerUnitFrame:SetScript('OnEvent', function(_, _, _, _, spellId)
			-- event, unit, lineId
			if IsPlayerSpell(spellId) and not spellHistoryBlacklist[spellId] then
				TableInsert(self.spellHistory, 1, spellId)

				if #self.spellHistory > 5 then
					TableRemove(self.spellHistory)
				end
			end
		end)
	end

	self:Print(self.Colors.Info .. 'Initialized', "info")
end

MaxDps.visibleNameplates = {}
function MaxDps:NAME_PLATE_UNIT_ADDED(_, nameplateUnit)
	if not TableContains(self.visibleNameplates, nameplateUnit) then
		TableInsert(self.visibleNameplates, nameplateUnit)
	end
end

function MaxDps:NAME_PLATE_UNIT_REMOVED(_, nameplateUnit)
	local index = TableIndexOf(self.visibleNameplates, nameplateUnit)
	if index ~= nil then
		TableRemove(self.visibleNameplates, index)
	end
end

function MaxDps:TalentsUpdated()
	self:DisableRotation()
	self:UpdateSpellsAndTalents()
end

local MaxDpsSpellTable
function MaxDps:UpdateSpellsAndTalents()
    local idtoclass = {
        [1] = "Warrior",
        [2] = "Paladin",
        [3] = "Hunter",
        [4] = "Rogue",
        [5] = "Priest",
        [6] = "Death Knight",
        [7] = "Shaman",
        [8] = "Mage",
        [9] = "Warlock",
        [10] = "Monk",
        [11] = "Druid",
        [12] = "Demon Hunter",
        [13] = "Evoker",
    }
	local idtospec = {
	    --Death Knight
	    [250] = "Blood",
	    [251] = "Frost",
	    [252] = "Unholy",
	    --Demon Hunter
	    [577] = "Havoc",
	    [581] = "Vengeance",
	    --Druid
	    [102] = "Balance",
	    [103] = "Feral",
	    [104] = "Guardian",
	    [105] = "Restoration",
		--Evoker
		[1473] = "Augmentation",
		[1467] = "Devastation",
		[1468] = "Preservation",
	    --Hunter
	    [253] = "Beast Mastery",
	    [254] = "Marksmanship",
	    [255] = "Survival",
	    --Mage
	    [62] = "Arcane",
	    [63] = "Fire",
	    [64] = "Frost",
	    --Monk
	    [268] = "Brewmaster",
	    [269] = "Windwalker",
	    [270] = "Mistweaver",
	    --Paladin
	    [65] = "Holy",
	    [66] = "Protection",
	    [70] = "Retribution",
	    --Priest
	    [256] = "Discipline",
	    [257] = "Holy",
	    [258] = "Shadow",
	    --Rogue
	    [259] = "Assassination",
	    [260] = "Outlaw",
	    [261] = "Subtlety",
	    --Shaman
	    [262] = "Elemental",
	    [263] = "Enhancement",
	    [264] = "Restoration",
	    --Warlock
	    [265] = "Affliction",
	    [266] = "Demonology",
	    [267] = "Destruction",
	    --Warrior
	    [71] = "Arms",
	    [72] = "Fury",
	    [73] = "Protection",
    }
	MaxDpsSpellTable = {
		["Warrior"] = {
			["Protection"] = {
				["KeepYourFeetontheGround"] = 438590,
				["BatteringRam"] = 394312,
				["Uproar"] = 391572,
				["ArmoredtotheTeeth"] = 394855,
				["Ravager"] = 228920,
				["PiercingHowl"] = 12323,
				["HeavyRepercussions"] = 203177,
				["ThunderousWords"] = 384969,
				["ImpenetrableWall"] = 384072,
				["ShieldCharge"] = 385952,
				["StormBolts"] = 436162,
				["ThunderBlast"] = 435607,
				["Sidearm"] = 384404,
				["HeroicThrow"] = 57755,
				["Earthquaker"] = 440992,
				["SuddenDeath"] = 29725,
				["Demolish"] = 436358,
				["ThunderousRoar"] = 384318,
				["PainandGain"] = 382549,
				["TideofBattle"] = 429641,
				["Bloodsurge"] = 384361,
				["ShieldSlam"] = 23922,
				["ChampionsMight"] = 386284,
				["ImpendingVictory"] = 202168,
				["FocusedVigor"] = 384067,
				["EnduringAlacrity"] = 384063,
				["Shockwave"] = 46968,
				["Instigate"] = 394311,
				["Bloodborne"] = 385704,
				["Avatar"] = 401150,
				["Menace"] = 275338,
				["BestServedCold"] = 202560,
				["IntotheFray"] = 202603,
				["Bolster"] = 280001,
				["ImmovableObject"] = 394307,
				["BerserkerShout"] = 384100,
				["LightningStrikes"] = 434969,
				["BattleShout"] = 6673,
				["Punish"] = 275334,
				["ReviveBattlePets"] = 125439,
				["HeroicLeap"] = 6544,
				["BattleStance"] = 386164,
				["ConcussiveBlows"] = 383115,
				["GuildMail"] = 83951,
				["DefensiveStance"] = 386208,
				["BerserkerRage"] = 18499,
				["BoundingStride"] = 202163,
				["OverwhelmingRage"] = 382767,
				["ChampionsBulwark"] = 386328,
				["Juggernaut"] = 393967,
				["StormBolt"] = 107570,
				["ReinforcedPlates"] = 382939,
				["ShowofForce"] = 385843,
				["ToughasNails"] = 385888,
				["Thunderlord"] = 385840,
				["Cultivation"] = 20552,
				["WildStrikes"] = 382946,
				["ViolentOutburst"] = 386477,
				["BoomingVoice"] = 202743,
				["StrengthoftheMountain"] = 437068,
				["SecondWind"] = 29838,
				["Charge"] = 100,
				["DisruptingShout"] = 386071,
				["FightThroughtheFlames"] = 452494,
				["VictoryRush"] = 34428,
				["Endurance"] = 20550,
				["LeechingStrikes"] = 382258,
				["OneHandedWeaponSpecialization"] = 382895,
				["Revenge"] = 6572,
				["Pummel"] = 6552,
				["MobileBanking"] = 83958,
				["GroundCurrent"] = 436148,
				["SeismicReverberation"] = 382956,
				["FastFootwork"] = 382260,
				["DefendersAegis"] = 397103,
				["ArmorSkills"] = 76268,
				["Vanguard"] = 71,
				["DeepWounds"] = 115768,
				["PreciseMight"] = 431548,
				["Devastate"] = 20243,
				["RumblingEarth"] = 275339,
				["LastStand"] = 12975,
				["Slam"] = 1464,
				["SpellReflection"] = 23920,
				["ShieldBlock"] = 2565,
				["CruelStrikes"] = 392777,
				["WeaponSkills"] = 76290,
				["TheQuickandtheDead"] = 83950,
				["NatureResistance"] = 20551,
				["WreckingThrow"] = 384110,
				["MountUp"] = 78633,
				["BarbaricTraining"] = 390675,
				["ThunderClap"] = 6343,
				["MasteryCriticalBlock"] = 76857,
				["ArterialBleed"] = 440995,
				["HastyHearth"] = 83944,
				["IntimidatingShout"] = 5246,
				["UnstoppableForce"] = 275336,
				["ShieldWall"] = 871,
				["BraceForImpact"] = 386030,
				["PracticedStrikes"] = 429647,
				["GatheringClouds"] = 436201,
				["DoubleTime"] = 103827,
				["FlashingSkies"] = 437079,
				["Whirlwind"] = 1680,
				["AngerManagement"] = 152278,
				["ShatteringThrow"] = 64382,
				["CrashingThunder"] = 436707,
				["OneAgainstMany"] = 429637,
				["SteadfastasthePeaks"] = 434970,
				["Devastator"] = 236279,
				["Taunt"] = 355,
				["ColossalMight"] = 429634,
				["Indomitable"] = 202095,
				["HonedReflexes"] = 391271,
				["PiercingChallenge"] = 382948,
				["EnduranceTraining"] = 382940,
				["BurstofPower"] = 437118,
				["StormShield"] = 438597,
				["DanceofDeath"] = 390713,
				["ShieldSpecialization"] = 386011,
				["IgnorePain"] = 190456,
				["ChallengingShout"] = 1161,
				["BitterImmunity"] = 383762,
				["EnduringDefenses"] = 386027,
				["Massacre"] = 281001,
				["WarMachine"] = 316733,
				["NoStrangertoPain"] = 429644,
				["BattleScarredVeteran"] = 386394,
				["CacophonousRoar"] = 382954,
				["VindicaarMatrixCrystal"] = 251463,
				["VeteranVitality"] = 440993,
				["FrothingBerserker"] = 392790,
				["ThorimsMight"] = 436152,
				["Strategist"] = 384041,
				["Execute"] = 163201,
				["Rend"] = 394062,
				["BrutalVitality"] = 384036,
				["DemoralizingShout"] = 1160,
				["FueledbyViolence"] = 383103,
				["MasterRiding"] = 90265,
				["Boneshaker"] = 429639,
				["CracklingThunder"] = 203201,
				["Languages"] = 79746,
				["RallyingCry"] = 97462,
				["WarStomp"] = 20549,
				["CrushingForce"] = 390642,
				["BattleforAzerothPathfinder"] = 278833,
				["Brawn"] = 154743,
				["BrokenIslesPathfinder"] = 233368,
				["StormofSteel"] = 382953,
				["DominanceoftheColossus"] = 429636,
				["AvataroftheStorm"] = 437134,
				["ChampionsSpear"] = 376079,
				["MountainofMuscleandScars"] = 429642,
				["Intervene"] = 3411,
				["SnapInduction"] = 456270,
				["Hamstring"] = 1715,
				["MartialExpert"] = 429638,
				["UnnervingFocus"] = 384042,
				["AutoAttack"] = 6603,
				["SpellBlock"] = 392966,
				["Riposte"] = 161798,
			},
			["Arms"] = {
				["BluntInstruments"] = 383442,
				["Uproar"] = 391572,
				["CriticalThinking"] = 389306,
				["DanceofDeath"] = 390713,
				["Ravager"] = 228920,
				["PiercingHowl"] = 12323,
				["ImprovedOverpower"] = 385571,
				["ThunderousWords"] = 384969,
				["MortalStrike"] = 12294,
				["ViciousAgility"] = 444777,
				["TheQuickandtheDead"] = 83950,
				["Sidearm"] = 384404,
				["RelentlessPursuit"] = 444776,
				["HeroicThrow"] = 57755,
				["Earthquaker"] = 440992,
				["SuddenDeath"] = 29725,
				["SweepingStrikes"] = 260708,
				["Dreadnaught"] = 262150,
				["ThunderousRoar"] = 384318,
				["PainandGain"] = 382549,
				["TideofBattle"] = 429641,
				["Bloodsurge"] = 384361,
				["ShieldSlam"] = 23922,
				["ChampionsMight"] = 386284,
				["ImpendingVictory"] = 202168,
				["Unhinged"] = 386628,
				["IntimidatingShout"] = 5246,
				["Shockwave"] = 46968,
				["WreckingThrow"] = 384110,
				["Bloodborne"] = 383287,
				["Avatar"] = 107574,
				["Menace"] = 275338,
				["BrokenIslesPathfinder"] = 233368,
				["ColossusSmash"] = 167105,
				["BerserkerShout"] = 384100,
				["BattleShout"] = 6673,
				["Fatality"] = 383703,
				["ImprovedSweepingStrikes"] = 383155,
				["ReviveBattlePets"] = 125439,
				["HeroicLeap"] = 6544,
				["BattleStance"] = 386164,
				["WarlordsTorment"] = 390140,
				["GuildMail"] = 83951,
				["DefensiveStance"] = 386208,
				["RallyingCry"] = 97462,
				["BoundingStride"] = 202163,
				["OverwhelmingRage"] = 382767,
				["Cleave"] = 845,
				["Juggernaut"] = 383292,
				["SharpenedBlades"] = 383341,
				["TestofMight"] = 385008,
				["StormBolt"] = 107570,
				["ReinforcedPlates"] = 382939,
				["CracklingThunder"] = 203201,
				["FastFootwork"] = 382260,
				["Cultivation"] = 20552,
				["WildStrikes"] = 382946,
				["Bloodletting"] = 383154,
				["SlayersDominance"] = 444767,
				["ValorinVictory"] = 383338,
				["SecondWind"] = 29838,
				["Charge"] = 100,
				["Skullsplitter"] = 260643,
				["VictoryRush"] = 34428,
				["Endurance"] = 20550,
				["Overpower"] = 7384,
				["BlademastersTorment"] = 390138,
				["LeechingStrikes"] = 382258,
				["Warbreaker"] = 262161,
				["Pummel"] = 6552,
				["MobileBanking"] = 83958,
				["DeftExperience"] = 389308,
				["SeismicReverberation"] = 382956,
				["BrutalFinish"] = 446085,
				["InForTheKill"] = 248621,
				["CullingCyclone"] = 444778,
				["PreciseMight"] = 431548,
				["Impale"] = 383430,
				["RumblingEarth"] = 275339,
				["SpitefulSerenity"] = 400314,
				["StrengthofArms"] = 400803,
				["Opportunist"] = 444774,
				["Slam"] = 1464,
				["MercilessBonegrinder"] = 383317,
				["IgnorePain"] = 190456,
				["BarbaricTraining"] = 383082,
				["NatureResistance"] = 20551,
				["FervorofBattle"] = 202316,
				["ImprovedExecute"] = 316405,
				["HastyHearth"] = 83944,
				["EnduranceTraining"] = 382940,
				["MountainofMuscleandScars"] = 429642,
				["Tactician"] = 184783,
				["ExecutionersPrecision"] = 386634,
				["MountUp"] = 78633,
				["CrushingForce"] = 382764,
				["PracticedStrikes"] = 429647,
				["FueledbyViolence"] = 383103,
				["SeasonedSoldier"] = 279423,
				["OneAgainstMany"] = 429637,
				["DoubleTime"] = 103827,
				["MartialProwess"] = 316440,
				["Whirlwind"] = 1680,
				["AngerManagement"] = 152278,
				["ShatteringThrow"] = 64382,
				["Brawn"] = 154743,
				["BattleforAzerothPathfinder"] = 278833,
				["ArmorSkills"] = 76268,
				["ArmoredtotheTeeth"] = 384124,
				["FierceFollowthrough"] = 444773,
				["Battlelord"] = 386630,
				["BerserkerRage"] = 18499,
				["ReaptheStorm"] = 444775,
				["PiercingChallenge"] = 382948,
				["ImminentDemise"] = 444769,
				["HonedReflexes"] = 391271,
				["UnrelentingOnslaught"] = 444780,
				["ArterialBleed"] = 440995,
				["Demolish"] = 436358,
				["CruelStrikes"] = 392777,
				["StormofSwords"] = 385512,
				["DeathDrive"] = 444770,
				["NoStrangertoPain"] = 429644,
				["CollateralDamage"] = 334779,
				["WarMachine"] = 262231,
				["DiebytheSword"] = 118038,
				["OverwhelmingBlades"] = 444772,
				["CacophonousRoar"] = 382954,
				["VindicaarMatrixCrystal"] = 251463,
				["VeteranVitality"] = 440993,
				["FrothingBerserker"] = 392792,
				["FinishingBlows"] = 400205,
				["BitterImmunity"] = 383762,
				["Execute"] = 281000,
				["Rend"] = 772,
				["ExhilaratingBlows"] = 383219,
				["Bladestorm"] = 227847,
				["Massacre"] = 281001,
				["MasterRiding"] = 90265,
				["Boneshaker"] = 429639,
				["ColossalMight"] = 429634,
				["Languages"] = 79746,
				["ShowNoMercy"] = 444771,
				["TwoHandedWeaponSpecialization"] = 382896,
				["ConcussiveBlows"] = 383115,
				["SpellReflection"] = 23920,
				["WarStomp"] = 20549,
				["SlayersMalice"] = 444779,
				["StormWall"] = 388807,
				["DominanceoftheColossus"] = 429636,
				["CleansedVestments"] = 328263,
				["ChampionsSpear"] = 376079,
				["ThunderClap"] = 6343,
				["Intervene"] = 3411,
				["WeaponSkills"] = 76290,
				["Hamstring"] = 1715,
				["MartialExpert"] = 429638,
				["ShieldBlock"] = 2565,
				["AutoAttack"] = 6603,
				["Taunt"] = 355,
				["MasteryDeepWounds"] = 262111,
			},
			["Fury"] = {
				["KeepYourFeetontheGround"] = 438590,
				["OdynsFury"] = 385059,
				["SwiftStrikes"] = 383459,
				["Uproar"] = 391572,
				["CriticalThinking"] = 383297,
				["AshenJuggernaut"] = 392536,
				["RagingBlow"] = 85288,
				["Ravager"] = 228920,
				["FreshMeat"] = 215568,
				["PiercingHowl"] = 12323,
				["UnrelentingOnslaught"] = 444780,
				["ThunderousWords"] = 384969,
				["ViciousAgility"] = 444777,
				["StormBolts"] = 436162,
				["ThunderBlast"] = 435607,
				["Sidearm"] = 384404,
				["RelentlessPursuit"] = 444776,
				["HeroicThrow"] = 57755,
				["SuddenDeath"] = 280721,
				["EnragedRegeneration"] = 184364,
				["ThunderousRoar"] = 384318,
				["SingleMindedFury"] = 81099,
				["DepthsofInsanity"] = 383922,
				["AvataroftheStorm"] = 437134,
				["ShieldSlam"] = 23922,
				["MasteryUnshackledFury"] = 76856,
				["ChampionsMight"] = 386284,
				["ImpendingVictory"] = 202168,
				["Unhinged"] = 386628,
				["UnbridledFerocity"] = 389603,
				["ThunderClap"] = 6343,
				["WreckingThrow"] = 384110,
				["Bloodborne"] = 385703,
				["Avatar"] = 107574,
				["Menace"] = 275338,
				["BrokenIslesPathfinder"] = 233368,
				["Rampage"] = 184367,
				["Tenderize"] = 388933,
				["OverwhelmingBlades"] = 444772,
				["BerserkerShout"] = 384100,
				["LightningStrikes"] = 434969,
				["BattleShout"] = 6673,
				["ReviveBattlePets"] = 125439,
				["HeroicLeap"] = 6544,
				["DualWield"] = 231842,
				["ConcussiveBlows"] = 383115,
				["GuildMail"] = 83951,
				["DefensiveStance"] = 386208,
				["RallyingCry"] = 97462,
				["BoundingStride"] = 202163,
				["OverwhelmingRage"] = 382767,
				["InvigoratingFury"] = 383468,
				["Frenzy"] = 335077,
				["RecklessAbandon"] = 396749,
				["StormBolt"] = 107570,
				["ReinforcedPlates"] = 382939,
				["CracklingThunder"] = 203201,
				["ViciousContempt"] = 383885,
				["FastFootwork"] = 382260,
				["Cultivation"] = 20552,
				["DualWieldSpecialization"] = 382900,
				["WildStrikes"] = 382946,
				["SlayersDominance"] = 444767,
				["StrengthoftheMountain"] = 437068,
				["SecondWind"] = 29838,
				["Charge"] = 100,
				["VictoryRush"] = 34428,
				["WrathandFury"] = 392936,
				["Cruelty"] = 392931,
				["Warpaint"] = 208154,
				["Bloodcraze"] = 393950,
				["Pummel"] = 6552,
				["MobileBanking"] = 83958,
				["DeftExperience"] = 383295,
				["SeismicReverberation"] = 382956,
				["BrutalFinish"] = 446085,
				["CullingCyclone"] = 444778,
				["Bloodthirst"] = 23881,
				["Brawn"] = 154743,
				["RumblingEarth"] = 275339,
				["Onslaught"] = 315720,
				["SpellReflection"] = 23920,
				["FierceFollowthrough"] = 444773,
				["TitansGrip"] = 46917,
				["FrenziedEnrage"] = 383848,
				["NatureResistance"] = 20551,
				["Bladestorm"] = 227847,
				["ImprovedExecute"] = 316402,
				["BarbaricTraining"] = 390674,
				["MeatCleaver"] = 280392,
				["DeathDrive"] = 444770,
				["ShieldBlock"] = 2565,
				["Massacre"] = 206315,
				["BerserkerRage"] = 18499,
				["WeaponSkills"] = 76290,
				["CrushingForce"] = 382764,
				["Enrage"] = 184361,
				["PiercingChallenge"] = 382948,
				["GatheringClouds"] = 436201,
				["DoubleTime"] = 103827,
				["FlashingSkies"] = 437079,
				["Whirlwind"] = 190411,
				["AngerManagement"] = 152278,
				["ShatteringThrow"] = 64382,
				["CrashingThunder"] = 436707,
				["MountUp"] = 78633,
				["SteadfastasthePeaks"] = 434970,
				["EnduranceTraining"] = 391997,
				["IntimidatingShout"] = 5246,
				["HastyHearth"] = 83944,
				["Endurance"] = 20550,
				["ReaptheStorm"] = 444775,
				["TitanicRage"] = 394329,
				["ThorimsMight"] = 436152,
				["PainandGain"] = 382549,
				["Recklessness"] = 1719,
				["SlaughteringStrikes"] = 388004,
				["Slam"] = 1464,
				["CruelStrikes"] = 392777,
				["ImprovedBloodthirst"] = 383852,
				["BurstofPower"] = 437118,
				["Shockwave"] = 46968,
				["ImprovedRagingBlow"] = 383854,
				["WarMachine"] = 346002,
				["ArmoredtotheTeeth"] = 384124,
				["Opportunist"] = 444774,
				["CacophonousRoar"] = 382954,
				["VindicaarMatrixCrystal"] = 251463,
				["StormShield"] = 438597,
				["FrothingBerserker"] = 215571,
				["HackandSlash"] = 383877,
				["BitterImmunity"] = 383762,
				["Execute"] = 280735,
				["FocusinChaos"] = 383486,
				["LeechingStrikes"] = 382258,
				["PowerfulEnrage"] = 440277,
				["BerserkersTorment"] = 390123,
				["MasterRiding"] = 90265,
				["HonedReflexes"] = 391271,
				["TitansTorment"] = 390135,
				["Languages"] = 79746,
				["ShowNoMercy"] = 444771,
				["ImminentDemise"] = 444769,
				["WarStomp"] = 20549,
				["ArmorSkills"] = 76268,
				["BattleforAzerothPathfinder"] = 278833,
				["SlayersMalice"] = 444779,
				["StormofSteel"] = 382953,
				["GroundCurrent"] = 436148,
				["ImprovedWhirlwind"] = 12950,
				["ChampionsSpear"] = 376079,
				["TheQuickandtheDead"] = 83950,
				["Intervene"] = 3411,
				["SnapInduction"] = 456270,
				["ColdSteelHotBlood"] = 383959,
				["Hamstring"] = 1715,
				["DancingBlades"] = 391683,
				["AutoAttack"] = 6603,
				["Taunt"] = 355,
				["BerserkerStance"] = 386196,
			},
		},
		["Paladin"] = {
			["Protection"] = {
				["SacrosanctCrusade"] = 431730,
				["SeasonedWarhorse"] = 376996,
				["FaithsArmor"] = 406101,
				["Sanctification"] = 432977,
				["BlessedHammer"] = 204019,
				["SealofOrder"] = 385129,
				["BlessingofFreedom"] = 1044,
				["Redoubt"] = 280373,
				["UnrelentingCharger"] = 432990,
				["UndisputedRuling"] = 432626,
				["CleanseToxins"] = 213644,
				["CrusaderStrike"] = 35395,
				["HolyBulwark"] = 432459,
				["TheQuickandtheDead"] = 83950,
				["Contemplation"] = 121183,
				["SealofAlacrity"] = 385425,
				["DivineGuidance"] = 433106,
				["Consecration"] = 26573,
				["HolyAegis"] = 385515,
				["Rebuke"] = 96231,
				["DivinePurpose"] = 223817,
				["CrusadersJudgment"] = 204023,
				["FerrenMarcussFervor"] = 378762,
				["LightsDeliverance"] = 425518,
				["GrandCrusader"] = 85043,
				["QuickenedInvocation"] = 379391,
				["RelentlessInquisitor"] = 383388,
				["GreaterJudgment"] = 231663,
				["Obduracy"] = 385427,
				["AurasoftheResolute"] = 385633,
				["UthersCounsel"] = 378425,
				["JudgmentofLight"] = 183778,
				["SharedResolve"] = 432821,
				["LightsGuidance"] = 427445,
				["StrengthinAdversity"] = 393071,
				["SacrificeoftheJust"] = 384820,
				["ReviveBattlePets"] = 125439,
				["SealofMercy"] = 384897,
				["ArdentDefender"] = 31850,
				["TouchofLight"] = 385349,
				["Sentinel"] = 389539,
				["GuardianofAncientKings"] = 86659,
				["DivineInspiration"] = 432964,
				["Recompense"] = 384914,
				["StrengthofConviction"] = 379008,
				["SanctifiedPlates"] = 402964,
				["Forewarning"] = 432804,
				["BulwarkofOrder"] = 209389,
				["ConsecratedGround"] = 204054,
				["ShiningLight"] = 321136,
				["WordofGlory"] = 85673,
				["BlessingofSpellwarding"] = 204018,
				["Logging"] = 167895,
				["Repentance"] = 20066,
				["LightforgedBlessing"] = 406468,
				["HammerofJustice"] = 853,
				["TurnEvil"] = 10326,
				["LayingDownArms"] = 432866,
				["Riposte"] = 161800,
				["UnboundFreedom"] = 305394,
				["FearNoEvil"] = 432834,
				["Hammerfall"] = 432463,
				["HammerofWrath"] = 24275,
				["Justification"] = 377043,
				["HammeroftheRighteous"] = 53595,
				["InnerLight"] = 386568,
				["HammerandAnvil"] = 433718,
				["BondsofFellowship"] = 432992,
				["HigherCalling"] = 431687,
				["ShieldoftheRighteous"] = 53600,
				["MobileBanking"] = 83958,
				["LayonHands"] = 633,
				["SealofReprisal"] = 377053,
				["UnbreakableSpirit"] = 114154,
				["ShaketheHeavens"] = 431533,
				["ResoluteDefender"] = 385422,
				["CrusaderAura"] = 32223,
				["ZealotsParagon"] = 391142,
				["Valiance"] = 432919,
				["ZealousVindication"] = 431463,
				["ImprovedBlessingofProtection"] = 384909,
				["BastionofLight"] = 378974,
				["InspiringVanguard"] = 393022,
				["ArmorSkills"] = 76271,
				["FaithintheLight"] = 379043,
				["TirionsDevotion"] = 392928,
				["HastyHearth"] = 83944,
				["HandofReckoning"] = 62124,
				["DivineResonance"] = 386738,
				["RighteousProtector"] = 204074,
				["ConcentrationAura"] = 317920,
				["WrathfulDescent"] = 431551,
				["Solidarity"] = 432802,
				["MountUp"] = 78633,
				["ForWhomtheBellTolls"] = 432929,
				["GuildMail"] = 83951,
				["GoldenPath"] = 377128,
				["BlessingoftheForge"] = 433011,
				["Judgment"] = 275779,
				["GiftoftheGoldenValkyr"] = 378279,
				["RiteofAdjuration"] = 433583,
				["FistofJustice"] = 234299,
				["EyeofTyr"] = 387174,
				["ArcaneAcuity"] = 154742,
				["DevotionAura"] = 465,
				["Intercession"] = 391054,
				["SealofMight"] = 385450,
				["Punishment"] = 403530,
				["DivineShield"] = 642,
				["SealofCharity"] = 384815,
				["BlessingofProtection"] = 1022,
				["BlessedAssurance"] = 433015,
				["DivineSteed"] = 190784,
				["FocusedEnmity"] = 378845,
				["ConsecrationinFlame"] = 379022,
				["AvengingWrath"] = 31884,
				["FinalStand"] = 204077,
				["Incandescence"] = 385464,
				["Sanctuary"] = 379021,
				["DivineToll"] = 375576,
				["MomentofGlory"] = 327193,
				["ArcaneAffinity"] = 28877,
				["HandoftheProtector"] = 315924,
				["SoaringShield"] = 378457,
				["BarricadeofFaith"] = 385726,
				["VindicaarMatrixCrystal"] = 251463,
				["Cavalier"] = 230332,
				["InmostLight"] = 405757,
				["ImprovedArdentDefender"] = 393114,
				["RiteofSanctification"] = 433568,
				["BulwarkofRighteousFury"] = 386653,
				["SealoftheCrusader"] = 385728,
				["Excoriation"] = 433896,
				["FadingLight"] = 405768,
				["SenseUndead"] = 5502,
				["MasterRiding"] = 90265,
				["BlindingLight"] = 115750,
				["LightoftheTitans"] = 378405,
				["Languages"] = 79748,
				["OfDuskandDawn"] = 409441,
				["ImprovedHolyShield"] = 393030,
				["TyrsEnforcer"] = 378285,
				["ArcaneTorrent"] = 155145,
				["BlessingofSacrifice"] = 6940,
				["BrokenIslesPathfinder"] = 233368,
				["ArcaneResistance"] = 822,
				["HolyShield"] = 152261,
				["WeaponSkills"] = 76294,
				["Afterimage"] = 385414,
				["BattleforAzerothPathfinder"] = 278833,
				["AvengersShield"] = 31935,
				["FlashofLight"] = 19750,
				["EndlessWrath"] = 432615,
				["CrusadersResolve"] = 380188,
				["Redemption"] = 7328,
				["AutoAttack"] = 6603,
				["AegisofLight"] = 353367,
				["MasteryDivineBulwark"] = 76671,
			},
			["Holy"] = {
				["Cleanse"] = 4987,
				["Punishment"] = 403530,
				["SeasonedWarhorse"] = 376996,
				["FaithsArmor"] = 406101,
				["DivineToll"] = 375576,
				["Aurora"] = 439760,
				["SealofOrder"] = 385129,
				["BlessingofFreedom"] = 1044,
				["TowerofRadiance"] = 231642,
				["Absolution"] = 212056,
				["OverflowingLight"] = 461244,
				["ArcaneAcuity"] = 154742,
				["CrusaderStrike"] = 35395,
				["SealofMight"] = 385450,
				["HandofDivinity"] = 414273,
				["TheQuickandtheDead"] = 83950,
				["Dawnlight"] = 431377,
				["Contemplation"] = 121183,
				["SealofAlacrity"] = 385425,
				["DivineGuidance"] = 433106,
				["Reclamation"] = 415364,
				["RighteousJudgment"] = 414113,
				["HolyAegis"] = 385515,
				["Rebuke"] = 96231,
				["LightsProtection"] = 461243,
				["DivinePurpose"] = 223817,
				["Awestruck"] = 417855,
				["ShiningRighteousness"] = 414443,
				["BattleforAzerothPathfinder"] = 278833,
				["QuickenedInvocation"] = 379391,
				["BestowLight"] = 448040,
				["GreaterJudgment"] = 231644,
				["Obduracy"] = 385427,
				["AurasoftheResolute"] = 385633,
				["JudgmentofLight"] = 183778,
				["SharedResolve"] = 432821,
				["Extrication"] = 461278,
				["SacrificeoftheJust"] = 384820,
				["SunSear"] = 431413,
				["ReviveBattlePets"] = 125439,
				["SealofMercy"] = 384897,
				["ImprovedBlessingofProtection"] = 384909,
				["TouchofLight"] = 385349,
				["DivineRevelations"] = 387808,
				["WeaponSkills"] = 76294,
				["ResplendentLight"] = 392902,
				["Recompense"] = 384914,
				["StrengthofConviction"] = 379008,
				["EmpyreanLegacy"] = 387170,
				["SanctifiedPlates"] = 402964,
				["TruthPrevails"] = 461273,
				["SunsAvatar"] = 431425,
				["ProtectionofTyr"] = 200430,
				["BlessedAssurance"] = 433015,
				["ImbuedInfusions"] = 392961,
				["WordofGlory"] = 85673,
				["Logging"] = 167895,
				["Repentance"] = 20066,
				["LightforgedBlessing"] = 406468,
				["HammerofJustice"] = 853,
				["TurnEvil"] = 10326,
				["GloriousDawn"] = 461246,
				["LayingDownArms"] = 432866,
				["RiteofAdjuration"] = 433583,
				["FearNoEvil"] = 432834,
				["MomentofCompassion"] = 387786,
				["HammerofWrath"] = 24275,
				["MorningStar"] = 431482,
				["Justification"] = 377043,
				["RisingSunlight"] = 461250,
				["LightofDawn"] = 85222,
				["HammerandAnvil"] = 433718,
				["ShieldoftheRighteous"] = 415091,
				["MobileBanking"] = 83958,
				["LayonHands"] = 633,
				["Illumine"] = 431423,
				["UnbreakableSpirit"] = 114154,
				["MasteryLightbringer"] = 183997,
				["ImprovedCleanse"] = 393024,
				["MercifulAuras"] = 183415,
				["SolarGrace"] = 431404,
				["CrusaderAura"] = 32223,
				["GoldenPath"] = 377128,
				["GlisteningRadiance"] = 461245,
				["Luminosity"] = 431402,
				["Redemption"] = 7328,
				["Valiance"] = 432919,
				["RelentlessInquisitor"] = 383388,
				["HandofReckoning"] = 62124,
				["DivineShield"] = 642,
				["BreakingDawn"] = 387879,
				["Afterimage"] = 385414,
				["LightsConviction"] = 414073,
				["FlashofLight"] = 19750,
				["BeaconoftheLightbringer"] = 197446,
				["Consecration"] = 26573,
				["ConcentrationAura"] = 317920,
				["EchoingBlessings"] = 387801,
				["HastyHearth"] = 83944,
				["BarrierofFaith"] = 148039,
				["DivineResonance"] = 386738,
				["MountUp"] = 78633,
				["InflorescenceoftheSunwell"] = 392907,
				["UnendingLight"] = 387998,
				["SanctifiedWrath"] = 53376,
				["GuildMail"] = 83951,
				["BrokenIslesPathfinder"] = 233368,
				["ArmorSkills"] = 76271,
				["TyrsDeliverance"] = 200652,
				["DivineProtection"] = 498,
				["Judgment"] = 275773,
				["HolyLight"] = 82326,
				["ArcaneTorrent"] = 155145,
				["FistofJustice"] = 234299,
				["HolyPrism"] = 114165,
				["BlessingofProtection"] = 1022,
				["DevotionAura"] = 465,
				["Intercession"] = 391054,
				["HolyBulwark"] = 432459,
				["VanguardsMomentum"] = 416869,
				["Veneration"] = 392938,
				["CrusadersMight"] = 196926,
				["HolyInfusion"] = 414214,
				["Awakening"] = 414195,
				["DivineSteed"] = 190784,
				["BeaconofFaith"] = 156910,
				["EternalFlame"] = 156322,
				["AvengingWrath"] = 31884,
				["BeaconofVirtue"] = 200025,
				["AuraMastery"] = 31821,
				["WilloftheDawn"] = 431406,
				["DivineInspiration"] = 432964,
				["BlessingoftheForge"] = 433011,
				["ArcaneAffinity"] = 28877,
				["LingeringRadiance"] = 431407,
				["Solidarity"] = 432802,
				["BeaconofLight"] = 53563,
				["VindicaarMatrixCrystal"] = 251463,
				["UnwaveringSpirit"] = 392911,
				["Forewarning"] = 432804,
				["BlessingofSummer"] = 388007,
				["RiteofSanctification"] = 433568,
				["Cavalier"] = 230332,
				["SealoftheCrusader"] = 416770,
				["Excoriation"] = 433896,
				["FadingLight"] = 405768,
				["HolyShock"] = 20473,
				["MasterRiding"] = 90265,
				["BlindingLight"] = 115750,
				["LightoftheMartyr"] = 447985,
				["Languages"] = 79748,
				["OfDuskandDawn"] = 409439,
				["SavedbytheLight"] = 157047,
				["AvengingCrusader"] = 216331,
				["GleamingRays"] = 431480,
				["BlessingofSacrifice"] = 6940,
				["PoweroftheSilverHand"] = 200474,
				["ArcaneResistance"] = 822,
				["Liberation"] = 461287,
				["SecondSunrise"] = 431474,
				["CommandingLight"] = 387781,
				["DivineFavor"] = 460422,
				["Incandescence"] = 385464,
				["BoundlessSalvation"] = 392951,
				["TirionsDevotion"] = 414720,
				["SenseUndead"] = 5502,
				["BlessingofAnshe"] = 445200,
				["AutoAttack"] = 6603,
				["InfusionofLight"] = 53576,
				["DivineGlimpse"] = 387805,
			},
			["Retribution"] = {
				["SacrosanctCrusade"] = 431730,
				["TempestoftheLightbringer"] = 383396,
				["SeasonedWarhorse"] = 376996,
				["FaithsArmor"] = 406101,
				["DivineToll"] = 375576,
				["Aurora"] = 439760,
				["SealofOrder"] = 385129,
				["BlessingofFreedom"] = 1044,
				["ZealotsFervor"] = 403509,
				["UnrelentingCharger"] = 432990,
				["Cavalier"] = 230332,
				["CleanseToxins"] = 213644,
				["CrusaderStrike"] = 35395,
				["SealofMight"] = 385450,
				["BurningCrusade"] = 405289,
				["TheQuickandtheDead"] = 83950,
				["Dawnlight"] = 431377,
				["Contemplation"] = 121183,
				["SealofAlacrity"] = 385425,
				["Consecration"] = 26573,
				["HolyAegis"] = 385515,
				["Rebuke"] = 96231,
				["DivinePurpose"] = 408459,
				["BladesofLight"] = 403664,
				["ConsecratedBlade"] = 404834,
				["DivineStorm"] = 53385,
				["RighteousCause"] = 402912,
				["RadiantGlory"] = 458359,
				["QuickenedInvocation"] = 379391,
				["GreaterJudgment"] = 231663,
				["CrusadingStrikes"] = 404542,
				["Obduracy"] = 385427,
				["AurasoftheResolute"] = 385633,
				["JudgmentofLight"] = 183778,
				["GuidedPrayer"] = 404357,
				["Sanctify"] = 382536,
				["LightsGuidance"] = 427445,
				["SacrificeoftheJust"] = 384820,
				["SunSear"] = 431413,
				["ReviveBattlePets"] = 125439,
				["SealofMercy"] = 384897,
				["ImprovedBlessingofProtection"] = 384909,
				["TouchofLight"] = 385349,
				["MountUp"] = 78633,
				["WeaponSkills"] = 76294,
				["BladeofVengeance"] = 403826,
				["ImprovedBladeofJustice"] = 403745,
				["VanguardofJustice"] = 406545,
				["MasteryHighlordsJudgment"] = 267316,
				["DivineHammer"] = 198034,
				["StrengthofConviction"] = 379008,
				["EmpyreanLegacy"] = 387170,
				["SanctifiedPlates"] = 402964,
				["ShieldofVengeance"] = 184662,
				["SunsAvatar"] = 431425,
				["SeethingFlames"] = 405355,
				["BladeofJustice"] = 184575,
				["WordofGlory"] = 85673,
				["BoundlessJudgment"] = 405278,
				["Logging"] = 167895,
				["VengefulWrath"] = 406835,
				["Repentance"] = 20066,
				["LightforgedBlessing"] = 403479,
				["HeartoftheCrusader"] = 406154,
				["TurnEvil"] = 10326,
				["Redemption"] = 7328,
				["Penitence"] = 403026,
				["UnboundFreedom"] = 305394,
				["JudgmentofJustice"] = 403495,
				["HammerofWrath"] = 24275,
				["TemplarsVerdict"] = 85256,
				["Expurgation"] = 383344,
				["Justification"] = 377043,
				["JusticarsVengeance"] = 215661,
				["BondsofFellowship"] = 432992,
				["HigherCalling"] = 431687,
				["SwiftJustice"] = 383228,
				["DivineWrath"] = 406872,
				["MobileBanking"] = 83958,
				["ExecutionSentence"] = 343527,
				["LayonHands"] = 633,
				["BurntoAsh"] = 446663,
				["Illumine"] = 431423,
				["UnbreakableSpirit"] = 114154,
				["ShaketheHeavens"] = 431533,
				["SolarGrace"] = 431404,
				["CrusaderAura"] = 32223,
				["GoldenPath"] = 377128,
				["Luminosity"] = 431402,
				["TemplarStrikes"] = 406646,
				["ImprovedCrusaderStrike"] = 383254,
				["ZealousVindication"] = 431463,
				["Crusade"] = 384392,
				["ConsecratedGround"] = 204054,
				["ShieldoftheRighteous"] = 53600,
				["Recompense"] = 384914,
				["Jurisdiction"] = 402971,
				["HandofReckoning"] = 62124,
				["HastyHearth"] = 83944,
				["HealingHands"] = 326734,
				["DivineResonance"] = 384027,
				["FlashofLight"] = 19750,
				["ImprovedJudgment"] = 405461,
				["WrathfulDescent"] = 431551,
				["DivineArbiter"] = 404306,
				["GuildMail"] = 83951,
				["ForWhomtheBellTolls"] = 432929,
				["BlessingofAnshe"] = 445200,
				["MorningStar"] = 431482,
				["DivineProtection"] = 403876,
				["Judgment"] = 20271,
				["ArcaneAcuity"] = 154742,
				["GleamingRays"] = 431480,
				["FistofJustice"] = 234299,
				["LightsCelerity"] = 403698,
				["Adjudication"] = 406157,
				["DevotionAura"] = 465,
				["Intercession"] = 391054,
				["JudgeJuryandExecutioner"] = 405607,
				["ArtofWar"] = 406064,
				["SearingLight"] = 404540,
				["WilloftheDawn"] = 431406,
				["UndisputedRuling"] = 432626,
				["Sanctification"] = 432977,
				["DivineSteed"] = 190784,
				["EternalFlame"] = 156322,
				["RushofLight"] = 407067,
				["AvengingWrath"] = 31884,
				["Hammerfall"] = 432463,
				["BlessedChampion"] = 403010,
				["HighlordsWrath"] = 404512,
				["DivineAuxiliary"] = 406158,
				["EmpyreanPower"] = 326732,
				["ArcaneAffinity"] = 28877,
				["LingeringRadiance"] = 431407,
				["VanguardsMomentum"] = 383314,
				["FinalReckoning"] = 343721,
				["VindicaarMatrixCrystal"] = 251463,
				["Incandescence"] = 385464,
				["SealoftheCrusader"] = 385728,
				["HolyBlade"] = 383342,
				["BlessingofProtection"] = 1022,
				["AegisofProtection"] = 403654,
				["InquisitorsIre"] = 403975,
				["Punishment"] = 403530,
				["FadingLight"] = 405768,
				["FinalVerdict"] = 383328,
				["MasterRiding"] = 90265,
				["BlindingLight"] = 115750,
				["ExecutionersWill"] = 406940,
				["Languages"] = 79748,
				["OfDuskandDawn"] = 385125,
				["ArcaneTorrent"] = 155145,
				["WakeofAshes"] = 255937,
				["LightsDeliverance"] = 425518,
				["BlessingofSacrifice"] = 6940,
				["ArmorSkills"] = 76271,
				["ArcaneResistance"] = 822,
				["BrokenIslesPathfinder"] = 233368,
				["SecondSunrise"] = 431474,
				["Afterimage"] = 385414,
				["DivineShield"] = 642,
				["LightofJustice"] = 404436,
				["HammerofJustice"] = 853,
				["EndlessWrath"] = 432615,
				["BattleforAzerothPathfinder"] = 278833,
				["SenseUndead"] = 5502,
				["AutoAttack"] = 6603,
				["ConcentrationAura"] = 317920,
				["InstrumentofRetribution"] = 404752,
			},
		},
		["Shaman"] = {
			["Enhancement"] = {
				["SwiftRecall"] = 445027,
				["EarthShield"] = 974,
				["Stormflurry"] = 344357,
				["TravelingStorms"] = 204403,
				["PlanesTraveler"] = 381647,
				["Stormblast"] = 319930,
				["ImprovedMaelstromWeapon"] = 383303,
				["BloodFury"] = 33697,
				["LightningLasso"] = 305483,
				["NaturesProtection"] = 454027,
				["FireNova"] = 333974,
				["VoodooMastery"] = 204268,
				["WindBarrier"] = 445031,
				["TheQuickandtheDead"] = 83950,
				["CalloftheElements"] = 383011,
				["TotemicSurge"] = 381867,
				["SpiritWalk"] = 58875,
				["Purge"] = 370,
				["IceStrike"] = 342240,
				["NaturesFury"] = 381655,
				["Hex"] = 51514,
				["TempestStrikes"] = 428071,
				["LavaLash"] = 60103,
				["AncestralWolfAffinity"] = 382197,
				["PulseCapacitor"] = 445032,
				["SpiritWolf"] = 260878,
				["LegacyoftheFrostWitch"] = 384450,
				["Earthsurge"] = 455590,
				["FarSight"] = 6196,
				["Oversurge"] = 445030,
				["GustofWind"] = 192063,
				["UnlimitedPower"] = 454391,
				["SwirlingMaelstrom"] = 384359,
				["BrokenIslesPathfinder"] = 233368,
				["ElementalBlast"] = 117014,
				["JetStream"] = 462817,
				["CapacitorTotem"] = 192058,
				["Thunderstorm"] = 51490,
				["Stormstrike"] = 17364,
				["SplinteredElements"] = 382042,
				["LightningShield"] = 192106,
				["SeasonedWinds"] = 355630,
				["ReviveBattlePets"] = 125439,
				["CleanseSpirit"] = 51886,
				["SpiritwalkersGrace"] = 79206,
				["LashingFlames"] = 334046,
				["GuildMail"] = 83951,
				["RefreshingWaters"] = 378211,
				["ElementalAssault"] = 210853,
				["Sundering"] = 197214,
				["ElementalSpirits"] = 262624,
				["AscendingAir"] = 462791,
				["TremorTotem"] = 8143,
				["GhostWolf"] = 2645,
				["AmplificationCore"] = 445029,
				["ChainHeal"] = 1064,
				["FireandIce"] = 382886,
				["StoneBulwarkTotem"] = 108270,
				["HotHand"] = 201900,
				["OversizedTotems"] = 445026,
				["HealingStreamTotem"] = 5394,
				["PrimalMaelstrom"] = 384405,
				["AstralRecall"] = 556,
				["TotemicCoordination"] = 445036,
				["NaturesGuardian"] = 30884,
				["FlameShock"] = 188389,
				["CreationCore"] = 383012,
				["StaticAccumulation"] = 384411,
				["Flurry"] = 382888,
				["BrimmingwithLife"] = 381689,
				["EncasingCold"] = 462762,
				["FeralSpirit"] = 51533,
				["EarthbindTotem"] = 2484,
				["ManaSpring"] = 381930,
				["Reactivity"] = 445035,
				["FrostShock"] = 196840,
				["ElementalWeapons"] = 384355,
				["MobileBanking"] = 83958,
				["FeralLunge"] = 196884,
				["PrimalStrike"] = 73899,
				["WindShear"] = 57994,
				["ThorimsInvocation"] = 384444,
				["FlametongueWeapon"] = 318038,
				["RagingMaelstrom"] = 384143,
				["ArmorSkills"] = 76272,
				["CrashLightning"] = 187874,
				["ElementalWarding"] = 381650,
				["ConvergingStorms"] = 384363,
				["ThunderousPaws"] = 378075,
				["DeeplyRootedElements"] = 378270,
				["TotemicProjection"] = 108287,
				["LavaBurst"] = 51505,
				["ElementalOrbit"] = 383010,
				["HastyHearth"] = 83944,
				["DoomWinds"] = 384352,
				["Supercharge"] = 455110,
				["TotemicRebound"] = 445025,
				["PrimordialBond"] = 381764,
				["AutoAttack"] = 6603,
				["Skyfury"] = 462854,
				["AstralShift"] = 108271,
				["WindsofAlAkir"] = 382215,
				["Thundershock"] = 378779,
				["WhirlingElements"] = 445024,
				["TotemicRecall"] = 108285,
				["MaelstromWeapon"] = 187880,
				["ConductiveEnergy"] = 455123,
				["AncestralSpirit"] = 2008,
				["WeaponSkills"] = 76296,
				["Hardiness"] = 20573,
				["Command"] = 21563,
				["EnhancedImbues"] = 462796,
				["BattleforAzerothPathfinder"] = 278833,
				["EarthElemental"] = 198103,
				["GreaterPurge"] = 378773,
				["Reincarnation"] = 20608,
				["StormSwell"] = 455088,
				["AncestralGuidance"] = 108281,
				["WindRushTotem"] = 192077,
				["GracefulSpirit"] = 192088,
				["SurgingTotem"] = 444995,
				["AlphaWolf"] = 198434,
				["SpiritwalkersAegis"] = 378077,
				["Languages"] = 79743,
				["TotemicFocus"] = 382201,
				["OverflowingMaelstrom"] = 384149,
				["VoltaicSurge"] = 454919,
				["UnrulyWinds"] = 390288,
				["MasterRiding"] = 90265,
				["NaturesSwiftness"] = 378081,
				["WitchDoctorsAncestry"] = 384447,
				["ShockingGrasp"] = 454022,
				["VindicaarMatrixCrystal"] = 251463,
				["WaterWalking"] = 546,
				["CrashingStorms"] = 334308,
				["PoisonCleansingTotem"] = 383013,
				["WindfuryWeapon"] = 33757,
				["Tempest"] = 454009,
				["Hailstorm"] = 334195,
				["Stormcaller"] = 454021,
				["AshenCatalyst"] = 390370,
				["ArcDischarge"] = 455096,
				["ImbuementMastery"] = 445028,
				["MasteryEnhancedElements"] = 77223,
				["PrimordialWave"] = 375982,
				["RollingThunder"] = 454026,
				["SurgingCurrents"] = 454372,
				["ForcefulWinds"] = 262647,
				["LivelyTotems"] = 445034,
				["StaticCharge"] = 265046,
				["EarthgrabTotem"] = 51485,
				["AstralBulwark"] = 377933,
				["SupportiveImbuements"] = 445033,
				["AwakeningStorms"] = 455129,
				["MoltenAssault"] = 334033,
				["LightningBolt"] = 188196,
				["Bloodlust"] = 2825,
				["MountUp"] = 78633,
				["ArcticSnowstorm"] = 462764,
				["ElementalResistance"] = 462368,
				["GuardiansCudgel"] = 381819,
				["HealingSurge"] = 8004,
				["Ascendance"] = 114051,
				["ChainLightning"] = 188443,
				["StormsWrath"] = 392352,
			},
			["Restoration"] = {
				["SpiritwalkersMomentum"] = 443425,
				["TidalWaves"] = 51564,
				["SurgingTotem"] = 444995,
				["ArcticSnowstorm"] = 462764,
				["TravelingStorms"] = 204403,
				["AncestralSwiftness"] = 443454,
				["PoisonCleansingTotem"] = 383013,
				["Wellspring"] = 197995,
				["PrimordialWave"] = 428332,
				["LivingStream"] = 382482,
				["BloodFury"] = 33697,
				["LightningLasso"] = 305483,
				["Undercurrent"] = 382194,
				["VoodooMastery"] = 204268,
				["WindBarrier"] = 445031,
				["TheQuickandtheDead"] = 83950,
				["CalloftheElements"] = 383011,
				["LivelyTotems"] = 445034,
				["SpiritWalk"] = 58875,
				["Deluge"] = 200076,
				["UnleashLife"] = 73685,
				["Purge"] = 370,
				["HighTide"] = 157154,
				["Hex"] = 51514,
				["AncestralWolfAffinity"] = 382197,
				["PulseCapacitor"] = 445032,
				["SpiritWolf"] = 260878,
				["OverflowingShores"] = 383222,
				["AncestralGuidance"] = 108281,
				["EarthenWallTotem"] = 198838,
				["Earthsurge"] = 455590,
				["FarSight"] = 6196,
				["Oversurge"] = 445030,
				["GustofWind"] = 192063,
				["BrokenIslesPathfinder"] = 233368,
				["SpiritwalkersTidalTotem"] = 404522,
				["SpiritLinkTotem"] = 98008,
				["CapacitorTotem"] = 192058,
				["Undulation"] = 200071,
				["TideTurner"] = 404019,
				["GreaterPurge"] = 378773,
				["LightningShield"] = 192106,
				["SeasonedWinds"] = 355630,
				["AncestralAwakening"] = 382309,
				["AstralBulwark"] = 377933,
				["SpiritwalkersGrace"] = 79206,
				["Torrent"] = 200072,
				["GuildMail"] = 83951,
				["RefreshingWaters"] = 378211,
				["MountUp"] = 78633,
				["AncestralReach"] = 382732,
				["GracefulSpirit"] = 192088,
				["AscendingAir"] = 462791,
				["WavespeakersBlessing"] = 381946,
				["TremorTotem"] = 8143,
				["GhostWolf"] = 2645,
				["AmplificationCore"] = 445029,
				["ChainHeal"] = 1064,
				["FireandIce"] = 382886,
				["StoneBulwarkTotem"] = 108270,
				["HealingRain"] = 73920,
				["OversizedTotems"] = 445026,
				["HealingStreamTotem"] = 5394,
				["ElementalReverb"] = 443418,
				["AstralRecall"] = 556,
				["ManaTideTotem"] = 16191,
				["TotemicCoordination"] = 445036,
				["CurrentControl"] = 404015,
				["SpoutingSpirits"] = 462383,
				["NaturesGuardian"] = 30884,
				["FlameShock"] = 188389,
				["CreationCore"] = 383012,
				["Preeminence"] = 462443,
				["HealingSurge"] = 8004,
				["BrimmingwithLife"] = 381689,
				["EncasingCold"] = 462762,
				["EarthbindTotem"] = 2484,
				["AcidRain"] = 378443,
				["ManaSpring"] = 381930,
				["Reactivity"] = 445035,
				["FrostShock"] = 196840,
				["CloudburstTotem"] = 157153,
				["Tidewaters"] = 462424,
				["MobileBanking"] = 83958,
				["PrimalStrike"] = 73899,
				["WindShear"] = 57994,
				["FlametongueWeapon"] = 318038,
				["ArmorSkills"] = 76272,
				["ElementalOrbit"] = 383010,
				["ElementalWarding"] = 381650,
				["WaterShield"] = 52127,
				["AutoAttack"] = 6603,
				["ChainLightning"] = 188443,
				["TotemicProjection"] = 108287,
				["DeeplyRootedElements"] = 378270,
				["Skyfury"] = 462854,
				["Reincarnation"] = 20608,
				["ImprovedEarthlivingWeapon"] = 382315,
				["AncestralSpirit"] = 2008,
				["LavaBurst"] = 51505,
				["MasteryDeepHealing"] = 77226,
				["WeaponSkills"] = 76296,
				["Riptide"] = 61295,
				["EarthgrabTotem"] = 51485,
				["Bloodlust"] = 2825,
				["TotemicRebound"] = 445025,
				["PrimordialBond"] = 381764,
				["TotemicRecall"] = 108285,
				["HastyHearth"] = 83944,
				["AstralShift"] = 108271,
				["WindsofAlAkir"] = 382215,
				["Thundershock"] = 378779,
				["WhirlingElements"] = 445024,
				["Hardiness"] = 20573,
				["Thunderstorm"] = 51490,
				["Command"] = 21563,
				["EarthlivingWeapon"] = 382021,
				["LatentWisdom"] = 443449,
				["BattleforAzerothPathfinder"] = 278833,
				["CalloftheAncestors"] = 443450,
				["RoutineCommunication"] = 443445,
				["ReviveBattlePets"] = 125439,
				["HeedMyCall"] = 443444,
				["PurifySpirit"] = 77130,
				["WindRushTotem"] = 192077,
				["NaturesFury"] = 381655,
				["PlanesTraveler"] = 381647,
				["SwiftRecall"] = 445027,
				["OfferingfromBeyond"] = 443451,
				["Downpour"] = 462486,
				["MasterRiding"] = 90265,
				["SpiritwalkersAegis"] = 378077,
				["FlowoftheTides"] = 382039,
				["EarthElemental"] = 198103,
				["EarthenHarmony"] = 382020,
				["WaterWalking"] = 546,
				["FinalCalling"] = 443446,
				["WaterTotemMastery"] = 382030,
				["Resurgence"] = 16196,
				["LavaSurge"] = 77756,
				["PrimalTideCore"] = 382045,
				["VindicaarMatrixCrystal"] = 251463,
				["AncestralProtectionTotem"] = 207399,
				["AncientFellowship"] = 443423,
				["StaticCharge"] = 265046,
				["FirstAscendant"] = 462440,
				["EarthenCommunion"] = 443441,
				["MasteroftheElements"] = 462375,
				["ReactiveWarding"] = 462454,
				["HealingWave"] = 77472,
				["NaturesSwiftness"] = 378081,
				["ImbuementMastery"] = 445028,
				["AncestralVigor"] = 207401,
				["EarthShield"] = 974,
				["Languages"] = 79743,
				["TotemicFocus"] = 382201,
				["JetStream"] = 462817,
				["EchooftheElements"] = 333919,
				["EnhancedImbues"] = 462796,
				["MaelstromSupremacy"] = 443447,
				["ImprovedPurifySpirit"] = 383016,
				["SupportiveImbuements"] = 445033,
				["PrimordialCapacity"] = 443448,
				["TotemicSurge"] = 381867,
				["LightningBolt"] = 188196,
				["Tidebringer"] = 236501,
				["ThunderousPaws"] = 378075,
				["WhiteWater"] = 462587,
				["NaturalHarmony"] = 443442,
				["GuardiansCudgel"] = 381819,
				["AncestralVision"] = 212048,
				["Ascendance"] = 114052,
				["HealingTideTotem"] = 108280,
				["ElementalResistance"] = 462368,
			},
			["Elemental"] = {
				["SpiritwalkersMomentum"] = 443425,
				["UnrelentingCalamity"] = 382685,
				["EarthShield"] = 974,
				["TravelingStorms"] = 204403,
				["AncestralSwiftness"] = 443454,
				["PlanesTraveler"] = 381647,
				["LavaSurge"] = 77756,
				["PrimordialWave"] = 375982,
				["BloodFury"] = 33697,
				["LightningLasso"] = 305483,
				["PrimalElementalist"] = 117013,
				["FlowofPower"] = 385923,
				["NaturesProtection"] = 454027,
				["PoweroftheMaelstrom"] = 191861,
				["VoodooMastery"] = 204268,
				["TheQuickandtheDead"] = 83950,
				["CalloftheElements"] = 383011,
				["TotemicSurge"] = 381867,
				["SpiritWalk"] = 58875,
				["Earthquake"] = 462620,
				["Purge"] = 370,
				["NaturesFury"] = 381655,
				["Hex"] = 51514,
				["AncestralWolfAffinity"] = 382197,
				["SpiritWolf"] = 260878,
				["EchooftheElements"] = 333919,
				["StormElemental"] = 192249,
				["PrimordialFury"] = 378193,
				["ElementalEquilibrium"] = 378271,
				["BattleforAzerothPathfinder"] = 278833,
				["GustofWind"] = 192063,
				["UnlimitedPower"] = 454391,
				["BrokenIslesPathfinder"] = 233368,
				["Supercharge"] = 455110,
				["JetStream"] = 462817,
				["CapacitorTotem"] = 192058,
				["Thunderstorm"] = 51490,
				["EyeoftheStorm"] = 381708,
				["EarthShock"] = 8042,
				["SplinteredElements"] = 382042,
				["LightningShield"] = 192106,
				["SeasonedWinds"] = 355630,
				["ReviveBattlePets"] = 125439,
				["CleanseSpirit"] = 51886,
				["SpiritwalkersGrace"] = 79206,
				["AncientFellowship"] = 443423,
				["Stormkeeper"] = 191634,
				["RefreshingWaters"] = 378211,
				["MountUp"] = 78633,
				["WeaponSkills"] = 76296,
				["GracefulSpirit"] = 192088,
				["AscendingAir"] = 462791,
				["TremorTotem"] = 8143,
				["GhostWolf"] = 2645,
				["ChainHeal"] = 1064,
				["FireandIce"] = 382886,
				["StoneBulwarkTotem"] = 108270,
				["SearingFlames"] = 381782,
				["FireElemental"] = 198067,
				["FluxMelting"] = 381776,
				["ElementalReverb"] = 443418,
				["ImprovedFlametongueWeapon"] = 382027,
				["AstralRecall"] = 556,
				["PrimordialCapacity"] = 443448,
				["MountainsWillFall"] = 381726,
				["NaturesGuardian"] = 30884,
				["FlamesoftheCauldron"] = 378266,
				["CreationCore"] = 383012,
				["Preeminence"] = 462443,
				["HealingSurge"] = 8004,
				["BrimmingwithLife"] = 381689,
				["EncasingCold"] = 462762,
				["EarthbindTotem"] = 2484,
				["Icefury"] = 462816,
				["ManaSpring"] = 381930,
				["FrostShock"] = 196840,
				["ElementalUnity"] = 462866,
				["Aftershock"] = 273221,
				["MobileBanking"] = 83958,
				["PrimalStrike"] = 73899,
				["WindShear"] = 57994,
				["FlametongueWeapon"] = 318038,
				["MasteryElementalOverload"] = 168534,
				["FuryoftheStorms"] = 191717,
				["ArmorSkills"] = 76272,
				["ElementalWarding"] = 381650,
				["ElementalOrbit"] = 383010,
				["Reincarnation"] = 20608,
				["ChainLightning"] = 188443,
				["AutoAttack"] = 6603,
				["DeeplyRootedElements"] = 378270,
				["TotemicProjection"] = 108287,
				["Inundate"] = 378776,
				["FarSight"] = 6196,
				["StormFrenzy"] = 462695,
				["LavaBurst"] = 51505,
				["Hardiness"] = 20573,
				["AncestralSpirit"] = 2008,
				["HastyHearth"] = 83944,
				["EarthgrabTotem"] = 51485,
				["Languages"] = 79743,
				["TotemicFocus"] = 382201,
				["PrimordialBond"] = 381764,
				["ConductiveEnergy"] = 455123,
				["Command"] = 21563,
				["AstralShift"] = 108271,
				["MagmaChamber"] = 381932,
				["Thundershock"] = 378779,
				["CalloftheAncestors"] = 443450,
				["Skyfury"] = 462854,
				["AncestralGuidance"] = 108281,
				["LightningConduit"] = 462862,
				["EarthenRage"] = 170374,
				["LatentWisdom"] = 443449,
				["FusionofElements"] = 462840,
				["MaelstromSupremacy"] = 443447,
				["RoutineCommunication"] = 443445,
				["LiquidMagmaTotem"] = 192222,
				["EarthElemental"] = 198103,
				["ThunderstrikeWard"] = 462757,
				["EnhancedImbues"] = 462796,
				["StormSwell"] = 455088,
				["SwellingMaelstrom"] = 381707,
				["ElementalFury"] = 60188,
				["OfferingfromBeyond"] = 443451,
				["WindRushTotem"] = 192077,
				["SurgeofPower"] = 262303,
				["SpiritwalkersAegis"] = 378077,
				["LightningRod"] = 210689,
				["NaturesSwiftness"] = 378081,
				["EchoChamber"] = 382032,
				["VoltaicSurge"] = 454919,
				["EchooftheElementals"] = 462864,
				["WaterWalking"] = 546,
				["HealingStreamTotem"] = 5394,
				["EverlastingElements"] = 462867,
				["ShockingGrasp"] = 454022,
				["VindicaarMatrixCrystal"] = 251463,
				["GreaterPurge"] = 378773,
				["FirstAscendant"] = 462440,
				["EchoesofGreatSundering"] = 384087,
				["ArcticSnowstorm"] = 462764,
				["EarthenCommunion"] = 443441,
				["Tempest"] = 454009,
				["Stormcaller"] = 454021,
				["StaticCharge"] = 265046,
				["ArcDischarge"] = 455096,
				["MasterRiding"] = 90265,
				["TotemicRecall"] = 108285,
				["SkybreakersFieryDemise"] = 378310,
				["RollingThunder"] = 454026,
				["SurgingCurrents"] = 454372,
				["MasteroftheElements"] = 16166,
				["FinalCalling"] = 443446,
				["ThunderousPaws"] = 378075,
				["PoisonCleansingTotem"] = 383013,
				["HeedMyCall"] = 443444,
				["WindsofAlAkir"] = 382215,
				["FlashofLightning"] = 381936,
				["AstralBulwark"] = 377933,
				["LightningBolt"] = 188196,
				["Bloodlust"] = 2825,
				["AwakeningStorms"] = 455129,
				["GuildMail"] = 83951,
				["NaturalHarmony"] = 443442,
				["GuardiansCudgel"] = 381819,
				["FlameShock"] = 188389,
				["Ascendance"] = 114050,
				["ElementalBlast"] = 117014,
				["ElementalResistance"] = 462368,
			},
		},
		["Monk"] = {
			["Windwalker"] = {
				["FlurryofXuen"] = 452137,
				["VeteransEye"] = 450987,
				["Ascension"] = 115396,
				["ElusiveMists"] = 388681,
				["MemoryoftheMonastery"] = 454969,
				["Transcendence"] = 101643,
				["YulonsKnowledge"] = 443625,
				["XuensBond"] = 392986,
				["SwiftArt"] = 450622,
				["LeadfromtheFront"] = 450985,
				["ProfoundRebuttal"] = 392910,
				["WindsReach"] = 450514,
				["QuickFooted"] = 450503,
				["SoothingMist"] = 115175,
				["PressurePoints"] = 450432,
				["TigerTailSweep"] = 264348,
				["CraneVortex"] = 388848,
				["Windwalking"] = 157411,
				["RevolvingWhirl"] = 451524,
				["VigorousExpulsion"] = 392900,
				["TempleTraining"] = 442743,
				["MartialPrecision"] = 450990,
				["StormEarthandFire"] = 137639,
				["FlightoftheRedCrane"] = 443255,
				["JadeIgnition"] = 392979,
				["ExpelHarm"] = 322101,
				["FastFeet"] = 388809,
				["CrashingMomentum"] = 450335,
				["AugustDynasty"] = 442818,
				["Resuscitate"] = 115178,
				["Clash"] = 324312,
				["BrokenIslesPathfinder"] = 233368,
				["SummonWhiteTigerStatue"] = 450639,
				["CourageousImpulse"] = 451495,
				["StrengthoftheBlackOx"] = 443110,
				["CombatWisdom"] = 121817,
				["PeaceandProsperity"] = 450448,
				["SequencedStrikes"] = 451515,
				["ReviveBattlePets"] = 125439,
				["LighterThanAir"] = 449582,
				["Celerity"] = 115173,
				["GuildMail"] = 83951,
				["TigerPalm"] = 100780,
				["FerocityofXuen"] = 388674,
				["WeaponSkills"] = 106902,
				["Disable"] = 116095,
				["JadeSanctuary"] = 443059,
				["EnergyBurst"] = 451498,
				["ImprovedTouchofDeath"] = 322113,
				["PoweroftheThunderKing"] = 459809,
				["SpearHandStrike"] = 116705,
				["FistsofFury"] = 113656,
				["TranscendenceLinkedSpirits"] = 434774,
				["ShadowboxingTreads"] = 392982,
				["TigersLust"] = 116841,
				["RisingSunKick"] = 107428,
				["Ferociousness"] = 458623,
				["HitCombo"] = 196740,
				["FatalTouch"] = 394123,
				["Paralysis"] = 115078,
				["FlowofChi"] = 450569,
				["SpinningCraneKick"] = 101546,
				["DualThreat"] = 451823,
				["MartialInstincts"] = 450427,
				["FuryofXuen"] = 396166,
				["FortifyingBrew"] = 115203,
				["JadefireHarmony"] = 391412,
				["TeachingsoftheMonastery"] = 116645,
				["NiuzaosProtection"] = 442747,
				["JadefireStomp"] = 388193,
				["TouchofKarma"] = 122470,
				["InvokersDelight"] = 388661,
				["Afterlife"] = 116092,
				["VivaciousVivification"] = 388812,
				["MysticTouch"] = 8647,
				["BounceBack"] = 389577,
				["StrengthofSpirit"] = 387276,
				["ZenPilgrimage"] = 126892,
				["BoundingAgility"] = 450520,
				["ZenFlight"] = 125883,
				["TouchoftheTiger"] = 388856,
				["DanceoftheWind"] = 432181,
				["Vivify"] = 116670,
				["Provoke"] = 115546,
				["ProtectandServe"] = 450984,
				["LegSweep"] = 119381,
				["BlackoutKick"] = 100784,
				["Roll"] = 109132,
				["ArmorSkills"] = 106904,
				["ComboBreaker"] = 137384,
				["SaveThemAll"] = 389579,
				["TheQuickandtheDead"] = 83950,
				["QuakingPalm"] = 107079,
				["OneVersusMany"] = 450988,
				["ChiBurst"] = 460485,
				["EfficientTraining"] = 450989,
				["MobileBanking"] = 83958,
				["Thunderfist"] = 392985,
				["InvokeXuentheWhiteTiger"] = 123904,
				["HardenedSoles"] = 391383,
				["MasteryComboStrikes"] = 115636,
				["DiffuseMagic"] = 122783,
				["MartialMixture"] = 451454,
				["DartingHurricane"] = 459839,
				["HastyHearth"] = 83944,
				["RushingJadeWind"] = 451505,
				["ExpeditiousFortification"] = 388813,
				["EnergyTransfer"] = 450631,
				["BattleforAzerothPathfinder"] = 278833,
				["ChiWave"] = 450391,
				["Bouncy"] = 107076,
				["GraceoftheCrane"] = 388811,
				["ChiTorpedo"] = 115008,
				["GaleForce"] = 451580,
				["FlurryStrikes"] = 450615,
				["WhirlingDragonPunch"] = 152175,
				["HighImpact"] = 450982,
				["XuensBattlegear"] = 392993,
				["StrikeoftheWindlord"] = 392983,
				["PrideofPandaria"] = 450979,
				["RingofPeace"] = 116844,
				["WisdomoftheWall"] = 450994,
				["CalmingPresence"] = 388664,
				["PredictiveTraining"] = 450992,
				["WhirlingSteel"] = 450991,
				["SpiritualFocus"] = 280197,
				["CourageoftheWhiteTiger"] = 443087,
				["VigilantWatch"] = 450993,
				["Epicurean"] = 107072,
				["Detox"] = 218164,
				["Gourmand"] = 107073,
				["CelestialDetermination"] = 450638,
				["GloryoftheDawn"] = 392958,
				["UnityWithin"] = 443589,
				["IronshellBrew"] = 388814,
				["JadefireFists"] = 457974,
				["DrinkingHornCover"] = 391370,
				["FlyingSerpentKick"] = 101545,
				["ChiJisSwiftness"] = 443566,
				["HeartoftheJadeSerpent"] = 443294,
				["XuensGuidance"] = 442687,
				["MomentumBoost"] = 451294,
				["SpiritsEssence"] = 450595,
				["VindicaarMatrixCrystal"] = 251463,
				["SongofChiJi"] = 198898,
				["MeridianStrikes"] = 391330,
				["LastEmperorsCapacitor"] = 392989,
				["CelestialConduit"] = 443028,
				["PathofJade"] = 392994,
				["DanceofChiJi"] = 325201,
				["RestoreBalance"] = 442719,
				["InnerCompass"] = 443571,
				["KnowledgeoftheBrokenTemple"] = 451529,
				["MasterRiding"] = 90265,
				["AgainstAllOdds"] = 450986,
				["BrawlersIntensity"] = 451485,
				["Languages"] = 131701,
				["RushingReflexes"] = 450154,
				["OrderedElements"] = 451463,
				["YulonsGrace"] = 414131,
				["EscapefromReality"] = 394110,
				["CommunionWithWind"] = 451576,
				["JadeWalk"] = 450553,
				["ChiProficiency"] = 450426,
				["TransferthePower"] = 195300,
				["SingularlyFocusedJade"] = 451573,
				["MountUp"] = 78633,
				["InnerPeace"] = 107074,
				["RisingStar"] = 388849,
				["AncientArts"] = 344359,
				["TouchofDeath"] = 322109,
				["HealingWinds"] = 450560,
				["HastyProvocation"] = 328670,
				["AutoAttack"] = 6603,
				["CracklingJadeLightning"] = 117952,
				["Acclamation"] = 451432,
			},
			["Brewmaster"] = {
				["BlackOxAdept"] = 455079,
				["OneWiththeWind"] = 454484,
				["VeteransEye"] = 450987,
				["ElusiveMists"] = 388681,
				["PredictiveTraining"] = 450992,
				["Transcendence"] = 101643,
				["SwiftArt"] = 450622,
				["CelestialFlames"] = 325177,
				["LeadfromtheFront"] = 450985,
				["QuickSip"] = 388505,
				["ProfoundRebuttal"] = 392910,
				["OxStance"] = 455068,
				["WindsReach"] = 450514,
				["QuickFooted"] = 450503,
				["AspectofHarmony"] = 450508,
				["SoothingMist"] = 115175,
				["PressurePoints"] = 450432,
				["CalltoArms"] = 397251,
				["TigerTailSweep"] = 264348,
				["CelestialDetermination"] = 450638,
				["Windwalking"] = 157411,
				["AugustBlessing"] = 454483,
				["HeightenedGuard"] = 455081,
				["VigorousExpulsion"] = 392900,
				["MartialPrecision"] = 450990,
				["GaiPlinsImperialBrew"] = 383700,
				["PresstheAdvantage"] = 418359,
				["CarversEye"] = 350899,
				["StormstoutsLastKeg"] = 383707,
				["ExpelHarm"] = 322101,
				["FastFeet"] = 388809,
				["DragonfireBrew"] = 383994,
				["CrashingMomentum"] = 450335,
				["TouchofDeath"] = 322109,
				["BalancedStratagem"] = 450889,
				["Clash"] = 324312,
				["BrokenIslesPathfinder"] = 233368,
				["HitScheme"] = 383695,
				["ExplodingKeg"] = 325153,
				["PeaceandProsperity"] = 450448,
				["ReviveBattlePets"] = 125439,
				["LighterThanAir"] = 449582,
				["ChiSurge"] = 393400,
				["Celerity"] = 115173,
				["GuildMail"] = 83951,
				["TigerPalm"] = 100780,
				["FerocityofXuen"] = 388674,
				["WeaponSkills"] = 106902,
				["Disable"] = 116095,
				["ImprovedTouchofDeath"] = 322113,
				["PurifyingBrew"] = 119582,
				["StaggeringStrikes"] = 387625,
				["SpearHandStrike"] = 116705,
				["ChiProficiency"] = 450426,
				["TranscendenceLinkedSpirits"] = 434774,
				["ShadowboxingTreads"] = 387638,
				["TigersLust"] = 116841,
				["PretenseofInstability"] = 393516,
				["RoarfromtheHeavens"] = 451043,
				["SalsalabimsStrength"] = 383697,
				["BreathofFire"] = 115181,
				["MantraofPurity"] = 451036,
				["FatalTouch"] = 394123,
				["Paralysis"] = 115078,
				["FlowofChi"] = 450569,
				["SpinningCraneKick"] = 322729,
				["WayofaThousandStrikes"] = 450965,
				["CalmingPresence"] = 388664,
				["MartialInstincts"] = 450427,
				["PathofResurgence"] = 450912,
				["WhirlingSteel"] = 450991,
				["FortifyingBrew"] = 115203,
				["Detox"] = 218164,
				["InvokeNiuzaotheBlackOx"] = 132578,
				["HighTolerance"] = 196737,
				["KegSmash"] = 121253,
				["VivaciousVivification"] = 388812,
				["WeaponsofOrder"] = 387184,
				["StrengthofSpirit"] = 387276,
				["ZenFlight"] = 125883,
				["PurifiedSpirit"] = 450867,
				["CelestialFortune"] = 216519,
				["BrewmastersBalance"] = 245013,
				["DanceoftheWind"] = 414132,
				["MysticTouch"] = 8647,
				["ZenPilgrimage"] = 126892,
				["ProtectandServe"] = 450984,
				["MasteryElusiveBrawler"] = 117906,
				["SummonBlackOxStatue"] = 115315,
				["Vivify"] = 116670,
				["ArmorSkills"] = 106904,
				["Resuscitate"] = 115178,
				["Roll"] = 109132,
				["Provoke"] = 115546,
				["QuakingPalm"] = 107079,
				["OneVersusMany"] = 450988,
				["ScaldingBrew"] = 383698,
				["TigersVigor"] = 451041,
				["LegSweep"] = 119381,
				["CracklingJadeLightning"] = 117952,
				["FortifyingBrewDetermination"] = 322960,
				["ChiWave"] = 450391,
				["BlackOxBrew"] = 115399,
				["BlackoutKick"] = 100784,
				["TheQuickandtheDead"] = 83950,
				["JadeWalk"] = 450553,
				["Stagger"] = 115069,
				["ZenMeditation"] = 115176,
				["ExpeditiousFortification"] = 388813,
				["DiffuseMagic"] = 122783,
				["VigilantWatch"] = 450993,
				["MountUp"] = 78633,
				["Bouncy"] = 107076,
				["BounceBack"] = 389577,
				["SpiritoftheOx"] = 400629,
				["ChiTorpedo"] = 115008,
				["HastyHearth"] = 83944,
				["CelestialBrew"] = 322507,
				["Languages"] = 131701,
				["EfficientTraining"] = 450989,
				["BattleforAzerothPathfinder"] = 278833,
				["CharredPassions"] = 386965,
				["RingofPeace"] = 116844,
				["GraceoftheCrane"] = 388811,
				["ClarityofPurpose"] = 451017,
				["MobileBanking"] = 83958,
				["ChiBurst"] = 123986,
				["SaveThemAll"] = 389579,
				["BoundingAgility"] = 450520,
				["FlurryStrikes"] = 450615,
				["Epicurean"] = 107072,
				["Shuffle"] = 322120,
				["Gourmand"] = 107073,
				["GiftoftheOx"] = 124502,
				["FacePalm"] = 389942,
				["Counterstrike"] = 383785,
				["HighImpact"] = 450982,
				["PrideofPandaria"] = 450979,
				["MantraofTenacity"] = 451029,
				["WalkwiththeOx"] = 387219,
				["RuneforgedSpurs"] = 326512,
				["StrikeAtDawn"] = 455043,
				["LightBrewing"] = 325093,
				["ElixirofDetermination"] = 455139,
				["SpiritsEssence"] = 450595,
				["VindicaarMatrixCrystal"] = 251463,
				["SongofChiJi"] = 198898,
				["DampenHarm"] = 122278,
				["Anvil&Stave"] = 386937,
				["SpecialDelivery"] = 196730,
				["WisdomoftheWall"] = 450994,
				["EndlessDraught"] = 450892,
				["BobandWeave"] = 280515,
				["ImprovedInvokeNiuzaotheBlackOx"] = 322740,
				["HarmonicGambit"] = 450870,
				["MasterRiding"] = 90265,
				["AgainstAllOdds"] = 450986,
				["ElusiveFootwork"] = 387046,
				["EscapefromReality"] = 394110,
				["RushingReflexes"] = 450154,
				["FluidityofMotion"] = 387230,
				["YulonsGrace"] = 414131,
				["TrainingofNiuzao"] = 383714,
				["Manifestation"] = 450875,
				["BlackoutCombo"] = 196736,
				["EnergyTransfer"] = 450631,
				["RushingJadeWind"] = 116847,
				["ForgeborneReveries"] = 326514,
				["OverwhelmingForce"] = 451024,
				["InnerPeace"] = 107074,
				["RisingSunKick"] = 107428,
				["AncientArts"] = 344359,
				["TranquilSpirit"] = 393357,
				["HealingWinds"] = 450560,
				["HastyProvocation"] = 328670,
				["AutoAttack"] = 6603,
				["Coalescence"] = 450529,
				["IronshellBrew"] = 388814,
			},
			["Mistweaver"] = {
				["ZenPulse"] = 446326,
				["RefreshingJadeWind"] = 457397,
				["ElusiveMists"] = 388681,
				["LegacyofWisdom"] = 404408,
				["Transcendence"] = 101643,
				["YulonsKnowledge"] = 443625,
				["SwiftArt"] = 450622,
				["CelestialHarmony"] = 343655,
				["VeilofPride"] = 400053,
				["GiftoftheCelestials"] = 388212,
				["ProfoundRebuttal"] = 392910,
				["WindsReach"] = 450514,
				["QuickFooted"] = 450503,
				["AspectofHarmony"] = 450508,
				["SoothingMist"] = 115175,
				["PressurePoints"] = 450432,
				["TigerTailSweep"] = 264348,
				["CelestialDetermination"] = 450638,
				["TearofMorning"] = 387991,
				["Windwalking"] = 157411,
				["LotusInfusion"] = 458431,
				["DancingMists"] = 388701,
				["VigorousExpulsion"] = 392900,
				["TempleTraining"] = 442743,
				["FlightoftheRedCrane"] = 443255,
				["InnerCompass"] = 443571,
				["FastFeet"] = 388809,
				["CrashingMomentum"] = 450335,
				["AugustDynasty"] = 442818,
				["BalancedStratagem"] = 450889,
				["Clash"] = 324312,
				["SheilunsGift"] = 399491,
				["EnergizingBrew"] = 422031,
				["StrengthoftheBlackOx"] = 443110,
				["Chrysalis"] = 202424,
				["PeaceandProsperity"] = 450448,
				["ReviveBattlePets"] = 125439,
				["LighterThanAir"] = 449582,
				["Celerity"] = 115173,
				["GuildMail"] = 83951,
				["TigerPalm"] = 100780,
				["FerocityofXuen"] = 388674,
				["WeaponSkills"] = 106902,
				["Disable"] = 116095,
				["TeaofSerenity"] = 393460,
				["ImprovedTouchofDeath"] = 322113,
				["SpearHandStrike"] = 116705,
				["Unison"] = 388477,
				["ChiProficiency"] = 450426,
				["TranscendenceLinkedSpirits"] = 434774,
				["TigersLust"] = 116841,
				["RisingSunKick"] = 107428,
				["RoarfromtheHeavens"] = 451043,
				["AncientTeachings"] = 388023,
				["RapidDiffusion"] = 388847,
				["FatalTouch"] = 394123,
				["Paralysis"] = 115078,
				["FlowofChi"] = 450569,
				["SpinningCraneKick"] = 101546,
				["WayofaThousandStrikes"] = 450965,
				["CalmingPresence"] = 388664,
				["MartialInstincts"] = 450427,
				["RisingMist"] = 274909,
				["PathofResurgence"] = 450912,
				["AwakenedJadefire"] = 388779,
				["FortifyingBrew"] = 115203,
				["Detox"] = 115450,
				["AncientConcordance"] = 388740,
				["CracklingJadeLightning"] = 117952,
				["ZenFlight"] = 125883,
				["Coalescence"] = 450529,
				["HealingElixir"] = 122280,
				["JadefireStomp"] = 388193,
				["ZenPilgrimage"] = 126892,
				["TeachingsoftheMonastery"] = 116645,
				["MistyPeaks"] = 388682,
				["Vivify"] = 116670,
				["VivaciousVivification"] = 388812,
				["NourishingChi"] = 387765,
				["TouchofDeath"] = 322109,
				["BounceBack"] = 389577,
				["Provoke"] = 115546,
				["StrengthofSpirit"] = 387276,
				["SummonJadeSerpentStatue"] = 115313,
				["BoundingAgility"] = 450520,
				["CalmingCoalescence"] = 388218,
				["AncientArts"] = 344359,
				["DanceoftheWind"] = 432181,
				["ExpelHarm"] = 322101,
				["BlackoutKick"] = 100784,
				["TheQuickandtheDead"] = 83950,
				["MountUp"] = 78633,
				["JadeWalk"] = 450553,
				["BattleforAzerothPathfinder"] = 278833,
				["ArmorSkills"] = 106904,
				["BurstofLife"] = 399226,
				["SaveThemAll"] = 389579,
				["BrokenIslesPathfinder"] = 233368,
				["QuakingPalm"] = 107079,
				["GraceoftheCrane"] = 388811,
				["InvigoratingMists"] = 274586,
				["YulonsWhisper"] = 388038,
				["OverflowingMists"] = 388511,
				["PeerIntoPeace"] = 440008,
				["Languages"] = 131701,
				["DeepClarity"] = 446345,
				["EnergyTransfer"] = 450631,
				["ShaohaosLessons"] = 400089,
				["ChiWave"] = 450391,
				["Reawaken"] = 212051,
				["HastyHearth"] = 83944,
				["InvokeChiJitheRedCrane"] = 325197,
				["ExpeditiousFortification"] = 388813,
				["DiffuseMagic"] = 122783,
				["MendingProliferation"] = 388509,
				["ThunderFocusTea"] = 116680,
				["Bouncy"] = 107076,
				["PeacefulMending"] = 388593,
				["TeaofPlenty"] = 388517,
				["ChiTorpedo"] = 115008,
				["PoolofMists"] = 173841,
				["RenewingMist"] = 115151,
				["TigersVigor"] = 451041,
				["RestoreBalance"] = 442719,
				["Lifecycles"] = 197915,
				["MantraofTenacity"] = 451029,
				["DanceofChiJi"] = 438439,
				["JadeSanctuary"] = 443059,
				["ClarityofPurpose"] = 451017,
				["MistWrap"] = 197900,
				["PurifiedSpirit"] = 450867,
				["NiuzaosProtection"] = 442747,
				["CourageoftheWhiteTiger"] = 443087,
				["Epicurean"] = 107072,
				["FocusedThunder"] = 197895,
				["Revival"] = 115310,
				["Gourmand"] = 107073,
				["InvokersDelight"] = 388661,
				["MantraofPurity"] = 451036,
				["TranscendenceTransfer"] = 119996,
				["MysticTouch"] = 8647,
				["MasteryGustofMists"] = 117907,
				["ChiHarmony"] = 448392,
				["ChiJisSwiftness"] = 443566,
				["MistsofLife"] = 388548,
				["EndlessDraught"] = 450892,
				["ResplendentMist"] = 388020,
				["UnityWithin"] = 443589,
				["SpiritsEssence"] = 450595,
				["VindicaarMatrixCrystal"] = 251463,
				["SongofChiJi"] = 198898,
				["XuensGuidance"] = 442687,
				["JadeBond"] = 388031,
				["CelestialConduit"] = 443028,
				["RingofPeace"] = 116844,
				["Manifestation"] = 450875,
				["ManaTea"] = 115294,
				["SecretInfusion"] = 388491,
				["HarmonicGambit"] = 450870,
				["MasterRiding"] = 90265,
				["ChiBurst"] = 123986,
				["CraneStyle"] = 446260,
				["EscapefromReality"] = 394110,
				["RushingReflexes"] = 450154,
				["Restoral"] = 388615,
				["YulonsGrace"] = 414131,
				["MobileBanking"] = 83958,
				["Roll"] = 109132,
				["LifeCocoon"] = 116849,
				["OverwhelmingForce"] = 451024,
				["HeartoftheJadeSerpent"] = 443294,
				["ImprovedDetox"] = 388874,
				["UpliftedSpirits"] = 388551,
				["InnerPeace"] = 107074,
				["LegSweep"] = 119381,
				["EnvelopingMist"] = 124682,
				["Resuscitate"] = 115178,
				["HealingWinds"] = 450560,
				["HastyProvocation"] = 328670,
				["AutoAttack"] = 6603,
				["InvokeYulontheJadeSerpent"] = 322118,
				["IronshellBrew"] = 388814,
			},
		},
		["Rogue"] = {
			["Outlaw"] = {
				["BladeRush"] = 271877,
				["KillingSpree"] = 51690,
				["SuperiorMixture"] = 423701,
				["Crackshot"] = 423703,
				["AdrenalineRush"] = 13750,
				["FatefulEnding"] = 454428,
				["DealFate"] = 454419,
				["GracefulGuile"] = 423647,
				["SwiftSlasher"] = 381988,
				["Blind"] = 2094,
				["PistolShot"] = 185763,
				["DeviousStratagem"] = 394321,
				["PrecisionShot"] = 428377,
				["DeadlyPrecision"] = 381542,
				["Stealth"] = 1784,
				["TightSpender"] = 381621,
				["DeliveredDoom"] = 454426,
				["HandofFate"] = 452536,
				["TheQuickandtheDead"] = 83950,
				["Smoke"] = 441247,
				["BetweentheEyes"] = 315341,
				["ResoundingClarity"] = 381622,
				["HitandRun"] = 196922,
				["WithoutaTrace"] = 382513,
				["Ambidexterity"] = 381822,
				["RetractableHook"] = 256188,
				["NimbleFingers"] = 378427,
				["ImprovedAmbush"] = 381620,
				["Shiv"] = 5938,
				["IronStomach"] = 193546,
				["AcrobaticStrikes"] = 455143,
				["SoTricky"] = 441403,
				["DisorientingStrikes"] = 441274,
				["RocketJump"] = 69070,
				["AceUpYourSleeve"] = 381828,
				["BrokenIslesPathfinder"] = 233368,
				["ImprovedSprint"] = 231691,
				["DestinyDefined"] = 454435,
				["GhostlyStrike"] = 196937,
				["UnbreakableStride"] = 400804,
				["ShroudofConcealment"] = 114018,
				["CloakofShadows"] = 31224,
				["SoothingDarkness"] = 393970,
				["RushedSetup"] = 378803,
				["GuildMail"] = 83951,
				["MountUp"] = 78633,
				["DancingSteel"] = 272026,
				["Sprint"] = 2983,
				["RolltheBones"] = 315508,
				["Recuperator"] = 378996,
				["DeeperStratagem"] = 193531,
				["Shadowstep"] = 36554,
				["Stillshroud"] = 423662,
				["Dispatch"] = 2098,
				["Elusiveness"] = 79008,
				["DeadenedNerves"] = 231719,
				["CombatPotency"] = 61329,
				["Gouge"] = 1776,
				["Distract"] = 1725,
				["CounttheOdds"] = 381982,
				["Kick"] = 1766,
				["DeathsArrival"] = 454433,
				["FantheHammer"] = 381846,
				["InexorableMarch"] = 454432,
				["AtrophicPoison"] = 381637,
				["FlawlessForm"] = 441321,
				["PickPocket"] = 921,
				["Riposte"] = 344363,
				["Featherfoot"] = 423683,
				["HeavyHitter"] = 381885,
				["FleetFooted"] = 378813,
				["DontBeSuspicious"] = 441415,
				["NimbleFlurry"] = 441367,
				["PickLock"] = 1804,
				["Subterfuge"] = 108208,
				["DirtyTricks"] = 108216,
				["Flickerstrike"] = 441359,
				["VirulentPoisons"] = 381543,
				["Audacity"] = 381845,
				["BetterLivingThroughChemistry"] = 69045,
				["TripleThreat"] = 381894,
				["ImprovedAdrenalineRush"] = 395422,
				["CheapShot"] = 1833,
				["ArmorSkills"] = 76273,
				["ChosensRevelry"] = 454300,
				["CheatDeath"] = 31230,
				["SummarilyDispatched"] = 381990,
				["LoadedDice"] = 256170,
				["Shadowrunner"] = 378807,
				["UnseenBlade"] = 441146,
				["DoubleJeopardy"] = 454430,
				["MeanStreak"] = 453428,
				["TimeisMoney"] = 69042,
				["ThousandCuts"] = 441346,
				["HastyHearth"] = 83944,
				["CuttotheChase"] = 51667,
				["Sap"] = 6770,
				["ThiefsVersatility"] = 381619,
				["Alacrity"] = 193539,
				["SafeFall"] = 1860,
				["Vigor"] = 14983,
				["Inevitability"] = 454434,
				["ThistleTea"] = 381623,
				["Vanish"] = 1856,
				["StingLikeaBee"] = 131511,
				["UnderhandedUpperHand"] = 424044,
				["CoupdeGrace"] = 441423,
				["CrimsonVial"] = 185311,
				["FatalFlourish"] = 35551,
				["Ruthlessness"] = 14161,
				["SleightofHand"] = 381839,
				["QuickDraw"] = 196938,
				["TemptedFate"] = 454286,
				["Reverberation"] = 394332,
				["DeftManeuvers"] = 381878,
				["PackHobgoblin"] = 69046,
				["HiddenOpportunity"] = 383281,
				["Blackjack"] = 379005,
				["NumbingPoison"] = 5761,
				["Ambush"] = 8676,
				["CloudCover"] = 441429,
				["FateIntertwined"] = 454429,
				["SurprisingStrikes"] = 441273,
				["Lethality"] = 382238,
				["RestlessBlades"] = 79096,
				["GreenskinsWickers"] = 386823,
				["TricksoftheTrade"] = 57934,
				["RocketBarrage"] = 69041,
				["EdgeCase"] = 453457,
				["MasterPoisoner"] = 378436,
				["ImprovedWoundPoison"] = 319066,
				["AirborneIrritant"] = 200733,
				["ColdBlood"] = 382245,
				["VindicaarMatrixCrystal"] = 251463,
				["EchoingReprimand"] = 385616,
				["Mirrors"] = 441250,
				["NoScruples"] = 441398,
				["ImprovedBetweentheEyes"] = 235484,
				["TakeembySurprise"] = 382742,
				["MobileBanking"] = 83958,
				["ReviveBattlePets"] = 125439,
				["MasteryMainGauche"] = 76806,
				["CombatStamina"] = 381877,
				["MasterRiding"] = 90265,
				["BlindingPowder"] = 256165,
				["ImprovedMainGauche"] = 382746,
				["Languages"] = 79749,
				["BattleforAzerothPathfinder"] = 278833,
				["Evasion"] = 5277,
				["BestDealsAnywhere"] = 69044,
				["PreciseCuts"] = 381985,
				["WeaponSkills"] = 76297,
				["SinisterStrike"] = 193315,
				["SliceandDice"] = 315496,
				["LeechingPoison"] = 280716,
				["Detection"] = 56814,
				["GrapplingHook"] = 195457,
				["KidneyShot"] = 408,
				["Shadowheart"] = 455131,
				["DeviousDistractions"] = 441263,
				["Opportunity"] = 279876,
				["BladeFlurry"] = 13877,
				["Feint"] = 1966,
				["AutoAttack"] = 6603,
				["FloatLikeaButterfly"] = 354897,
				["KeepItRolling"] = 381989,
			},
			["Subtlety"] = {
				["SuperiorMixture"] = 423701,
				["ShadowDance"] = 185313,
				["BestDealsAnywhere"] = 69044,
				["Shadowstrike"] = 185438,
				["SingularFocus"] = 457055,
				["SilentStorm"] = 385722,
				["Blind"] = 2094,
				["TerrifyingPace"] = 428387,
				["Vigor"] = 14983,
				["DeadlyPrecision"] = 381542,
				["DeathstalkersMark"] = 457052,
				["Veiltouched"] = 382017,
				["Stealth"] = 1784,
				["TightSpender"] = 381621,
				["GoremawsBite"] = 426591,
				["CleartheWitnesses"] = 457053,
				["TheQuickandtheDead"] = 83950,
				["Smoke"] = 441247,
				["ShurikenToss"] = 114014,
				["ResoundingClarity"] = 381622,
				["EtherealCloak"] = 457022,
				["ShadowTechniques"] = 196912,
				["ShadowBlades"] = 121471,
				["NimbleFingers"] = 378427,
				["TheRotten"] = 382015,
				["SwiftDeath"] = 394309,
				["ExhilaratingExecution"] = 428486,
				["Shiv"] = 5938,
				["IronStomach"] = 193546,
				["ShadowedFinishers"] = 382511,
				["SoTricky"] = 441403,
				["DisorientingStrikes"] = 441274,
				["DeepeningShadows"] = 185314,
				["RocketJump"] = 69070,
				["HuntThemDown"] = 457054,
				["Mirrors"] = 441250,
				["BrokenIslesPathfinder"] = 233368,
				["ImprovedSprint"] = 231691,
				["ShurikenTornado"] = 277925,
				["WatchtheShoes!"] = 336140,
				["NoScruples"] = 441398,
				["Rupture"] = 1943,
				["UnbreakableStride"] = 400804,
				["ShroudofConcealment"] = 114018,
				["SymbolicVictory"] = 457062,
				["CloakofShadows"] = 31224,
				["SoothingDarkness"] = 393970,
				["RushedSetup"] = 378803,
				["Shadowcraft"] = 426594,
				["MountUp"] = 78633,
				["WeaponSkills"] = 76297,
				["NightTerrors"] = 277953,
				["Recuperator"] = 378996,
				["DeeperStratagem"] = 193531,
				["TokenofAppreciation"] = 336245,
				["Eviscerate"] = 196819,
				["Shadowstep"] = 36554,
				["Stillshroud"] = 423662,
				["QuickDecisions"] = 382503,
				["Elusiveness"] = 79008,
				["DeadenedNerves"] = 231719,
				["UnseenBlade"] = 441146,
				["Gouge"] = 1776,
				["FindWeakness"] = 91023,
				["LingeringShadow"] = 382524,
				["Blackjack"] = 379005,
				["Kick"] = 1766,
				["AtrophicPoison"] = 381637,
				["FlawlessForm"] = 441321,
				["BlackPowder"] = 319175,
				["ImprovedShurikenStorm"] = 319951,
				["Featherfoot"] = 423683,
				["DarkShadow"] = 245687,
				["FleetFooted"] = 378813,
				["DontBeSuspicious"] = 441415,
				["NimbleFlurry"] = 441367,
				["PickLock"] = 1804,
				["SecretStratagem"] = 394320,
				["Flickerstrike"] = 441359,
				["VirulentPoisons"] = 381543,
				["BetterLivingThroughChemistry"] = 69045,
				["PlannedExecution"] = 382508,
				["LifeoftheParty"] = 336247,
				["ShroudofNight"] = 457063,
				["Backstab"] = 53,
				["MasteryExecutioner"] = 76808,
				["CuttotheChase"] = 51667,
				["ImprovedShadowDance"] = 393972,
				["ShroudedinDarkness"] = 382507,
				["PerforatedVeins"] = 382518,
				["AcrobaticStrikes"] = 455143,
				["CorrupttheBlood"] = 457066,
				["ImprovedShadowTechniques"] = 394023,
				["PickPocket"] = 921,
				["CheatDeath"] = 31230,
				["KidneyShot"] = 408,
				["Sprint"] = 2983,
				["CloakedinShadows"] = 382515,
				["Distract"] = 1725,
				["Shadowrunner"] = 378807,
				["CheapShot"] = 1833,
				["Sepsis"] = 385408,
				["MasterofShadows"] = 196976,
				["TimeisMoney"] = 69042,
				["ReplicatingShadows"] = 382506,
				["Flagellation"] = 384631,
				["CoupdeGrace"] = 441423,
				["Sap"] = 6770,
				["EphemeralBond"] = 426563,
				["Alacrity"] = 193539,
				["HastyHearth"] = 83944,
				["GuildMail"] = 83951,
				["DeviousDistractions"] = 441263,
				["ThistleTea"] = 381623,
				["Vanish"] = 1856,
				["BattleforAzerothPathfinder"] = 278833,
				["FollowtheBlood"] = 457068,
				["TricksoftheTrade"] = 57934,
				["Languages"] = 79749,
				["Finality"] = 382525,
				["ReviveBattlePets"] = 125439,
				["Shadewalker"] = 457057,
				["Inevitability"] = 382512,
				["FadetoNothing"] = 382514,
				["Reverberation"] = 394332,
				["LingeringDarkness"] = 457056,
				["PackHobgoblin"] = 69046,
				["Gloomblade"] = 200758,
				["Evasion"] = 5277,
				["NumbingPoison"] = 5761,
				["ThousandCuts"] = 441346,
				["CloudCover"] = 441429,
				["WithoutaTrace"] = 382513,
				["WarningSigns"] = 426555,
				["Lethality"] = 382238,
				["DarkestNight"] = 457058,
				["DoubleDance"] = 394930,
				["ShadowFocus"] = 108209,
				["SoothingShade"] = 336239,
				["ImprovedWoundPoison"] = 319066,
				["MasterPoisoner"] = 378436,
				["BaitandSwitch"] = 457034,
				["AirborneIrritant"] = 200733,
				["ColdBlood"] = 382245,
				["VindicaarMatrixCrystal"] = 251463,
				["DarkBrew"] = 382504,
				["ShurikenStorm"] = 197835,
				["EchoingReprimand"] = 385616,
				["Weaponmaster"] = 193537,
				["FatalIntent"] = 461980,
				["MobileBanking"] = 83958,
				["TheFirstDance"] = 382505,
				["GracefulGuile"] = 423647,
				["MomentumofDespair"] = 457067,
				["MasterRiding"] = 90265,
				["InvigoratingShadowdust"] = 382523,
				["RocketBarrage"] = 69041,
				["SurprisingStrikes"] = 441273,
				["RelentlessStrikes"] = 58423,
				["SymbolsofDeath"] = 212283,
				["ArmorSkills"] = 76273,
				["ImprovedAmbush"] = 381620,
				["DeeperDaggers"] = 382517,
				["ShotintheDark"] = 257505,
				["SliceandDice"] = 315496,
				["LeechingPoison"] = 280716,
				["Detection"] = 56814,
				["CrimsonVial"] = 185311,
				["SecretTechnique"] = 280719,
				["Shadowheart"] = 455131,
				["Premeditation"] = 343160,
				["DanseMacabre"] = 382528,
				["ImprovedBackstab"] = 319949,
				["Feint"] = 1966,
				["AutoAttack"] = 6603,
				["SafeFall"] = 1860,
				["Subterfuge"] = 108208,
			},
			["Assassination"] = {
				["Doomblade"] = 381673,
				["SuperiorMixture"] = 423701,
				["FatefulEnding"] = 454428,
				["DealFate"] = 454419,
				["SingularFocus"] = 457055,
				["PathofBlood"] = 423054,
				["Blind"] = 2094,
				["IntenttoKill"] = 381630,
				["DragonTemperedBlades"] = 381801,
				["SealFate"] = 14190,
				["DeathstalkersMark"] = 457052,
				["Stealth"] = 115191,
				["TightSpender"] = 381621,
				["DeliveredDoom"] = 454426,
				["PoisonedKnife"] = 185565,
				["HandofFate"] = 452536,
				["TheQuickandtheDead"] = 83950,
				["ThrownPrecision"] = 381629,
				["ResoundingClarity"] = 381622,
				["EtherealCloak"] = 457022,
				["ImprovedGarrote"] = 381632,
				["NimbleFingers"] = 378427,
				["ImprovedAmbush"] = 381620,
				["TinyToxicBlade"] = 381800,
				["IronStomach"] = 193546,
				["AcrobaticStrikes"] = 455143,
				["ShroudedSuffocation"] = 385478,
				["ImprovedShiv"] = 319032,
				["HuntThemDown"] = 457054,
				["BrokenIslesPathfinder"] = 233368,
				["ImprovedSprint"] = 231691,
				["DestinyDefined"] = 454435,
				["LightweightShiv"] = 394983,
				["UnbreakableStride"] = 400804,
				["FatalConcoction"] = 392384,
				["ShroudofConcealment"] = 114018,
				["SymbolicVictory"] = 457062,
				["CloakofShadows"] = 31224,
				["SoothingDarkness"] = 393970,
				["RushedSetup"] = 378803,
				["GuildMail"] = 83951,
				["MountUp"] = 78633,
				["WeaponSkills"] = 76297,
				["Sprint"] = 2983,
				["Recuperator"] = 378996,
				["DeeperStratagem"] = 193531,
				["PoisonBomb"] = 255544,
				["Shadowstep"] = 36554,
				["Stillshroud"] = 423662,
				["Elusiveness"] = 79008,
				["DeadenedNerves"] = 231719,
				["CrimsonTempest"] = 121411,
				["Gouge"] = 1776,
				["Distract"] = 1725,
				["Blackjack"] = 379005,
				["SuddenDemise"] = 423136,
				["Kick"] = 1766,
				["DeathsArrival"] = 454433,
				["FanofKnives"] = 51723,
				["InexorableMarch"] = 454432,
				["Inevitability"] = 454434,
				["BaitandSwitch"] = 457034,
				["SystemicFailure"] = 381652,
				["PickPocket"] = 921,
				["Envenom"] = 32645,
				["Featherfoot"] = 423683,
				["FleetFooted"] = 378813,
				["BloodyMess"] = 381626,
				["DarkestNight"] = 457058,
				["PickLock"] = 1804,
				["EchoingReprimand"] = 385616,
				["LethalDose"] = 381640,
				["VirulentPoisons"] = 381543,
				["FlyingDaggers"] = 381631,
				["MobileBanking"] = 83958,
				["ShroudofNight"] = 457063,
				["CheapShot"] = 1833,
				["DeadlyPoison"] = 2823,
				["ScentofBlood"] = 381799,
				["TwisttheKnife"] = 381669,
				["CorrupttheBlood"] = 457066,
				["CausticSpatter"] = 421975,
				["ChosensRevelry"] = 454300,
				["CheatDeath"] = 31230,
				["Shadowrunner"] = 378807,
				["MasteryPotentAssassin"] = 76803,
				["DoubleJeopardy"] = 454430,
				["MeanStreak"] = 453428,
				["DashingScoundrel"] = 381797,
				["CuttotheChase"] = 51667,
				["HastyHearth"] = 83944,
				["SafeFall"] = 1860,
				["Sap"] = 6770,
				["Feint"] = 1966,
				["Alacrity"] = 193539,
				["ZoldyckRecipe"] = 381798,
				["KidneyShot"] = 408,
				["MomentumofDespair"] = 457067,
				["ThistleTea"] = 381623,
				["Vanish"] = 1856,
				["FollowtheBlood"] = 457068,
				["Garrote"] = 703,
				["AtrophicPoison"] = 381637,
				["BetterLivingThroughChemistry"] = 69045,
				["AmplifyingPoison"] = 381664,
				["Shiv"] = 5938,
				["TricksoftheTrade"] = 57934,
				["EdgeCase"] = 453457,
				["ViciousVenoms"] = 381634,
				["Reverberation"] = 394332,
				["SerratedBoneSpikes"] = 455352,
				["PackHobgoblin"] = 69046,
				["RapidInjection"] = 455072,
				["ImprovedPoisons"] = 381624,
				["NumbingPoison"] = 5761,
				["Ambush"] = 8676,
				["Evasion"] = 5277,
				["Mutilate"] = 1329,
				["BestDealsAnywhere"] = 69044,
				["Lethality"] = 382238,
				["BattleforAzerothPathfinder"] = 278833,
				["ArmorSkills"] = 76273,
				["IndiscriminateCarnage"] = 381802,
				["RocketBarrage"] = 69041,
				["RocketJump"] = 69070,
				["MasterPoisoner"] = 378436,
				["ColdBlood"] = 382245,
				["AirborneIrritant"] = 200733,
				["ImprovedWoundPoison"] = 319066,
				["VindicaarMatrixCrystal"] = 251463,
				["GracefulGuile"] = 423647,
				["Subterfuge"] = 108208,
				["ReviveBattlePets"] = 125439,
				["Kingsbane"] = 385627,
				["FatalIntent"] = 461980,
				["Vigor"] = 14983,
				["LingeringDarkness"] = 457056,
				["DeadlyPrecision"] = 381542,
				["ArterialPrecision"] = 400783,
				["MasterRiding"] = 90265,
				["MasterAssassin"] = 255989,
				["Deathmark"] = 360194,
				["Languages"] = 79749,
				["WithoutaTrace"] = 382513,
				["SanguineStratagem"] = 457512,
				["CleartheWitnesses"] = 457053,
				["TemptedFate"] = 454286,
				["Shadewalker"] = 457057,
				["SanguineBlades"] = 200806,
				["SliceandDice"] = 315496,
				["LeechingPoison"] = 280716,
				["Detection"] = 56814,
				["IronWire"] = 196861,
				["TimeisMoney"] = 69042,
				["Shadowheart"] = 455131,
				["CrimsonVial"] = 185311,
				["FateIntertwined"] = 454429,
				["InternalBleeding"] = 381627,
				["VenomousWounds"] = 79134,
				["AutoAttack"] = 6603,
				["Rupture"] = 1943,
				["Blindside"] = 328085,
			},
		},
		["Mage"] = {
			["Frost"] = {
				["FracturedFrost"] = 378448,
				["TomeofAntonidas"] = 382490,
				["TomeofRhonin"] = 382493,
				["ArcaneTorrent"] = 28730,
				["DivertedEnergy"] = 382270,
				["Frostbite"] = 378756,
				["SlipperySlinging"] = 444752,
				["PhantasmalImage"] = 444784,
				["SplinteringSorcery"] = 443739,
				["BrainFreeze"] = 190447,
				["MassPolymorph"] = 383121,
				["TempestBarrier"] = 382289,
				["ArcaneWarding"] = 383092,
				["BarrierDiffusion"] = 455428,
				["ArcaneAcuity"] = 154742,
				["ArcaneExplosion"] = 1449,
				["BlastWave"] = 157981,
				["TheQuickandtheDead"] = 83950,
				["IceBarrier"] = 11426,
				["AuguryAbounds"] = 443783,
				["PerpetualWinter"] = 378198,
				["Slow"] = 31589,
				["OverflowingEnergy"] = 390218,
				["SlickIce"] = 382144,
				["Wintertide"] = 378406,
				["FireBlast"] = 319836,
				["CryoFreeze"] = 382292,
				["CometStorm"] = 153595,
				["ColdestSnap"] = 417493,
				["IceFloes"] = 108839,
				["EnergizedBarriers"] = 386828,
				["ReactiveBarrier"] = 444827,
				["VolatileDetonation"] = 389627,
				["ShiftingShards"] = 444675,
				["Meltdown"] = 431131,
				["BrokenIslesPathfinder"] = 233368,
				["FrozenTouch"] = 205030,
				["IncantersFlow"] = 1463,
				["FlashFreeze"] = 379993,
				["ShiftingPower"] = 382440,
				["WintersBlessing"] = 417489,
				["ReviveBattlePets"] = 125439,
				["FreezingRain"] = 270233,
				["Cryopathy"] = 417491,
				["GuildMail"] = 83951,
				["MountUp"] = 78633,
				["WeaponSkills"] = 76298,
				["MasteryIcicles"] = 76613,
				["Reduplication"] = 382569,
				["ImprovedFrostNova"] = 343183,
				["FreezingWinds"] = 382103,
				["MassInvisibility"] = 414664,
				["GlacialSpike"] = 199786,
				["AlterTime"] = 342245,
				["IceLance"] = 30455,
				["SplittingIce"] = 56377,
				["ThermalVoid"] = 155149,
				["UnerringProficiency"] = 444974,
				["ChainReaction"] = 278309,
				["FrostfireEmpowerment"] = 431176,
				["BoneChilling"] = 205027,
				["Displacement"] = 389713,
				["LookAgain"] = 444756,
				["RemoveCurse"] = 475,
				["AccumulativeShielding"] = 382800,
				["Polymorph"] = 118,
				["ExcessFrost"] = 438600,
				["IncantationofSwiftness"] = 382293,
				["ForceofWill"] = 444719,
				["LonelyWinter"] = 205024,
				["InspiredIntellect"] = 458437,
				["Blink"] = 1953,
				["SevereTemperatures"] = 431189,
				["FlameandFrost"] = 431112,
				["DragonsBreath"] = 31661,
				["IceCold"] = 414659,
				["SpellfrostTeachings"] = 444986,
				["FlashFreezeburn"] = 431178,
				["GlacialAssault"] = 378947,
				["Shatter"] = 12982,
				["IceNova"] = 157997,
				["MasterofTime"] = 342249,
				["SplinteringCold"] = 379049,
				["HastyHearth"] = 83944,
				["ElementalAffinity"] = 431067,
				["FrostNova"] = 122,
				["SlowFall"] = 130,
				["Invisibility"] = 66,
				["ControlledInstincts"] = 444483,
				["EverlastingFrost"] = 385167,
				["ArcaneIntellect"] = 1459,
				["Counterspell"] = 2139,
				["TemporalVelocity"] = 382826,
				["TimeAnomaly"] = 383243,
				["FrostfireBolt"] = 431044,
				["DeepShatter"] = 378749,
				["Splinterstorm"] = 443742,
				["IceBlock"] = 45438,
				["IceCaller"] = 236662,
				["FrozenOrb"] = 84714,
				["MassBarrier"] = 414660,
				["IceWard"] = 205036,
				["BattleforAzerothPathfinder"] = 278833,
				["Subzero"] = 380154,
				["ColdSnap"] = 235219,
				["QuickWitted"] = 382297,
				["IsothermicCore"] = 431095,
				["FrostfireMastery"] = 431038,
				["ExcessFire"] = 438595,
				["Flurry"] = 44614,
				["FlowofTime"] = 382268,
				["Frostbolt"] = 116,
				["RingofFrost"] = 113724,
				["PiercingCold"] = 378919,
				["SplinteringRay"] = 418733,
				["ArcaneAffinity"] = 28877,
				["FrigidWinds"] = 235224,
				["TimeManipulation"] = 387807,
				["VolatileMagic"] = 444968,
				["VindicaarMatrixCrystal"] = 251463,
				["Spellsteal"] = 30449,
				["MasterRiding"] = 90265,
				["ConeofCold"] = 120,
				["SplinteringOrbs"] = 444256,
				["ThermalConditioning"] = 431117,
				["DeathsChill"] = 450331,
				["MirrorImage"] = 55342,
				["Reabsorption"] = 382820,
				["Shoot"] = 5019,
				["TimeWarp"] = 80353,
				["PermafrostLances"] = 460590,
				["IcyVeins"] = 12472,
				["Languages"] = 79748,
				["RigidIce"] = 382481,
				["TeleportationNexus"] = 223413,
				["Hailstones"] = 381244,
				["WintersProtection"] = 382424,
				["MobileBanking"] = 83958,
				["FrostfireInfusion"] = 431166,
				["ArcaneResistance"] = 822,
				["RayofFrost"] = 205021,
				["GreaterInvisibility"] = 110959,
				["ColdFront"] = 382110,
				["ArmorSkills"] = 76276,
				["ImbuedWarding"] = 431066,
				["FingersofFrost"] = 112965,
				["FreezingCold"] = 386763,
				["Shimmer"] = 212653,
				["ConjureRefreshment"] = 190336,
				["AutoAttack"] = 6603,
				["Blizzard"] = 190356,
				["Supernova"] = 157980,
			},
			["Fire"] = {
				["TomeofAntonidas"] = 382490,
				["TomeofRhonin"] = 382493,
				["ArcaneTorrent"] = 28730,
				["Rondurmancy"] = 449596,
				["CriticalMass"] = 117216,
				["DivertedEnergy"] = 382270,
				["LitFuse"] = 450716,
				["FeeltheBurn"] = 383391,
				["MassPolymorph"] = 383121,
				["TempestBarrier"] = 382289,
				["ArcaneWarding"] = 383092,
				["Hyperthermia"] = 383860,
				["Scald"] = 450746,
				["ArcaneAcuity"] = 154742,
				["ArcaneExplosion"] = 1449,
				["Fireball"] = 133,
				["WintersProtection"] = 382424,
				["ImprovedScorch"] = 383604,
				["TheQuickandtheDead"] = 83950,
				["MirrorImage"] = 55342,
				["SunKingsBlessing"] = 383886,
				["ConjureRefreshment"] = 190336,
				["GloriousIncandescence"] = 449394,
				["ThermalConditioning"] = 431117,
				["Pyrotechnics"] = 157642,
				["FireBlast"] = 319836,
				["Explosivo"] = 451757,
				["FrigidWinds"] = 235224,
				["CalloftheSunKing"] = 343222,
				["IceFloes"] = 108839,
				["Reabsorption"] = 382820,
				["InvocationArcanePhoenix"] = 448658,
				["Meltdown"] = 431131,
				["BrokenIslesPathfinder"] = 233368,
				["Pyroblast"] = 11366,
				["SunfuryExecution"] = 449349,
				["Wildfire"] = 383489,
				["IncantersFlow"] = 1463,
				["ExcessFire"] = 438595,
				["ShiftingPower"] = 382440,
				["Convection"] = 416715,
				["ReviveBattlePets"] = 125439,
				["TemporalVelocity"] = 382826,
				["GuildMail"] = 83951,
				["MountUp"] = 78633,
				["WeaponSkills"] = 76298,
				["SpellfireSpheres"] = 448601,
				["ImprovedFrostNova"] = 343183,
				["Frostbolt"] = 116,
				["IsothermicCore"] = 431095,
				["FieryRush"] = 383634,
				["Scorch"] = 2948,
				["AlterTime"] = 342245,
				["FromtheAshes"] = 342344,
				["FrostfireMastery"] = 431038,
				["FrostfireEmpowerment"] = 431176,
				["BurdenofPower"] = 451035,
				["MerelyaSetback"] = 449330,
				["Displacement"] = 389713,
				["RemoveCurse"] = 475,
				["AccumulativeShielding"] = 382800,
				["Polymorph"] = 118,
				["SavortheMoment"] = 449412,
				["IncantationofSwiftness"] = 382293,
				["DeepImpact"] = 416719,
				["SurgingBlaze"] = 343230,
				["MasterofFlame"] = 384174,
				["InspiredIntellect"] = 458437,
				["Blink"] = 1953,
				["SevereTemperatures"] = 431189,
				["TimeManipulation"] = 387807,
				["DragonsBreath"] = 31661,
				["AlexstraszasFury"] = 235870,
				["IceCold"] = 414659,
				["FlashFreezeburn"] = 431178,
				["Pyromaniac"] = 451466,
				["IceNova"] = 157997,
				["MarkoftheFireLord"] = 450325,
				["Meteor"] = 153561,
				["MassInvisibility"] = 414664,
				["ArmorSkills"] = 76276,
				["EnergizedBarriers"] = 386828,
				["CryoFreeze"] = 382292,
				["FreezingCold"] = 386763,
				["OverflowingEnergy"] = 390218,
				["BattleforAzerothPathfinder"] = 278833,
				["LessonsinDebilitation"] = 449627,
				["MasterofTime"] = 342249,
				["BlastWave"] = 157981,
				["Slow"] = 31589,
				["Firefall"] = 384033,
				["IceBlock"] = 45438,
				["HastyHearth"] = 83944,
				["SlowFall"] = 130,
				["ElementalAffinity"] = 431067,
				["FrostNova"] = 122,
				["MajestyofthePhoenix"] = 451440,
				["GreaterInvisibility"] = 110959,
				["Invisibility"] = 66,
				["FlowofTime"] = 382268,
				["SparkingCinders"] = 457728,
				["FeveredIncantation"] = 383810,
				["ArcaneIntellect"] = 1459,
				["Kindling"] = 155148,
				["HeatShimmer"] = 457735,
				["TimeAnomaly"] = 383243,
				["FrostfireBolt"] = 431044,
				["FlameAccelerant"] = 453282,
				["PhoenixFlames"] = 257541,
				["RingofFrost"] = 113724,
				["QuickWitted"] = 382297,
				["BlazingBarrier"] = 235313,
				["MasterRiding"] = 90265,
				["IceWard"] = 205036,
				["Shoot"] = 5019,
				["UnleashedInferno"] = 416506,
				["SpontaneousCombustion"] = 451875,
				["MemoryofAlar"] = 449619,
				["IntensifyingFlame"] = 416714,
				["FlamePatch"] = 205037,
				["FiresIre"] = 450831,
				["Combustion"] = 190319,
				["ExplosiveIngenuity"] = 451760,
				["GravityLapse"] = 458513,
				["Spellsteal"] = 30449,
				["Quickflame"] = 450807,
				["BlastZone"] = 451755,
				["ArcaneAffinity"] = 28877,
				["FlameandFrost"] = 431112,
				["IgnitetheFuture"] = 449558,
				["BarrierDiffusion"] = 455428,
				["VindicaarMatrixCrystal"] = 251463,
				["RigidIce"] = 382481,
				["VolatileDetonation"] = 389627,
				["ConeofCold"] = 120,
				["HotStreak"] = 195283,
				["PhoenixReborn"] = 453123,
				["ExcessFrost"] = 438600,
				["Firestarter"] = 205026,
				["MoltenFury"] = 457803,
				["MasteryIgnite"] = 12846,
				["TimeWarp"] = 80353,
				["AshenFeather"] = 450813,
				["CodexoftheSunstriders"] = 449382,
				["Languages"] = 79748,
				["Flamestrike"] = 2120,
				["TeleportationNexus"] = 223413,
				["MassBarrier"] = 414660,
				["Inflame"] = 417467,
				["Reduplication"] = 382569,
				["FerventFlickering"] = 387044,
				["ArcaneResistance"] = 822,
				["MobileBanking"] = 83958,
				["FlameOn"] = 205029,
				["FrostfireInfusion"] = 431166,
				["ManaCascade"] = 449293,
				["ImbuedWarding"] = 431066,
				["ControlledDestruction"] = 383669,
				["Cauterize"] = 86949,
				["Shimmer"] = 212653,
				["Counterspell"] = 2139,
				["AutoAttack"] = 6603,
				["ImprovedCombustion"] = 383967,
				["Supernova"] = 157980,
			},
			["Arcane"] = {
				["PresenceofMind"] = 205025,
				["TomeofAntonidas"] = 382490,
				["TomeofRhonin"] = 382493,
				["ArcaneTorrent"] = 28730,
				["CodexoftheSunstriders"] = 449382,
				["ArcaneDebilitation"] = 453598,
				["DivertedEnergy"] = 382270,
				["SlipperySlinging"] = 444752,
				["PhantasmalImage"] = 444784,
				["SplinteringSorcery"] = 443739,
				["ArcaneBlast"] = 30451,
				["MagisSpark"] = 454016,
				["MassPolymorph"] = 383121,
				["TempestBarrier"] = 382289,
				["ArcaneWarding"] = 383092,
				["BarrierDiffusion"] = 455428,
				["ArcaneAcuity"] = 154742,
				["EnergyReconstitution"] = 461457,
				["ArcaneExplosion"] = 1449,
				["BlastWave"] = 157981,
				["TheQuickandtheDead"] = 83950,
				["AuguryAbounds"] = 443783,
				["Concentration"] = 384374,
				["ConjureRefreshment"] = 190336,
				["GloriousIncandescence"] = 449394,
				["OverflowingEnergy"] = 390218,
				["Eureka"] = 452198,
				["Enlightened"] = 321387,
				["ArcaneSurge"] = 365350,
				["FireBlast"] = 319836,
				["CryoFreeze"] = 382292,
				["FrigidWinds"] = 235224,
				["IceBlock"] = 45438,
				["NetherPrecision"] = 383782,
				["IceFloes"] = 108839,
				["Reabsorption"] = 382820,
				["Amplification"] = 236628,
				["VolatileDetonation"] = 389627,
				["ShiftingShards"] = 444675,
				["Leydrinker"] = 452196,
				["BrokenIslesPathfinder"] = 233368,
				["ArcingCleave"] = 231564,
				["ArcaneBarrage"] = 44425,
				["SunfuryExecution"] = 449349,
				["ImprovedPrismaticBarrier"] = 321745,
				["Leysight"] = 452187,
				["IncantersFlow"] = 1463,
				["MassBarrier"] = 414660,
				["ShiftingPower"] = 382440,
				["Clearcasting"] = 79684,
				["ReviveBattlePets"] = 125439,
				["TemporalVelocity"] = 382826,
				["PrismaticBarrier"] = 235450,
				["HighVoltage"] = 461248,
				["MountUp"] = 78633,
				["Dematerialize"] = 461456,
				["TimeLoop"] = 452924,
				["SpellfireSpheres"] = 448601,
				["ImprovedFrostNova"] = 343183,
				["Frostbolt"] = 116,
				["MassInvisibility"] = 414664,
				["Splinterstorm"] = 443742,
				["NetherMunitions"] = 450206,
				["AlterTime"] = 342245,
				["BigBrained"] = 461261,
				["UnerringProficiency"] = 444974,
				["ConsortiumsBauble"] = 461260,
				["BurdenofPower"] = 451035,
				["ArcaneEcho"] = 342231,
				["MerelyaSetback"] = 449330,
				["Displacement"] = 389713,
				["ArcaneBombardment"] = 384581,
				["RemoveCurse"] = 475,
				["AccumulativeShielding"] = 382800,
				["Polymorph"] = 118,
				["OrbBarrage"] = 384858,
				["SavortheMoment"] = 449412,
				["IncantationofSwiftness"] = 382293,
				["AetherAttunement"] = 453600,
				["ProdigiousSavant"] = 384612,
				["RigidIce"] = 382481,
				["InspiredIntellect"] = 458437,
				["Blink"] = 1953,
				["StaticCloud"] = 461257,
				["DragonsBreath"] = 31661,
				["IceCold"] = 414659,
				["SpellfrostTeachings"] = 444986,
				["TouchoftheMagi"] = 321507,
				["SurgingUrge"] = 457521,
				["ChargedOrb"] = 384651,
				["IceNova"] = 157997,
				["ArcaneHarmony"] = 384452,
				["ArcaneMissiles"] = 5143,
				["ImprovedClearcasting"] = 321420,
				["MasterofTime"] = 342249,
				["HastyHearth"] = 83944,
				["GreaterInvisibility"] = 110959,
				["Slipstream"] = 236457,
				["SlowFall"] = 130,
				["Invisibility"] = 66,
				["ArcaneIntellect"] = 1459,
				["EnergizedFamiliar"] = 452997,
				["TimeAnomaly"] = 383243,
				["Reverberate"] = 281482,
				["ControlledInstincts"] = 444483,
				["QuickWitted"] = 382297,
				["RingofFrost"] = 113724,
				["VolatileMagic"] = 444968,
				["IceWard"] = 205036,
				["Evocation"] = 12051,
				["LessonsinDebilitation"] = 449627,
				["MobileBanking"] = 83958,
				["WeaponSkills"] = 76298,
				["ResonantOrbs"] = 461453,
				["InvocationArcanePhoenix"] = 448658,
				["ReactiveBarrier"] = 444827,
				["WintersProtection"] = 382424,
				["FlowofTime"] = 382268,
				["GravityLapse"] = 458513,
				["LookAgain"] = 444756,
				["ArcaneFamiliar"] = 205022,
				["IlluminatedThoughts"] = 384060,
				["ArcaneAffinity"] = 28877,
				["Slow"] = 31589,
				["IgnitetheFuture"] = 449558,
				["FrostNova"] = 122,
				["VindicaarMatrixCrystal"] = 251463,
				["MirrorImage"] = 55342,
				["ManaCascade"] = 449293,
				["ConeofCold"] = 120,
				["TimeManipulation"] = 387807,
				["Spellsteal"] = 30449,
				["ImprovedTouchoftheMagi"] = 453002,
				["MemoryofAlar"] = 449619,
				["TimeWarp"] = 80353,
				["Shoot"] = 5019,
				["Impetus"] = 383676,
				["MasterRiding"] = 90265,
				["SplinteringOrbs"] = 444256,
				["Languages"] = 79748,
				["Reduplication"] = 382569,
				["TeleportationNexus"] = 223413,
				["Resonance"] = 205028,
				["ForceofWill"] = 444719,
				["ConcentratedPower"] = 414379,
				["Rondurmancy"] = 449596,
				["ArcaneResistance"] = 822,
				["MasterySavant"] = 190740,
				["ArmorSkills"] = 76276,
				["BattleforAzerothPathfinder"] = 278833,
				["GuildMail"] = 83951,
				["EnergizedBarriers"] = 386828,
				["ArcaneTempo"] = 383980,
				["FreezingCold"] = 386763,
				["Shimmer"] = 212653,
				["Counterspell"] = 2139,
				["AutoAttack"] = 6603,
				["ArcaneOrb"] = 153626,
				["Supernova"] = 157980,
			},
		},
		["Demon Hunter"] = {
			["Havoc"] = {
				["SigilofFlame"] = 204596,
				["ThrilloftheFight"] = 442686,
				["ArcaneTorrent"] = 202719,
				["FelBarrage"] = 258925,
				["EssenceBreak"] = 258860,
				["CharredWarblades"] = 213010,
				["TrailofRuin"] = 258881,
				["SetFiretothePain"] = 452406,
				["IncorruptibleSpirit"] = 442736,
				["Pursuit"] = 320654,
				["UnboundChaos"] = 347461,
				["DemonicIntensity"] = 452415,
				["PursuitofAngriness"] = 452404,
				["AuraofPain"] = 207347,
				["DemonHide"] = 428241,
				["Momentum"] = 206476,
				["Darkness"] = 196718,
				["SwallowedAnger"] = 320313,
				["SpectralSight"] = 188501,
				["WaveofDebilitation"] = 452403,
				["Initiative"] = 388108,
				["BurningHatred"] = 320374,
				["VengefulBonds"] = 320635,
				["BlindFury"] = 203550,
				["UnhinderedAssault"] = 444931,
				["ThrowGlaive"] = 185123,
				["FirstBlood"] = 206416,
				["StudentofSuffering"] = 452412,
				["WoundedQuarry"] = 442806,
				["PreciseSigils"] = 389799,
				["RelentlessOnslaught"] = 389977,
				["ArtoftheGlaive"] = 442290,
				["EyeBeam"] = 198013,
				["ReviveBattlePets"] = 125439,
				["ShatteredDestiny"] = 388116,
				["Soulscar"] = 388106,
				["AldrachiDesign"] = 391409,
				["MountUp"] = 78633,
				["WeaponSkills"] = 202783,
				["ChaoticDisposition"] = 428492,
				["AFireInside"] = 427775,
				["EnduringTorment"] = 452410,
				["KnowYourEnemy"] = 388118,
				["DashofChaos"] = 427794,
				["Metamorphosis"] = 191427,
				["CollectiveAnguish"] = 390152,
				["ChaosFragments"] = 320412,
				["FlamesofFury"] = 389694,
				["SigilofSpite"] = 390163,
				["DancingwithFate"] = 389978,
				["GlaiveTempest"] = 342817,
				["InternalStruggle"] = 393822,
				["ScarsofSuffering"] = 428232,
				["BurningBlades"] = 452408,
				["InfernalArmor"] = 320331,
				["ViolentTransformation"] = 452409,
				["ErraticFelheart"] = 391397,
				["AldrachiTactics"] = 442683,
				["Inertia"] = 427640,
				["CriticalChaos"] = 320413,
				["Torment"] = 185245,
				["IsolatedPrey"] = 388113,
				["KeenEngagement"] = 442497,
				["FocusedHatred"] = 452405,
				["FuriousThrows"] = 393029,
				["PreemptiveStrike"] = 444997,
				["LooksCanKill"] = 320415,
				["MobileBanking"] = 83958,
				["MonsterRising"] = 452414,
				["ImprovedSoulRending"] = 452407,
				["ChaosStrike"] = 162794,
				["Blur"] = 198589,
				["MortalDance"] = 328725,
				["DesperateInstincts"] = 205411,
				["DemonicAppetite"] = 206478,
				["DemonsBite"] = 162243,
				["ArmorSkills"] = 202782,
				["Netherwalk"] = 196555,
				["AcceleratedBlade"] = 391275,
				["ShatteredSouls"] = 178940,
				["DemonicWards"] = 278386,
				["GuildMail"] = 83951,
				["FelEruption"] = 211881,
				["ArcaneAcuity"] = 154742,
				["SerratedGlaive"] = 390154,
				["HastyHearth"] = 83944,
				["ArmyUntoOneself"] = 442714,
				["ReaversMark"] = 442679,
				["SoulSigils"] = 395446,
				["RestlessHunter"] = 390142,
				["ChaosBrand"] = 255260,
				["FuriousGaze"] = 343311,
				["ChampionoftheGlaive"] = 429211,
				["SoulRending"] = 204909,
				["ImmolationAura"] = 258920,
				["TheQuickandtheDead"] = 83950,
				["IncisiveBlade"] = 442492,
				["Flamebound"] = 452413,
				["ImprovedDisrupt"] = 320361,
				["ShatteredRestoration"] = 389824,
				["FelfireHaste"] = 389846,
				["ArcaneResistance"] = 822,
				["VengefulRetreat"] = 198793,
				["FelRush"] = 195072,
				["BattleforAzerothPathfinder"] = 278833,
				["CycleofHatred"] = 258887,
				["ImprovedSigilofMisery"] = 320418,
				["InsatiableHunger"] = 258876,
				["PitchBlack"] = 389783,
				["GrowingInferno"] = 390158,
				["TacticalRetreat"] = 389688,
				["BladeDance"] = 188499,
				["BurningWound"] = 391189,
				["LongNight"] = 389781,
				["IllidariKnowledge"] = 389696,
				["BrokenIslesPathfinder"] = 233368,
				["Glide"] = 131347,
				["ArcaneAffinity"] = 28877,
				["QuickenedSigils"] = 209281,
				["WarbladesHunger"] = 442502,
				["RushofChaos"] = 320421,
				["DemonBlades"] = 203555,
				["LivebytheGlaive"] = 428607,
				["Felblade"] = 232893,
				["VindicaarMatrixCrystal"] = 251463,
				["ChaosTheory"] = 389687,
				["LostinDarkness"] = 389849,
				["DisruptingFury"] = 183782,
				["MasteryDemonicPresence"] = 185164,
				["DemonMuzzle"] = 388111,
				["Demonsurge"] = 452402,
				["ChaoticTransformation"] = 388112,
				["MasteroftheGlaive"] = 389763,
				["BouncingGlaives"] = 320386,
				["MasterRiding"] = 90265,
				["EvasiveAction"] = 444926,
				["SigilofMisery"] = 207684,
				["Languages"] = 79748,
				["AnyMeansNecessary"] = 388114,
				["UntetheredFury"] = 452411,
				["WilloftheIllidari"] = 389695,
				["UnrestrainedFury"] = 320770,
				["FuryoftheAldrachi"] = 442718,
				["ChaosNova"] = 179057,
				["Demonic"] = 213410,
				["ImprovedChaosStrike"] = 343206,
				["InnerDemon"] = 389693,
				["ConsumeMagic"] = 278326,
				["ImprovedFelRush"] = 343017,
				["Ragefire"] = 388107,
				["Disrupt"] = 183752,
				["Imprison"] = 217832,
				["BlazingPath"] = 320416,
				["TheHunt"] = 370965,
				["AutoAttack"] = 6603,
				["DoubleJump"] = 196055,
				["DeflectingDance"] = 427776,
			},
			["Vengeance"] = {
				["SigilofFlame"] = 204596,
				["ThrilloftheFight"] = 442686,
				["ArcaneTorrent"] = 202719,
				["IlluminatedSigils"] = 428557,
				["PitchBlack"] = 389783,
				["PerfectlyBalancedGlaive"] = 320387,
				["Shear"] = 203782,
				["SetFiretothePain"] = 452406,
				["IncorruptibleSpirit"] = 442736,
				["Pursuit"] = 320654,
				["ChainsofAnger"] = 389715,
				["DemonicIntensity"] = 452415,
				["PursuitofAngriness"] = 452404,
				["FieryDemise"] = 389220,
				["FelDevastation"] = 212084,
				["StoketheFlames"] = 393827,
				["AuraofPain"] = 207347,
				["Darkness"] = 196718,
				["ShearFury"] = 389997,
				["AscendingFlame"] = 428603,
				["SwallowedAnger"] = 320313,
				["SigilofSilence"] = 202137,
				["WaveofDebilitation"] = 452403,
				["Disrupt"] = 183752,
				["VengefulBonds"] = 320635,
				["CalcifiedSpikes"] = 389720,
				["Soulmonger"] = 389711,
				["UnhinderedAssault"] = 444931,
				["MeteoricStrikes"] = 389724,
				["ThrowGlaive"] = 204157,
				["DisruptingFury"] = 183782,
				["MasteryFelBlood"] = 203747,
				["StudentofSuffering"] = 452412,
				["WoundedQuarry"] = 442806,
				["PreciseSigils"] = 389799,
				["SoulFurnace"] = 391165,
				["BurningAlive"] = 207739,
				["TheHunt"] = 370965,
				["FocusedCleave"] = 343207,
				["ReviveBattlePets"] = 125439,
				["AgonizingFlames"] = 207548,
				["AldrachiDesign"] = 391409,
				["VoidReaver"] = 268175,
				["MountUp"] = 78633,
				["WeaponSkills"] = 202783,
				["EnduringTorment"] = 452410,
				["SoulCleave"] = 228477,
				["Metamorphosis"] = 187827,
				["CollectiveAnguish"] = 390152,
				["RoaringFire"] = 391178,
				["FlamesofFury"] = 389694,
				["SigilofSpite"] = 390163,
				["Frailty"] = 389958,
				["InternalStruggle"] = 393822,
				["BurningBlades"] = 452408,
				["RuinousBulwark"] = 326853,
				["ViolentTransformation"] = 452409,
				["ErraticFelheart"] = 391397,
				["AldrachiTactics"] = 442683,
				["InfernalStrike"] = 189110,
				["Torment"] = 185245,
				["Fracture"] = 263642,
				["KeenEngagement"] = 442497,
				["FocusedHatred"] = 452405,
				["UntetheredFury"] = 452411,
				["PreemptiveStrike"] = 444997,
				["SoulCarver"] = 207407,
				["MonsterRising"] = 452414,
				["VolatileFlameblood"] = 390808,
				["DemonMuzzle"] = 388111,
				["ArmorSkills"] = 202782,
				["ImprovedDisrupt"] = 320361,
				["LastResort"] = 209258,
				["SpectralSight"] = 188501,
				["DemonicWards"] = 203513,
				["FeastofSouls"] = 207697,
				["BurningBlood"] = 390213,
				["Retaliation"] = 389729,
				["DarkglareBoon"] = 389708,
				["TheQuickandtheDead"] = 83950,
				["ThickSkin"] = 320380,
				["Painbringer"] = 207387,
				["ArmyUntoOneself"] = 442714,
				["ReaversMark"] = 442679,
				["SigilofChains"] = 202138,
				["ImmolationAura"] = 258920,
				["ChaosBrand"] = 255260,
				["DowninFlames"] = 389732,
				["ChampionoftheGlaive"] = 429211,
				["SoulRending"] = 204909,
				["ConsumeMagic"] = 278326,
				["DemonSpikes"] = 203720,
				["IncisiveBlade"] = 442492,
				["Flamebound"] = 452413,
				["HastyHearth"] = 83944,
				["FelfireHaste"] = 389846,
				["ArcaneResistance"] = 822,
				["SoulBarrier"] = 263648,
				["VengefulRetreat"] = 198793,
				["BrokenIslesPathfinder"] = 233368,
				["ImprovedSigilofMisery"] = 320418,
				["Vulnerability"] = 389976,
				["Soulcrush"] = 389985,
				["FieryBrand"] = 204021,
				["EvasiveAction"] = 444926,
				["ImprovedSoulRending"] = 452407,
				["BouncingGlaives"] = 320386,
				["ArcaneAcuity"] = 154742,
				["Glide"] = 131347,
				["LongNight"] = 389781,
				["IllidariKnowledge"] = 389696,
				["BulkExtraction"] = 320341,
				["MasteroftheGlaive"] = 389763,
				["ArcaneAffinity"] = 28877,
				["QuickenedSigils"] = 209281,
				["ExtendedSpikes"] = 389721,
				["RushofChaos"] = 320421,
				["ChaosFragments"] = 320412,
				["LivebytheGlaive"] = 428607,
				["Felblade"] = 232893,
				["VindicaarMatrixCrystal"] = 251463,
				["InfernalArmor"] = 320331,
				["LostinDarkness"] = 389849,
				["CycleofBinding"] = 389718,
				["Demonsurge"] = 452402,
				["ArtoftheGlaive"] = 442290,
				["SpiritBomb"] = 247454,
				["WarbladesHunger"] = 442502,
				["Fallout"] = 227174,
				["DeflectingSpikes"] = 321028,
				["MasterRiding"] = 90265,
				["FelFlameFortification"] = 389705,
				["GuildMail"] = 83951,
				["Languages"] = 79748,
				["MobileBanking"] = 83958,
				["FeedtheDemon"] = 218612,
				["WilloftheIllidari"] = 389695,
				["UnrestrainedFury"] = 320770,
				["RevelinPain"] = 343014,
				["ChaosNova"] = 179057,
				["Demonic"] = 213410,
				["ShatteredRestoration"] = 389824,
				["CharredWarblades"] = 213010,
				["SigilofMisery"] = 207684,
				["BattleforAzerothPathfinder"] = 278833,
				["SoulSigils"] = 395446,
				["FuryoftheAldrachi"] = 442718,
				["BlazingPath"] = 320416,
				["CharredFlesh"] = 336639,
				["Imprison"] = 217832,
				["AutoAttack"] = 6603,
				["DoubleJump"] = 196055,
				["ShatteredSouls"] = 204254,
			},
		},
		["Warlock"] = {
			["Demonology"] = {
				["SataielsVolition"] = 449637,
				["UnendingBreath"] = 5697,
				["ArcaneTorrent"] = 28730,
				["SoulLeech"] = 108370,
				["Doom"] = 460551,
				["CallDreadstalkers"] = 104316,
				["CarnivorousStalkers"] = 386194,
				["RitualofDoom"] = 342601,
				["SubjugateDemon"] = 1098,
				["ArcaneAcuity"] = 154742,
				["SoulEtchedCircles"] = 428911,
				["Shadowtouched"] = 453619,
				["AmplifyCurse"] = 328774,
				["AnnihilanTraining"] = 386174,
				["ImmutableHatred"] = 405670,
				["Guillotine"] = 386833,
				["WickedReaping"] = 449631,
				["SoulAnathema"] = 449624,
				["FriendsInDarkPlaces"] = 449703,
				["AbyssalDominion"] = 429581,
				["WickedMaw"] = 267170,
				["EternalServitude"] = 449707,
				["FelSynergy"] = 389367,
				["DemonicInspiration"] = 386858,
				["TouchofRancora"] = 429893,
				["SwiftArtifice"] = 452902,
				["FrequentDonor"] = 386686,
				["BattleforAzerothPathfinder"] = 278833,
				["GoreboundFortitude"] = 449701,
				["DiabolicRitual"] = 428514,
				["FelSunder"] = 387399,
				["DemonicCircle"] = 268358,
				["ShadowofDeath"] = 449638,
				["FiendishStride"] = 386110,
				["ReviveBattlePets"] = 125439,
				["MasteryMasterDemonologist"] = 77219,
				["InfernalMachine"] = 429917,
				["DemonicFortitude"] = 386617,
				["MountUp"] = 78633,
				["WeaponSkills"] = 76299,
				["CurseofTongues"] = 1714,
				["DarkPact"] = 108416,
				["HandofGuldan"] = 105174,
				["AnnihilansBellow"] = 429072,
				["GrimoireFelguard"] = 111898,
				["InfernalBulwark"] = 429130,
				["HealthFunnel"] = 755,
				["ClovenSouls"] = 428517,
				["AbyssWalker"] = 389609,
				["RitualofSummoning"] = 698,
				["PactoftheImpMother"] = 387541,
				["NaturesSplendor"] = 320668,
				["FoulMouth"] = 455502,
				["TeachingsoftheBlackHarvest"] = 385881,
				["SargereiTechnique"] = 405955,
				["NecrolyteTeachings"] = 449620,
				["Shadowflame"] = 384069,
				["Demoniac"] = 426115,
				["ImpGangBoss"] = 387445,
				["SharedFate"] = 449704,
				["TheCodexofXerrath"] = 101508,
				["WrathfulMinion"] = 386864,
				["ReignofTyranny"] = 427684,
				["BloodInvocation"] = 455576,
				["SoulLink"] = 108415,
				["MobileBanking"] = 83958,
				["MarkofFharg"] = 455450,
				["DemonicResilience"] = 389590,
				["FelInvocation"] = 428351,
				["MarkofShatug"] = 455449,
				["CursesofEnfeeblement"] = 386105,
				["SoulShards"] = 246985,
				["InfernalVitality"] = 429115,
				["InnerDemons"] = 267216,
				["ArmorSkills"] = 76277,
				["BilescourgeBombers"] = 267211,
				["DemonicEmbrace"] = 288843,
				["DemonicBrutality"] = 453908,
				["GroveInvigoration"] = 322721,
				["SummonDemonicTyrant"] = 265187,
				["AutoAttack"] = 6603,
				["SoulConduit"] = 215941,
				["DemonicSoul"] = 449614,
				["FelDomination"] = 333889,
				["DreadCalling"] = 387391,
				["ShadowBolt"] = 686,
				["Fear"] = 5782,
				["TheHoundmastersGambit"] = 455572,
				["EyeofKilrogg"] = 126,
				["SummonVilefiend"] = 264119,
				["HastyHearth"] = 83944,
				["Ruination"] = 428522,
				["CurseofWeakness"] = 702,
				["Corruption"] = 172,
				["StrengthofWill"] = 317138,
				["GuildMail"] = 83951,
				["UmbralBlaze"] = 405798,
				["DoomEternal"] = 455585,
				["ShadowInvocation"] = 422054,
				["BrokenIslesPathfinder"] = 233368,
				["DemonicTactics"] = 452894,
				["GloomofNathreza"] = 429899,
				["Quietus"] = 449634,
				["Soulburn"] = 385899,
				["SweetSouls"] = 386620,
				["IchorofDevils"] = 386664,
				["DemoniacsFervor"] = 449629,
				["AccruedVitality"] = 386613,
				["Implosion"] = 196277,
				["HowlofTerror"] = 5484,
				["Horrify"] = 56244,
				["CreateSoulwell"] = 29893,
				["RuneofShadows"] = 453744,
				["TheExpendables"] = 387600,
				["PowerSiphon"] = 264130,
				["DemonSkin"] = 219272,
				["CurseofExhaustion"] = 334275,
				["ResoluteBarrier"] = 389359,
				["SocretharsGuile"] = 405936,
				["Banish"] = 710,
				["Dreadlash"] = 264078,
				["TeachingsoftheSatyr"] = 387972,
				["SacrificedSouls"] = 267214,
				["DemonicCalling"] = 205145,
				["PactofGluttony"] = 386689,
				["ArcaneAffinity"] = 28877,
				["ImpendingDoom"] = 455587,
				["CreateHealthstone"] = 6201,
				["GorefiendsResolve"] = 389623,
				["VindicaarMatrixCrystal"] = 251463,
				["Shadowfury"] = 30283,
				["Nightmare"] = 386648,
				["MortalCoil"] = 6789,
				["Darkfury"] = 264874,
				["Flametouched"] = 453699,
				["PactoftheEredruin"] = 453568,
				["Lifeblood"] = 386646,
				["Imperator"] = 416230,
				["Shoot"] = 5019,
				["MasterRiding"] = 90265,
				["FlamesofXoroth"] = 429657,
				["SpellLock"] = 119910,
				["Languages"] = 79748,
				["FelPact"] = 386113,
				["CrueltyofKerxan"] = 429902,
				["SecretsoftheCoven"] = 428518,
				["DemonicGateway"] = 111771,
				["ImprovedDemonicTactics"] = 453800,
				["FiendishOblation"] = 455569,
				["ArcaneResistance"] = 822,
				["SpitefulReconstitution"] = 428394,
				["DrainLife"] = 234153,
				["TheQuickandtheDead"] = 83950,
				["SoulStrike"] = 428344,
				["DarkAccord"] = 386659,
				["FeastofSouls"] = 449706,
				["BurningRush"] = 111400,
				["DemonicStrength"] = 267171,
				["UnendingResolve"] = 104773,
				["AntoranArmaments"] = 387494,
				["FelArmor"] = 386124,
				["Soulstone"] = 20707,
			},
			["Destruction"] = {
				["Pyrogenics"] = 387095,
				["Soulstone"] = 20707,
				["UnendingBreath"] = 5697,
				["ArcaneTorrent"] = 28730,
				["Decimation"] = 456985,
				["IllhoofsDesign"] = 440070,
				["XalansFerocity"] = 440044,
				["Horrify"] = 56244,
				["MarkofXavius"] = 440046,
				["Inferno"] = 270545,
				["SubjugateDemon"] = 1098,
				["Shadowburn"] = 17877,
				["Cataclysm"] = 152108,
				["ArcaneAcuity"] = 154742,
				["SoulEtchedCircles"] = 428911,
				["MortalCoil"] = 6789,
				["AmplifyCurse"] = 328774,
				["Darkfury"] = 264874,
				["TheQuickandtheDead"] = 83950,
				["DemonSkin"] = 219272,
				["MasteryChaoticEnergies"] = 77220,
				["RoaringBlaze"] = 205184,
				["AbyssalDominion"] = 429581,
				["FelSynergy"] = 389367,
				["DemonicInspiration"] = 386858,
				["TouchofRancora"] = 429893,
				["Havoc"] = 80240,
				["SwiftArtifice"] = 452902,
				["FrequentDonor"] = 386686,
				["BattleforAzerothPathfinder"] = 278833,
				["ChaosBolt"] = 116858,
				["DrainLife"] = 234153,
				["DiabolicRitual"] = 428514,
				["DemonicCircle"] = 268358,
				["FiendishStride"] = 386110,
				["ReviveBattlePets"] = 125439,
				["InfernalMachine"] = 429917,
				["DemonicFortitude"] = 386617,
				["MasterRitualist"] = 387165,
				["WeaponSkills"] = 76299,
				["FiendishCruelty"] = 456943,
				["ChannelDemonfire"] = 196447,
				["InternalCombustion"] = 266134,
				["Flashpoint"] = 387259,
				["CrashingChaos"] = 417234,
				["ChaosIncarnate"] = 387275,
				["Conflagrate"] = 17962,
				["AuraofEnfeeblement"] = 440059,
				["DimensionalRift"] = 387976,
				["InfernalBulwark"] = 429130,
				["HealthFunnel"] = 755,
				["ClovenSouls"] = 428517,
				["AbyssWalker"] = 389609,
				["RitualofSummoning"] = 698,
				["Backlash"] = 387384,
				["RainofChaos"] = 266086,
				["AshenRemains"] = 387252,
				["TeachingsoftheBlackHarvest"] = 385881,
				["SargereiTechnique"] = 405955,
				["FlamesofXoroth"] = 429657,
				["IndiscriminateFlames"] = 457114,
				["Malevolence"] = 442726,
				["Backdraft"] = 196406,
				["Emberstorm"] = 454744,
				["TheCodexofXerrath"] = 101508,
				["GrimoireofSacrifice"] = 108503,
				["SummonInfernal"] = 1122,
				["ScaldingFlames"] = 388832,
				["WrathfulMinion"] = 386864,
				["BleakheartTactics"] = 440051,
				["DemonfireMastery"] = 456946,
				["SoulLink"] = 108415,
				["MobileBanking"] = 83958,
				["PactofGluttony"] = 386689,
				["DemonicResilience"] = 389590,
				["RagingDemonfire"] = 387166,
				["RollingHavoc"] = 387569,
				["CursesofEnfeeblement"] = 386105,
				["ImprovedConflagrate"] = 231793,
				["BlisteringAtrophy"] = 456939,
				["InfernalVitality"] = 429115,
				["SummonersEmbrace"] = 453105,
				["ArmorSkills"] = 76277,
				["DemonicEmbrace"] = 288843,
				["HowlofTerror"] = 5484,
				["SoulConduit"] = 215941,
				["RainofFire"] = 5740,
				["Mayhem"] = 387506,
				["PowerOverwhelming"] = 387279,
				["SoulShards"] = 246985,
				["Fear"] = 5782,
				["HastyHearth"] = 83944,
				["Ruination"] = 428522,
				["CommandDemon"] = 119898,
				["ZevrimsResilience"] = 440065,
				["StrengthofWill"] = 317138,
				["UnendingResolve"] = 104773,
				["CurseoftheSatyr"] = 440057,
				["DemonicTactics"] = 452894,
				["Immolate"] = 348,
				["CurseofWeakness"] = 702,
				["EyeofKilrogg"] = 126,
				["GloomofNathreza"] = 429899,
				["XalansCruelty"] = 440040,
				["MarkofPerotharn"] = 440045,
				["SweetSouls"] = 386620,
				["IchorofDevils"] = 386664,
				["ImprovedChaosBolt"] = 456951,
				["CurseofTongues"] = 1714,
				["GuildMail"] = 83951,
				["Incinerate"] = 29722,
				["MountUp"] = 78633,
				["CreateSoulwell"] = 29893,
				["Shadowflame"] = 384069,
				["BrokenIslesPathfinder"] = 233368,
				["RitualofRuin"] = 387156,
				["SocretharsGuile"] = 405936,
				["CurseofExhaustion"] = 334275,
				["BurntoAshes"] = 387153,
				["ResoluteBarrier"] = 389359,
				["Banish"] = 710,
				["Soulburn"] = 385899,
				["TeachingsoftheSatyr"] = 387972,
				["DiabolicEmbers"] = 387173,
				["Devastation"] = 454735,
				["ExplosivePotential"] = 388827,
				["ArcaneAffinity"] = 28877,
				["AvatarofDestruction"] = 456975,
				["UnstableRifts"] = 457064,
				["MasterRiding"] = 90265,
				["VindicaarMatrixCrystal"] = 251463,
				["CreateHealthstone"] = 6201,
				["Shadowfury"] = 30283,
				["ReverseEntropy"] = 205148,
				["Eradication"] = 196412,
				["Ruin"] = 387103,
				["DimensionRipper"] = 457025,
				["Lifeblood"] = 386646,
				["AccruedVitality"] = 386613,
				["Shoot"] = 5019,
				["ConflagrationofChaos"] = 387108,
				["Nightmare"] = 386648,
				["SoulFire"] = 6353,
				["Languages"] = 79748,
				["SoulLeech"] = 108370,
				["CrueltyofKerxan"] = 429902,
				["SecretsoftheCoven"] = 428518,
				["DemonicGateway"] = 111771,
				["SeedsofTheirDemise"] = 440055,
				["FelDomination"] = 333889,
				["ArcaneResistance"] = 822,
				["BurningRush"] = 111400,
				["HatefuryRituals"] = 440048,
				["AnnihilansBellow"] = 429072,
				["FelPact"] = 386113,
				["DarkAccord"] = 386659,
				["FireandBrimstone"] = 196408,
				["BlackenedSoul"] = 440043,
				["DarkPact"] = 108416,
				["Wither"] = 445465,
				["AutoAttack"] = 6603,
				["FelArmor"] = 386124,
				["RitualofDoom"] = 342601,
			},
			["Affliction"] = {
				["SataielsVolition"] = 449637,
				["UnendingBreath"] = 5697,
				["ArcaneTorrent"] = 28730,
				["SoulLeech"] = 108370,
				["XalansFerocity"] = 440044,
				["Horrify"] = 56244,
				["MarkofXavius"] = 440046,
				["RitualofDoom"] = 342601,
				["SacrolashsDarkStrike"] = 386986,
				["AbsoluteCorruption"] = 196103,
				["RavenousAfflictions"] = 459440,
				["Oblivion"] = 417537,
				["SubjugateDemon"] = 1098,
				["ArcaneAcuity"] = 154742,
				["MortalCoil"] = 6789,
				["PhantomSingularity"] = 205179,
				["AmplifyCurse"] = 328774,
				["Darkfury"] = 264874,
				["TheQuickandtheDead"] = 83950,
				["DemonSkin"] = 219272,
				["WickedReaping"] = 449631,
				["WildHuntStrategem"] = 352805,
				["SoulAnathema"] = 449624,
				["FriendsInDarkPlaces"] = 449703,
				["Fear"] = 5782,
				["EternalServitude"] = 449707,
				["FelSynergy"] = 389367,
				["DemonicInspiration"] = 386858,
				["SwiftArtifice"] = 452902,
				["FrequentDonor"] = 386686,
				["Nightfall"] = 108558,
				["GoreboundFortitude"] = 449701,
				["UnstableAffliction"] = 316099,
				["Relinquished"] = 453083,
				["VolatileAgony"] = 453034,
				["Haunt"] = 48181,
				["ShadowofDeath"] = 449638,
				["FiendishStride"] = 386110,
				["ShadowEmbrace"] = 32388,
				["SeedofCorruption"] = 27243,
				["ReviveBattlePets"] = 125439,
				["XavianTeachings"] = 317031,
				["SoulRot"] = 386997,
				["MaleficTouch"] = 458029,
				["GuildMail"] = 83951,
				["FeastofSouls"] = 449706,
				["MountUp"] = 78633,
				["WeaponSkills"] = 76299,
				["CurseofTongues"] = 1714,
				["DarkPact"] = 108416,
				["FocusedMalignancy"] = 399668,
				["MalevolentVisionary"] = 387273,
				["XalansCruelty"] = 440040,
				["XaviusGambit"] = 416615,
				["SiphonLife"] = 452999,
				["AuraofEnfeeblement"] = 440059,
				["HealthFunnel"] = 755,
				["AbyssWalker"] = 389609,
				["RitualofSummoning"] = 698,
				["MalignOmen"] = 458041,
				["SummonDarkglare"] = 205180,
				["TeachingsoftheBlackHarvest"] = 385881,
				["SargereiTechnique"] = 405955,
				["NecrolyteTeachings"] = 449620,
				["Shadowflame"] = 384069,
				["Malevolence"] = 442726,
				["KindledMalice"] = 405330,
				["SharedFate"] = 449704,
				["TheCodexofXerrath"] = 101508,
				["GrimoireofSacrifice"] = 108503,
				["WrathfulMinion"] = 386864,
				["BleakheartTactics"] = 440051,
				["SoulLink"] = 108415,
				["MobileBanking"] = 83958,
				["PactofGluttony"] = 386689,
				["DemonicResilience"] = 389590,
				["CursesofEnfeeblement"] = 386105,
				["WitheringBolt"] = 386976,
				["HatefuryRituals"] = 440048,
				["SummonersEmbrace"] = 453105,
				["ArmorSkills"] = 76277,
				["DemonicEmbrace"] = 288843,
				["ImprovedHaunt"] = 458034,
				["SoulConduit"] = 215941,
				["DemonicSoul"] = 449614,
				["FelDomination"] = 333889,
				["HastyHearth"] = 83944,
				["MasteryPotentAfflictions"] = 77215,
				["Agony"] = 980,
				["ZevrimsResilience"] = 440065,
				["Malediction"] = 453087,
				["BurningRush"] = 111400,
				["CurseoftheSatyr"] = 440057,
				["DemonicTactics"] = 452894,
				["UnendingResolve"] = 104773,
				["DeathsEmbrace"] = 453189,
				["SoulShards"] = 246985,
				["Infirmity"] = 458036,
				["Quietus"] = 449634,
				["MarkofPerotharn"] = 440045,
				["SweetSouls"] = 386620,
				["IchorofDevils"] = 386664,
				["Soulstone"] = 20707,
				["CulltheWeak"] = 453056,
				["EyeofKilrogg"] = 126,
				["CreepingDeath"] = 264000,
				["WritheinAgony"] = 196102,
				["CreateSoulwell"] = 29893,
				["DrainLife"] = 234153,
				["CurseofWeakness"] = 702,
				["Corruption"] = 172,
				["Contagion"] = 453096,
				["CurseofExhaustion"] = 334275,
				["ArcaneResistance"] = 822,
				["SocretharsGuile"] = 405936,
				["Banish"] = 710,
				["Soulburn"] = 385899,
				["TeachingsoftheSatyr"] = 387972,
				["StrengthofWill"] = 317138,
				["DemoniacsFervor"] = 449629,
				["BrokenIslesPathfinder"] = 233368,
				["ArcaneAffinity"] = 28877,
				["BattleforAzerothPathfinder"] = 278833,
				["CreateHealthstone"] = 6201,
				["GorefiendsResolve"] = 389623,
				["VindicaarMatrixCrystal"] = 251463,
				["Nightmare"] = 386648,
				["Shadowfury"] = 30283,
				["DarkHarvest"] = 387016,
				["AccruedVitality"] = 386613,
				["MasterRiding"] = 90265,
				["PerpetualUnstability"] = 459376,
				["Lifeblood"] = 386646,
				["VileTaint"] = 278350,
				["Shoot"] = 5019,
				["CunningCruelty"] = 453172,
				["HowlofTerror"] = 5484,
				["ImprovedShadowBolt"] = 453080,
				["Languages"] = 79748,
				["SpellLock"] = 119910,
				["IllhoofsDesign"] = 440070,
				["DemonicCircle"] = 268358,
				["DemonicGateway"] = 111771,
				["SeedsofTheirDemise"] = 440055,
				["ImprovedMaleficRapture"] = 454378,
				["TormentedCrescendo"] = 387075,
				["ResoluteBarrier"] = 389359,
				["DrainSoul"] = 388667,
				["DarkVirtuosity"] = 405327,
				["FelPact"] = 386113,
				["DarkAccord"] = 386659,
				["ShadowBolt"] = 686,
				["BlackenedSoul"] = 440043,
				["DemonicFortitude"] = 386617,
				["Wither"] = 445465,
				["AutoAttack"] = 6603,
				["FelArmor"] = 386124,
				["MaleficRapture"] = 324536,
			},
		},
		["Druid"] = {
			["Feral"] = {
				["NurturingInstinct"] = 33873,
				["MightyBash"] = 5211,
				["InstinctsoftheClaw"] = 449184,
				["SouloftheForest"] = 158476,
				["ImprovedBarkskin"] = 327993,
				["UrsineVigor"] = 377842,
				["AdaptiveSwarm"] = 391888,
				["Sabertooth"] = 202031,
				["Hibernate"] = 2637,
				["Ravage"] = 441583,
				["PacksEndurance"] = 441844,
				["Predator"] = 202021,
				["HeartoftheWild"] = 319454,
				["DreadfulWound"] = 441809,
				["Thrash"] = 106832,
				["BurstingGrowth"] = 440120,
				["Cyclone"] = 33786,
				["SkullBash"] = 106839,
				["FluidForm"] = 449193,
				["AstralInfluence"] = 197524,
				["AggravateWounds"] = 441829,
				["FlightForm"] = 276029,
				["WildCharge"] = 102401,
				["RagingFury"] = 391078,
				["CoiledtoSpring"] = 449537,
				["RemoveCorruption"] = 2782,
				["AquaticForm"] = 276012,
				["Maim"] = 22570,
				["Berserk"] = 106951,
				["Starsurge"] = 197626,
				["BrutalSlash"] = 202028,
				["VerdantHeart"] = 301768,
				["Sunfire"] = 93402,
				["TirelessEnergy"] = 383352,
				["IncapacitatingRoar"] = 99,
				["WarStomp"] = 20549,
				["SaberJaws"] = 421432,
				["BrokenIslesPathfinder"] = 233368,
				["LionsStrength"] = 391972,
				["MattedFur"] = 385786,
				["RampantFerocity"] = 391709,
				["StampedingRoar"] = 106898,
				["UnbridledSwarm"] = 391951,
				["UrsocsSpirit"] = 449182,
				["AshamanesGuidance"] = 391548,
				["ThrivingGrowth"] = 439528,
				["ReviveBattlePets"] = 125439,
				["TigerDash"] = 252216,
				["EntanglingVortex"] = 439895,
				["Veinripper"] = 391978,
				["GuildMail"] = 83951,
				["Implant"] = 440118,
				["BestialStrength"] = 441841,
				["SurvivalInstincts"] = 61336,
				["StrikefortheHeart"] = 441845,
				["ThickHide"] = 16931,
				["TwinSprouts"] = 440117,
				["EmpoweredShapeshifting"] = 441689,
				["LunarInspiration"] = 155580,
				["Bloodtalons"] = 319439,
				["KillingStrikes"] = 441824,
				["WellHonedInstincts"] = 377847,
				["Moonfire"] = 8921,
				["LycarasTeachings"] = 378988,
				["NaturesSplendor"] = 320668,
				["Innervate"] = 29166,
				["FlowerWalk"] = 439901,
				["TravelForm"] = 783,
				["Oakskin"] = 449191,
				["Endurance"] = 20550,
				["Mangle"] = 33917,
				["WildGrowth"] = 48438,
				["FranticMomentum"] = 391875,
				["RipandTear"] = 391347,
				["HuntBeneaththeOpenSkies"] = 439868,
				["ImprovedSunfire"] = 231050,
				["MassEntanglement"] = 102359,
				["CircleofLifeandDeath"] = 400320,
				["ClawRampage"] = 441835,
				["UrsolsVortex"] = 102793,
				["MobileBanking"] = 83958,
				["PouncingStrikes"] = 390772,
				["FelineSwiftness"] = 131768,
				["Regrowth"] = 8936,
				["PredatorySwiftness"] = 16974,
				["ResilientFlourishing"] = 439880,
				["ArmorSkills"] = 76275,
				["BattleforAzerothPathfinder"] = 278833,
				["BerserkHeartoftheLion"] = 391174,
				["Brawn"] = 154743,
				["BerserkFrenzy"] = 384668,
				["RootNetwork"] = 439882,
				["Revive"] = 50769,
				["FelineAdept"] = 300349,
				["SuddenAmbush"] = 384667,
				["MomentofClarity"] = 236068,
				["Rake"] = 1822,
				["Rip"] = 1079,
				["ApexPredatorsCraving"] = 391881,
				["NatureResistance"] = 20551,
				["Typhoon"] = 132469,
				["Barkskin"] = 22812,
				["HastyHearth"] = 83944,
				["ImprovedStampedingRoar"] = 288826,
				["Wrath"] = 5176,
				["ThrashingClaws"] = 405300,
				["Dreamwalk"] = 193753,
				["Rejuvenation"] = 774,
				["CharmWoodlandCreature"] = 127757,
				["DoubleClawedRake"] = 391700,
				["Soothe"] = 2908,
				["CarnivorousInstinct"] = 390902,
				["FountofStrength"] = 441675,
				["FrenziedRegeneration"] = 22842,
				["PrimalWrath"] = 285381,
				["WeaponSkills"] = 76300,
				["TigersTenacity"] = 391872,
				["Swipe"] = 213764,
				["MountUp"] = 78633,
				["SavageFury"] = 449645,
				["LethalPreservation"] = 455461,
				["BondwithNature"] = 439929,
				["FeralInstinct"] = 16949,
				["GroveInvigoration"] = 322721,
				["Shred"] = 5221,
				["VigorousCreepers"] = 440119,
				["EntanglingRoots"] = 339,
				["NaturalRecovery"] = 377796,
				["IncarnationAvatarofAshamane"] = 102543,
				["DreadfulBleeding"] = 391045,
				["KillerInstinct"] = 108299,
				["FerociousBite"] = 22568,
				["Rebirth"] = 20484,
				["Forestwalk"] = 400129,
				["RuthlessAggression"] = 441814,
				["TigersFury"] = 5217,
				["Ironfur"] = 192081,
				["Starfire"] = 197628,
				["PrimalFury"] = 159286,
				["NaturesVigil"] = 124974,
				["WildshapeMastery"] = 441678,
				["InfectedWounds"] = 48484,
				["RisingLightFallingNight"] = 417712,
				["TasteforBlood"] = 384665,
				["Prowl"] = 5215,
				["VindicaarMatrixCrystal"] = 251463,
				["WildpowerSurge"] = 441691,
				["StrategicInfusion"] = 439890,
				["BearForm"] = 5487,
				["LoreoftheGrove"] = 449185,
				["Growl"] = 6795,
				["MasterRiding"] = 90265,
				["StarlightConduit"] = 451211,
				["Cultivation"] = 20552,
				["Languages"] = 79746,
				["ConvoketheSpirits"] = 391528,
				["HarmoniousConstitution"] = 440116,
				["OmenofClarity"] = 16864,
				["TheQuickandtheDead"] = 83950,
				["WildSlashes"] = 390864,
				["TreantForm"] = 114282,
				["MercilessClaws"] = 231063,
				["CatForm"] = 768,
				["ImprovedRejuvenation"] = 231040,
				["Flap"] = 164862,
				["FeralFrenzy"] = 274837,
				["Renewal"] = 108238,
				["TearDowntheMighty"] = 441846,
				["MarkoftheWild"] = 1126,
				["MountForm"] = 210053,
				["Dash"] = 1850,
				["AutoAttack"] = 6603,
				["WildstalkersPower"] = 439926,
				["MasteryRazorClaws"] = 77493,
			},
			["Balance"] = {
				["AstralSmolder"] = 394058,
				["NurturingInstinct"] = 33873,
				["MightyBash"] = 5211,
				["InstinctsoftheClaw"] = 449184,
				["NaturesGrace"] = 450347,
				["SouloftheForest"] = 114107,
				["ImprovedBarkskin"] = 327993,
				["UrsineVigor"] = 377842,
				["SolarBeam"] = 78675,
				["DreamSurge"] = 433831,
				["HarmonyoftheGrove"] = 428731,
				["Moondust"] = 429538,
				["StellarFlare"] = 202347,
				["HeartoftheWild"] = 319454,
				["BloomingInfusion"] = 429433,
				["Thrash"] = 106832,
				["AtmosphericExposure"] = 429532,
				["Cyclone"] = 33786,
				["NewMoon"] = 274281,
				["FluidForm"] = 449193,
				["AstralInfluence"] = 197524,
				["FlightForm"] = 276029,
				["WildCharge"] = 102401,
				["WildSurges"] = 406890,
				["CharmWoodlandCreature"] = 127757,
				["RemoveCorruption"] = 2782,
				["BalanceofAllThings"] = 394048,
				["AquaticForm"] = 276012,
				["OwlkinFrenzy"] = 231042,
				["TwinMoons"] = 279620,
				["Starfall"] = 191034,
				["Maim"] = 22570,
				["Starsurge"] = 78674,
				["MountForm"] = 210053,
				["ConvoketheSpirits"] = 391528,
				["Sunfire"] = 93402,
				["Forestwalk"] = 400129,
				["IncapacitatingRoar"] = 99,
				["WarStomp"] = 20549,
				["LightoftheSun"] = 202918,
				["BrokenIslesPathfinder"] = 233368,
				["MattedFur"] = 385786,
				["StampedingRoar"] = 106898,
				["UrsocsSpirit"] = 449182,
				["PowerofGoldrinn"] = 394046,
				["ReviveBattlePets"] = 125439,
				["CelestialAlignment"] = 194223,
				["MoonGuardian"] = 429520,
				["GuildMail"] = 83951,
				["MountUp"] = 78633,
				["WeaponSkills"] = 76300,
				["OrbitalStrike"] = 390378,
				["Lunation"] = 429539,
				["Eclipse"] = 79577,
				["ThickHide"] = 16931,
				["GreaterAlignment"] = 450184,
				["PowerofNature"] = 428859,
				["Swipe"] = 213764,
				["FuryofElune"] = 202770,
				["Expansiveness"] = 429399,
				["WellHonedInstincts"] = 377847,
				["RadiantMoonlight"] = 394121,
				["SunderedFirmament"] = 394094,
				["LycarasTeachings"] = 378988,
				["NaturesSplendor"] = 320668,
				["Innervate"] = 29166,
				["ProtectiveGrowth"] = 433748,
				["TravelForm"] = 783,
				["Oakskin"] = 449191,
				["LunarAmplification"] = 429529,
				["BoundlessMoonlight"] = 424058,
				["Endurance"] = 20550,
				["Mangle"] = 33917,
				["Starweaver"] = 393940,
				["LunarInsight"] = 429530,
				["Starfire"] = 194153,
				["ImprovedSunfire"] = 231050,
				["MassEntanglement"] = 102359,
				["GrovesInspiration"] = 429402,
				["AstralCommunion"] = 450598,
				["StellarAmplification"] = 450212,
				["FelineSwiftness"] = 131768,
				["HarmonyoftheHeavens"] = 450558,
				["Regrowth"] = 8936,
				["WildMushroom"] = 88747,
				["OrbitBreaker"] = 383197,
				["ShootingStars"] = 202342,
				["CosmicRapidity"] = 400059,
				["TigerDash"] = 252216,
				["BattleforAzerothPathfinder"] = 278833,
				["Solstice"] = 343647,
				["GroveInvigoration"] = 322721,
				["FerociousBite"] = 22568,
				["Revive"] = 50769,
				["Dreamwalk"] = 193753,
				["VerdantHeart"] = 301768,
				["LoreoftheGrove"] = 449185,
				["UmbralIntensity"] = 383195,
				["Rip"] = 1079,
				["Renewal"] = 108238,
				["NaturesBalance"] = 202430,
				["RattletheStars"] = 393954,
				["Barkskin"] = 22812,
				["HastyHearth"] = 83944,
				["ImprovedStampedingRoar"] = 288826,
				["Wrath"] = 190984,
				["StellarCommand"] = 429668,
				["ImprovedRejuvenation"] = 231040,
				["Rejuvenation"] = 774,
				["CenariusMight"] = 455797,
				["IncarnationChosenofElune"] = 102560,
				["Starlord"] = 202345,
				["DurabilityofNature"] = 429227,
				["CatForm"] = 768,
				["FrenziedRegeneration"] = 22842,
				["KillerInstinct"] = 108299,
				["GlisteningFur"] = 429533,
				["Rake"] = 1822,
				["TreantsoftheMoon"] = 428544,
				["ArmorSkills"] = 76275,
				["Hibernate"] = 2637,
				["ForceofNature"] = 205636,
				["ControloftheDream"] = 434249,
				["MasteryAstralInvocation"] = 393014,
				["Shred"] = 5221,
				["LunarCalling"] = 429523,
				["DenizenoftheDream"] = 394065,
				["LunarShrapnel"] = 415169,
				["NaturalRecovery"] = 377796,
				["TheLightofElune"] = 428655,
				["EntanglingRoots"] = 339,
				["WaningTwilight"] = 393956,
				["TheEternalMoon"] = 424113,
				["Rebirth"] = 20484,
				["WarriorofElune"] = 202425,
				["MoonkinForm"] = 24858,
				["AetherialKindling"] = 327541,
				["Ironfur"] = 192081,
				["ArcaneAffinity"] = 429540,
				["UmbralInspiration"] = 450418,
				["PoweroftheDream"] = 434220,
				["PrimalFury"] = 159286,
				["VindicaarMatrixCrystal"] = 251463,
				["RisingLightFallingNight"] = 417712,
				["Prowl"] = 5215,
				["UrsolsVortex"] = 102793,
				["EarlySpring"] = 428937,
				["WildGrowth"] = 48438,
				["TouchtheCosmos"] = 450356,
				["BearForm"] = 5487,
				["SkullBash"] = 106839,
				["Growl"] = 6795,
				["MasterRiding"] = 90265,
				["StarlightConduit"] = 451211,
				["BounteousBloom"] = 429215,
				["Languages"] = 79746,
				["NaturesVigil"] = 124974,
				["MobileBanking"] = 83958,
				["Brawn"] = 154743,
				["Cultivation"] = 20552,
				["ElunesGuidance"] = 393991,
				["TreantForm"] = 114282,
				["NatureResistance"] = 20551,
				["TheQuickandtheDead"] = 83950,
				["Soothe"] = 2908,
				["Flap"] = 164862,
				["PotentEnchantments"] = 429420,
				["Typhoon"] = 132469,
				["AstralInsight"] = 429536,
				["ElunesGrace"] = 443046,
				["UmbralEmbrace"] = 393760,
				["Dash"] = 1850,
				["AutoAttack"] = 6603,
				["MarkoftheWild"] = 1126,
				["Moonfire"] = 8921,
			},
			["Guardian"] = {
				["NurturingInstinct"] = 33873,
				["MightyBash"] = 5211,
				["InstinctsoftheClaw"] = 449184,
				["SouloftheForest"] = 158477,
				["ImprovedBarkskin"] = 327993,
				["UrsineVigor"] = 377842,
				["LunarBeam"] = 204066,
				["Hibernate"] = 2637,
				["Ravage"] = 441583,
				["Moondust"] = 429538,
				["MoonlessNight"] = 400278,
				["PacksEndurance"] = 441844,
				["HeartoftheWild"] = 319454,
				["VulnerableFlesh"] = 372618,
				["DreadfulWound"] = 441809,
				["Thrash"] = 77758,
				["AtmosphericExposure"] = 429532,
				["Cyclone"] = 33786,
				["SkullBash"] = 106839,
				["UrsocsEndurance"] = 393611,
				["FluidForm"] = 449193,
				["AstralInfluence"] = 197524,
				["AggravateWounds"] = 441829,
				["FlightForm"] = 276029,
				["WildCharge"] = 16979,
				["CharmWoodlandCreature"] = 127757,
				["BloodFrenzy"] = 203962,
				["RemoveCorruption"] = 2782,
				["AquaticForm"] = 276012,
				["DreamofCenarius"] = 372119,
				["Maim"] = 22570,
				["Berserk"] = 50334,
				["Starsurge"] = 197626,
				["MountForm"] = 210053,
				["VerdantHeart"] = 301768,
				["Raze"] = 400254,
				["Sunfire"] = 93402,
				["Forestwalk"] = 400129,
				["IncapacitatingRoar"] = 99,
				["WarStomp"] = 20549,
				["FlashingClaws"] = 393427,
				["LightningReflexes"] = 231065,
				["BrokenIslesPathfinder"] = 233368,
				["MattedFur"] = 385786,
				["GalacticGuardian"] = 203964,
				["StampedingRoar"] = 77761,
				["TearDowntheMighty"] = 441846,
				["UrsocsSpirit"] = 449182,
				["ReviveBattlePets"] = 125439,
				["TigerDash"] = 252216,
				["IncarnationGuardianofUrsoc"] = 102558,
				["GuildMail"] = 83951,
				["SurvivaloftheFittest"] = 203965,
				["GoryFur"] = 200854,
				["SurvivalInstincts"] = 61336,
				["Lunation"] = 429539,
				["StellarCommand"] = 429668,
				["ThickHide"] = 16931,
				["ViciousCycle"] = 371999,
				["ThornsofIron"] = 400222,
				["Maul"] = 6807,
				["EmpoweredShapeshifting"] = 441689,
				["InnateResolve"] = 377811,
				["FountofStrength"] = 441675,
				["KillingStrikes"] = 441824,
				["WellHonedInstincts"] = 377847,
				["UntamedSavagery"] = 372943,
				["LycarasTeachings"] = 378988,
				["NaturesSplendor"] = 320668,
				["Innervate"] = 29166,
				["TravelForm"] = 783,
				["Oakskin"] = 449191,
				["LunarAmplification"] = 429529,
				["BoundlessMoonlight"] = 424058,
				["Endurance"] = 20550,
				["ReinforcedFur"] = 393618,
				["Mangle"] = 33917,
				["LunarInsight"] = 429530,
				["Starfire"] = 197628,
				["ImprovedSunfire"] = 231050,
				["MassEntanglement"] = 102359,
				["CircleofLifeandDeath"] = 391969,
				["ClawRampage"] = 441835,
				["UrsolsVortex"] = 102793,
				["RendandTear"] = 204053,
				["FelineSwiftness"] = 131768,
				["UrsocsFury"] = 377210,
				["UrsineAdept"] = 300346,
				["Regrowth"] = 8936,
				["ArmorSkills"] = 76275,
				["Brawn"] = 154743,
				["GroveInvigoration"] = 322721,
				["Earthwarden"] = 203974,
				["FuryofNature"] = 370695,
				["ScintillatingMoonlight"] = 238049,
				["Rake"] = 1822,
				["Rip"] = 1079,
				["ImprovedSurvivalInstincts"] = 328767,
				["KillerInstinct"] = 108299,
				["TwinMoonfire"] = 372567,
				["Barkskin"] = 22812,
				["HastyHearth"] = 83944,
				["ImprovedStampedingRoar"] = 288826,
				["Wrath"] = 5176,
				["Gore"] = 210706,
				["MarkoftheWild"] = 1126,
				["Rejuvenation"] = 774,
				["MoonGuardian"] = 429520,
				["Dreamwalk"] = 193753,
				["MasteryNaturesGuardian"] = 155783,
				["Typhoon"] = 132469,
				["CatForm"] = 768,
				["FrenziedRegeneration"] = 22842,
				["WildshapeMastery"] = 441678,
				["GlisteningFur"] = 429533,
				["ImprovedRejuvenation"] = 231040,
				["Pulverize"] = 80313,
				["TheQuickandtheDead"] = 83950,
				["ToothandClaw"] = 135288,
				["ConvoketheSpirits"] = 391528,
				["StrikefortheHeart"] = 441845,
				["LayeredMane"] = 384721,
				["Cultivation"] = 20552,
				["LunarCalling"] = 429523,
				["NaturesVigil"] = 124974,
				["Shred"] = 5221,
				["NaturalRecovery"] = 377796,
				["TheLightofElune"] = 428655,
				["EntanglingRoots"] = 339,
				["BestialStrength"] = 441841,
				["GuardianofElune"] = 155578,
				["Rebirth"] = 20484,
				["RuthlessAggression"] = 441814,
				["Ironfur"] = 192081,
				["TheEternalMoon"] = 424113,
				["BristlingFur"] = 155835,
				["ArcaneAffinity"] = 429540,
				["PrimalFury"] = 159286,
				["AftertheWildfire"] = 371905,
				["InfectedWounds"] = 345208,
				["VindicaarMatrixCrystal"] = 251463,
				["RisingLightFallingNight"] = 417712,
				["Prowl"] = 5215,
				["WildGrowth"] = 48438,
				["LoreoftheGrove"] = 449185,
				["WildpowerSurge"] = 441691,
				["UrsocsGuidance"] = 393414,
				["BearForm"] = 5487,
				["Revive"] = 50769,
				["Growl"] = 6795,
				["MasterRiding"] = 90265,
				["StarlightConduit"] = 451211,
				["ElunesFavored"] = 370586,
				["Languages"] = 79746,
				["RageoftheSleeper"] = 200851,
				["MobileBanking"] = 83958,
				["Brambles"] = 203953,
				["MountUp"] = 78633,
				["NatureResistance"] = 20551,
				["TreantForm"] = 114282,
				["WeaponSkills"] = 76300,
				["Reinvigoration"] = 372945,
				["Soothe"] = 2908,
				["Flap"] = 164862,
				["FerociousBite"] = 22568,
				["Renewal"] = 108238,
				["AstralInsight"] = 429536,
				["ElunesGrace"] = 443046,
				["BattleforAzerothPathfinder"] = 278833,
				["Dash"] = 1850,
				["AutoAttack"] = 6603,
				["Swipe"] = 213771,
				["Moonfire"] = 8921,
			},
			["Restoration"] = {
				["NurturingInstinct"] = 33873,
				["MightyBash"] = 5211,
				["WildSynthesis"] = 400533,
				["InstinctsoftheClaw"] = 449184,
				["SouloftheForest"] = 158478,
				["CenariusGuidance"] = 393371,
				["ImprovedBarkskin"] = 327993,
				["UrsineVigor"] = 377842,
				["DreamSurge"] = 433831,
				["Hibernate"] = 2637,
				["HeartoftheWild"] = 319454,
				["BloomingInfusion"] = 429433,
				["Thrash"] = 106832,
				["BurstingGrowth"] = 440120,
				["Cyclone"] = 33786,
				["SkullBash"] = 106839,
				["PassingSeasons"] = 382550,
				["NaturesVigil"] = 124974,
				["AstralInfluence"] = 197524,
				["FlightForm"] = 276029,
				["WildCharge"] = 102401,
				["CharmWoodlandCreature"] = 127757,
				["AquaticForm"] = 276012,
				["HarmoniousBlooming"] = 392256,
				["Maim"] = 22570,
				["Starsurge"] = 197626,
				["MountForm"] = 210053,
				["IncarnationTreeofLife"] = 33891,
				["Sunfire"] = 93402,
				["Regenesis"] = 383191,
				["IncapacitatingRoar"] = 99,
				["WarStomp"] = 20549,
				["Photosynthesis"] = 274902,
				["RegenerativeHeartwood"] = 392116,
				["MasteryHarmony"] = 77495,
				["BrokenIslesPathfinder"] = 233368,
				["MattedFur"] = 385786,
				["StampedingRoar"] = 106898,
				["Efflorescence"] = 145205,
				["UrsocsSpirit"] = 449182,
				["ThrivingGrowth"] = 439528,
				["TranquilMind"] = 403521,
				["TigerDash"] = 252216,
				["EntanglingVortex"] = 439895,
				["Abundance"] = 207383,
				["Implant"] = 440118,
				["ThrivingVegetation"] = 447131,
				["LethalPreservation"] = 455461,
				["BondwithNature"] = 439929,
				["Nourish"] = 50464,
				["ThickHide"] = 16931,
				["TwinSprouts"] = 440117,
				["TreantsoftheMoon"] = 428544,
				["UnstoppableGrowth"] = 382559,
				["PowerofNature"] = 428859,
				["Swipe"] = 213764,
				["Verdancy"] = 392325,
				["Liveliness"] = 426702,
				["Cultivation"] = 20552,
				["Moonfire"] = 8921,
				["LycarasTeachings"] = 378988,
				["NaturesSplendor"] = 392288,
				["Ironbark"] = 102342,
				["VerdantInfusion"] = 392410,
				["ProtectiveGrowth"] = 433748,
				["TravelForm"] = 783,
				["Oakskin"] = 449191,
				["Endurance"] = 20550,
				["SpringBlossoms"] = 207385,
				["CenariusMight"] = 455797,
				["WildGrowth"] = 48438,
				["Stonebark"] = 197061,
				["ImprovedNaturesCure"] = 392378,
				["RampantGrowth"] = 404521,
				["Starfire"] = 197628,
				["ImprovedSunfire"] = 231050,
				["MassEntanglement"] = 102359,
				["GrovesInspiration"] = 429402,
				["FlashofClarity"] = 392220,
				["NaturesCure"] = 88423,
				["CatForm"] = 768,
				["UrsolsVortex"] = 102793,
				["ConvoketheSpirits"] = 391528,
				["GroveTending"] = 383192,
				["Innervate"] = 29166,
				["PrimalFury"] = 159286,
				["CenarionWard"] = 102351,
				["WellHonedInstincts"] = 377847,
				["Mangle"] = 33917,
				["FerociousBite"] = 22568,
				["Regrowth"] = 8936,
				["Renewal"] = 108238,
				["Forestwalk"] = 400129,
				["Invigorate"] = 392160,
				["NurturingDormancy"] = 392099,
				["ArmorSkills"] = 76275,
				["Overgrowth"] = 203651,
				["ImprovedRejuvenation"] = 231040,
				["Brawn"] = 154743,
				["YserasGift"] = 145108,
				["BuddingLeaves"] = 392167,
				["Revive"] = 50769,
				["RootNetwork"] = 439882,
				["DreamofCenarius"] = 158504,
				["LoreoftheGrove"] = 449185,
				["Rake"] = 1822,
				["Rip"] = 1079,
				["EmbraceoftheDream"] = 392124,
				["KillerInstinct"] = 108299,
				["Expansiveness"] = 429399,
				["Barkskin"] = 22812,
				["HastyHearth"] = 83944,
				["ImprovedStampedingRoar"] = 288826,
				["Wrath"] = 5176,
				["HarmonyoftheGrove"] = 428731,
				["NatureResistance"] = 20551,
				["Rejuvenation"] = 774,
				["BattleforAzerothPathfinder"] = 278833,
				["ImprovedIronbark"] = 382552,
				["ImprovedWildGrowth"] = 328025,
				["DurabilityofNature"] = 429227,
				["ReviveBattlePets"] = 125439,
				["FrenziedRegeneration"] = 22842,
				["GroveGuardians"] = 102693,
				["Undergrowth"] = 392301,
				["Growl"] = 6795,
				["NaturesSwiftness"] = 132158,
				["Revitalize"] = 212040,
				["MobileBanking"] = 83958,
				["Lifebloom"] = 188550,
				["ControloftheDream"] = 434249,
				["GuildMail"] = 83951,
				["FlowerWalk"] = 439901,
				["EarlySpring"] = 428937,
				["VigorousCreepers"] = 440119,
				["HuntBeneaththeOpenSkies"] = 439868,
				["NaturalRecovery"] = 377796,
				["Shred"] = 5221,
				["EntanglingRoots"] = 339,
				["Flourish"] = 197721,
				["FelineSwiftness"] = 131768,
				["Rebirth"] = 20484,
				["Reforestation"] = 392356,
				["Prosperity"] = 200383,
				["ImprovedRegrowth"] = 231032,
				["Ironfur"] = 192081,
				["PoweroftheDream"] = 434220,
				["HarmoniousConstitution"] = 440116,
				["MasterShapeshifter"] = 289237,
				["WakingDream"] = 392221,
				["VindicaarMatrixCrystal"] = 251463,
				["RisingLightFallingNight"] = 417712,
				["Prowl"] = 5215,
				["ResilientFlourishing"] = 439880,
				["Tranquility"] = 740,
				["PoweroftheArchdruid"] = 392302,
				["StrategicInfusion"] = 439890,
				["BearForm"] = 5487,
				["Germination"] = 155675,
				["CalloftheElderDruid"] = 426784,
				["MasterRiding"] = 90265,
				["StarlightConduit"] = 451211,
				["BounteousBloom"] = 429215,
				["Languages"] = 79746,
				["Dreamstate"] = 392162,
				["MountUp"] = 78633,
				["OmenofClarity"] = 113043,
				["WeaponSkills"] = 76300,
				["PotentEnchantments"] = 429420,
				["TreantForm"] = 114282,
				["TheQuickandtheDead"] = 83950,
				["Dreamwalk"] = 193753,
				["Soothe"] = 2908,
				["Flap"] = 164862,
				["InnerPeace"] = 197073,
				["Typhoon"] = 132469,
				["MarkoftheWild"] = 1126,
				["VerdantHeart"] = 301768,
				["FluidForm"] = 449193,
				["Dash"] = 1850,
				["AutoAttack"] = 6603,
				["WildstalkersPower"] = 439926,
				["Swiftmend"] = 18562,
			},
		},
		["Death Knight"] = {
			["Unholy"] = {
				["GiftoftheSanlayn"] = 434152,
				["Decomposition"] = 455398,
				["AFeastofSouls"] = 444072,
				["TheBloodisLife"] = 434260,
				["Plaguebringer"] = 390175,
				["SanguineScent"] = 434263,
				["PactoftheApocalypse"] = 444083,
				["DeathsReach"] = 276079,
				["ScourgeStrike"] = 55090,
				["UnholyBond"] = 374261,
				["RuneMastery"] = 374574,
				["RottenTouch"] = 390275,
				["WilloftheNecropolis"] = 206967,
				["VampiricSpeed"] = 434028,
				["ArcaneAcuity"] = 154742,
				["AbominationLimb"] = 383269,
				["ImprovedDeathCoil"] = 377580,
				["MarchofDarkness"] = 391546,
				["VampiricStrike"] = 433901,
				["TheQuickandtheDead"] = 83950,
				["Coldthirst"] = 378848,
				["Morbidity"] = 377592,
				["DoomedBidding"] = 455386,
				["SubduingGrasp"] = 454822,
				["WhitemanesFamine"] = 444033,
				["ControlUndead"] = 111673,
				["ProliferatingChill"] = 373930,
				["WraithWalk"] = 212552,
				["IceboundFortitude"] = 48792,
				["NullMagic"] = 454842,
				["BattleforAzerothPathfinder"] = 278833,
				["BrokenIslesPathfinder"] = 233368,
				["DeathsEcho"] = 356367,
				["UnyieldingWill"] = 457574,
				["BlindingSleet"] = 207167,
				["VileContagion"] = 390279,
				["HungeringThirst"] = 444037,
				["GripoftheDead"] = 273952,
				["UnholyAura"] = 377440,
				["BloodyFortitude"] = 434136,
				["GuildMail"] = 83951,
				["DeathPact"] = 48743,
				["Superstrain"] = 390283,
				["MograinesMight"] = 444047,
				["OnaPaleHorse"] = 51986,
				["Enfeeble"] = 392566,
				["GhoulishFrenzy"] = 377587,
				["PathofFrost"] = 3714,
				["UnholyPact"] = 319230,
				["RunicAttenuation"] = 207104,
				["BloodDraw"] = 374598,
				["NazgrimsConquest"] = 444052,
				["ImprovedDeathStrike"] = 374277,
				["EbonFever"] = 207269,
				["Permafrost"] = 207200,
				["RidersChampion"] = 444005,
				["CoilofDevastation"] = 390270,
				["AntiMagicBarrier"] = 205727,
				["GloomWard"] = 391571,
				["Asphyxiate"] = 221562,
				["IcePrison"] = 454786,
				["VampiricAura"] = 434100,
				["ImprovedFesteringStrike"] = 316867,
				["UnholyAssault"] = 207289,
				["Assimilation"] = 374383,
				["ApocalypseNow"] = 444040,
				["FuryoftheHorsemen"] = 444069,
				["MindFreeze"] = 47528,
				["RupturedViscera"] = 390236,
				["DarkTransformation"] = 63560,
				["FoulInfections"] = 455396,
				["BloodSoakedGround"] = 434033,
				["MawswornMenace"] = 444099,
				["InciteTerror"] = 434151,
				["Epidemic"] = 207317,
				["AntiMagicShell"] = 48707,
				["ClawingShadows"] = 207311,
				["ArmorSkills"] = 76282,
				["CommanderoftheDead"] = 390259,
				["InfectedClaws"] = 207272,
				["MasteryDreadblade"] = 77515,
				["VestigialShell"] = 454851,
				["HastyHearth"] = 83944,
				["RunicCorruption"] = 51462,
				["MenacingMagus"] = 455135,
				["Lichborne"] = 49039,
				["Runeforging"] = 53428,
				["AntiMagicZone"] = 51052,
				["Outbreak"] = 77575,
				["DeathGate"] = 50977,
				["VisceralStrength"] = 434157,
				["DarkCommand"] = 56222,
				["CleavingStrikes"] = 316916,
				["PactoftheSanlayn"] = 434261,
				["WeaponSkills"] = 76292,
				["EternalAgony"] = 390268,
				["AllWillServe"] = 194916,
				["InsidiousChill"] = 391566,
				["MountUp"] = 78633,
				["ReviveBattlePets"] = 125439,
				["HorsemensAid"] = 444074,
				["DeathsAdvance"] = 48265,
				["ArcaneTorrent"] = 50613,
				["DeathRot"] = 377537,
				["FesteringScythe"] = 455397,
				["MobileBanking"] = 83958,
				["ArmyoftheDead"] = 42650,
				["SuddenDoom"] = 49530,
				["Festermight"] = 377590,
				["FesteringStrike"] = 85948,
				["DeathGrip"] = 49576,
				["RunicMastery"] = 390166,
				["DeathStrike"] = 49998,
				["InflictionofSorrow"] = 434143,
				["RaiseAbomination"] = 455395,
				["FrenziedBloodthirst"] = 434075,
				["ArcaneAffinity"] = 28877,
				["UnholyBlight"] = 460448,
				["SoulReaper"] = 343294,
				["SummonGargoyle"] = 49206,
				["VindicaarMatrixCrystal"] = 251463,
				["RaiseAlly"] = 61999,
				["NewlyTurned"] = 433934,
				["SacrificialPact"] = 327574,
				["MasterRiding"] = 90265,
				["Pestilence"] = 277234,
				["RaiseDead"] = 46584,
				["RunicProtection"] = 454788,
				["UnholyEndurance"] = 389682,
				["Defile"] = 152280,
				["RuneStrike"] = 316239,
				["DeathCharge"] = 444010,
				["Suppression"] = 374049,
				["Languages"] = 79748,
				["VeteranoftheThirdWar"] = 48263,
				["OnaPalerHorse"] = 444008,
				["IcyTalons"] = 194878,
				["TrollbanesIcyFury"] = 444097,
				["DarkSuccor"] = 178819,
				["DeathCoil"] = 47541,
				["ArcaneResistance"] = 822,
				["UnholyGround"] = 374265,
				["BloodScent"] = 374030,
				["DeathandDecay"] = 43265,
				["Osmosis"] = 454835,
				["MagusoftheDead"] = 390196,
				["ChainsofIce"] = 45524,
				["HarbingerofDoom"] = 276023,
				["Reaping"] = 377514,
				["Brittle"] = 374504,
				["AutoAttack"] = 6603,
				["BurstingSores"] = 207264,
				["Apocalypse"] = 275699,
			},
			["Frost"] = {
				["DarkTalons"] = 436687,
				["AFeastofSouls"] = 444072,
				["HornofWinter"] = 57330,
				["AntiMagicZone"] = 51052,
				["PactoftheApocalypse"] = 444083,
				["DeathsReach"] = 276079,
				["MasteryFrozenHeart"] = 77514,
				["UnholyBond"] = 374261,
				["ShatteringBlade"] = 207057,
				["RuneMastery"] = 374574,
				["WilloftheNecropolis"] = 206967,
				["SoulReaper"] = 343294,
				["ArcaneAcuity"] = 154742,
				["AbominationLimb"] = 383269,
				["SoulRupture"] = 437161,
				["BindinDarkness"] = 440031,
				["MarchofDarkness"] = 391546,
				["DarkCommand"] = 56222,
				["TheLongWinter"] = 456240,
				["FrigidExecutioner"] = 377073,
				["Coldthirst"] = 378848,
				["MightoftheFrozenWastes"] = 81333,
				["UnholyEndurance"] = 389682,
				["Everfrost"] = 376938,
				["SubduingGrasp"] = 454822,
				["WhitemanesFamine"] = 444033,
				["ImprovedObliterate"] = 317198,
				["ControlUndead"] = 111673,
				["PiercingChill"] = 377351,
				["ProliferatingChill"] = 373930,
				["WraithWalk"] = 212552,
				["CarversEye"] = 350899,
				["IceboundFortitude"] = 48792,
				["Hyperpyrexia"] = 456238,
				["RuneCarvedPlates"] = 440282,
				["BattleforAzerothPathfinder"] = 278833,
				["ColdHeart"] = 281208,
				["BrokenIslesPathfinder"] = 233368,
				["InexorableAssault"] = 253593,
				["DeathsEcho"] = 356367,
				["UnyieldingWill"] = 457574,
				["BlindingSleet"] = 207167,
				["HungeringThirst"] = 444037,
				["Avalanche"] = 207142,
				["GripoftheDead"] = 273952,
				["ReviveBattlePets"] = 125439,
				["Obliterate"] = 49020,
				["GuildMail"] = 83951,
				["DeathPact"] = 48743,
				["MountUp"] = 78633,
				["MograinesMight"] = 444047,
				["OnaPaleHorse"] = 51986,
				["Enfeeble"] = 392566,
				["PathofFrost"] = 3714,
				["RunicAttenuation"] = 207104,
				["BloodDraw"] = 374598,
				["EnduringStrength"] = 377190,
				["GlacialAdvance"] = 194913,
				["NazgrimsConquest"] = 444052,
				["ImprovedDeathStrike"] = 374277,
				["Obliteration"] = 281238,
				["Permafrost"] = 207200,
				["RidersChampion"] = 444005,
				["RemorselessWinter"] = 196770,
				["TrollbanesIcyFury"] = 444097,
				["PactoftheDeathbringer"] = 440476,
				["AntiMagicBarrier"] = 205727,
				["GloomWard"] = 391571,
				["Asphyxiate"] = 221562,
				["IcePrison"] = 454786,
				["WaveofSouls"] = 439851,
				["ReapersMark"] = 439843,
				["ApocalypseNow"] = 444040,
				["ChillStreak"] = 305392,
				["Exterminate"] = 441378,
				["RageoftheFrozenChampion"] = 377076,
				["BitingCold"] = 377056,
				["MindFreeze"] = 47528,
				["DeathsAdvance"] = 48265,
				["IcyTalons"] = 194878,
				["SacrificialPact"] = 327574,
				["FrostwyrmsFury"] = 279302,
				["MawswornMenace"] = 444099,
				["ArcticAssault"] = 456230,
				["ImprovedRime"] = 316838,
				["GatheringStorm"] = 194912,
				["KillingMachine"] = 51128,
				["Bonegrinder"] = 377098,
				["AbsoluteZero"] = 377047,
				["CryogenicChamber"] = 456237,
				["PillarofFrost"] = 51271,
				["VestigialShell"] = 454851,
				["ForgeborneReveries"] = 326514,
				["MurderousEfficiency"] = 207061,
				["RunicEmpowerment"] = 81229,
				["WitherAway"] = 441894,
				["Rime"] = 59057,
				["DarkSuccor"] = 178819,
				["FrostStrike"] = 49143,
				["Runeforging"] = 53428,
				["Lichborne"] = 49039,
				["EmpowerRuneWeapon"] = 47568,
				["HastyHearth"] = 83944,
				["InsidiousChill"] = 391566,
				["EnduringChill"] = 377376,
				["DeathGate"] = 50977,
				["ChainsofIce"] = 45524,
				["DeathandDecay"] = 43265,
				["Frostscythe"] = 207230,
				["DeathCoil"] = 47541,
				["WeaponSkills"] = 76292,
				["CleavingStrikes"] = 316916,
				["HorsemensAid"] = 444074,
				["ShatteredFrost"] = 455993,
				["ArmorSkills"] = 76282,
				["SmotheringOffense"] = 435005,
				["DeathGrip"] = 49576,
				["ImprovedFrostStrike"] = 316803,
				["DeathStrike"] = 49998,
				["MobileBanking"] = 83958,
				["HowlingBlast"] = 49184,
				["RuneforgedSpurs"] = 326512,
				["ArcaneAffinity"] = 28877,
				["Icecap"] = 207126,
				["VeteranoftheThirdWar"] = 48263,
				["RaiseAlly"] = 61999,
				["VindicaarMatrixCrystal"] = 251463,
				["FuryoftheHorsemen"] = 444069,
				["SwiftEnd"] = 443560,
				["ArcaneTorrent"] = 50613,
				["MasterRiding"] = 90265,
				["RunicCommand"] = 376251,
				["RaiseDead"] = 46585,
				["RunicProtection"] = 454788,
				["FrostwhelpsAid"] = 377226,
				["NullMagic"] = 454842,
				["RuneStrike"] = 316239,
				["IcyDeathTorrent"] = 435010,
				["Suppression"] = 374049,
				["Languages"] = 79748,
				["Icebreaker"] = 392950,
				["OnaPalerHorse"] = 444008,
				["BreathofSindragosa"] = 152279,
				["PainfulDeath"] = 443564,
				["Assimilation"] = 374383,
				["UnleashedFrenzy"] = 376905,
				["ArcaneResistance"] = 822,
				["DeathCharge"] = 444010,
				["BloodScent"] = 374030,
				["TheQuickandtheDead"] = 83950,
				["Osmosis"] = 454835,
				["AntiMagicShell"] = 48707,
				["BloodFever"] = 440002,
				["ExpellingShield"] = 439948,
				["DeathsMessenger"] = 437122,
				["GrimReaper"] = 434905,
				["AutoAttack"] = 6603,
				["UnholyGround"] = 374265,
				["Brittle"] = 374504,
			},
			["Blood"] = {
				["GiftoftheSanlayn"] = 434152,
				["DarkTalons"] = 436687,
				["ArcaneTorrent"] = 50613,
				["TheBloodisLife"] = 434260,
				["NewlyTurned"] = 433934,
				["BloodTap"] = 221699,
				["SanguineScent"] = 434263,
				["DeathsReach"] = 276079,
				["UnholyBond"] = 374261,
				["RuneMastery"] = 374574,
				["WilloftheNecropolis"] = 206967,
				["VampiricSpeed"] = 434028,
				["ArcaneAcuity"] = 154742,
				["AbominationLimb"] = 383269,
				["SoulRupture"] = 437161,
				["BindinDarkness"] = 440031,
				["MarchofDarkness"] = 391546,
				["VampiricStrike"] = 433901,
				["TheQuickandtheDead"] = 83950,
				["OssifiedVitriol"] = 458744,
				["Coldthirst"] = 378848,
				["Marrowrend"] = 195182,
				["UnholyEndurance"] = 389682,
				["SubduingGrasp"] = 454822,
				["Carnage"] = 458752,
				["BloodFeast"] = 391386,
				["ImprovedHeartStrike"] = 374717,
				["BloodiedBlade"] = 458753,
				["ProliferatingChill"] = 373930,
				["WraithWalk"] = 212552,
				["CarversEye"] = 350899,
				["IceboundFortitude"] = 48792,
				["RuneCarvedPlates"] = 440282,
				["BattleforAzerothPathfinder"] = 278833,
				["BrokenIslesPathfinder"] = 233368,
				["DeathsEcho"] = 356367,
				["UnyieldingWill"] = 457574,
				["BlindingSleet"] = 207167,
				["HeartStrike"] = 206930,
				["GripoftheDead"] = 273952,
				["PerseveranceoftheEbonBlade"] = 374747,
				["ReviveBattlePets"] = 125439,
				["ReinforcedBones"] = 374737,
				["Hemostasis"] = 273946,
				["EverlastingBond"] = 377668,
				["GuildMail"] = 83951,
				["DeathPact"] = 48743,
				["Bloodworms"] = 195679,
				["WeaponSkills"] = 76292,
				["OnaPaleHorse"] = 51986,
				["Enfeeble"] = 392566,
				["Coagulopathy"] = 391477,
				["BoneCollector"] = 458572,
				["RedThirst"] = 205723,
				["BloodDraw"] = 374598,
				["Heartrend"] = 377655,
				["MasteryBloodShield"] = 77513,
				["TighteningGrasp"] = 206970,
				["IronHeart"] = 391395,
				["ImprovedDeathStrike"] = 374277,
				["Permafrost"] = 207200,
				["PactoftheDeathbringer"] = 440476,
				["AntiMagicBarrier"] = 205727,
				["GloomWard"] = 391571,
				["Asphyxiate"] = 221562,
				["ImprovedBoneShield"] = 374715,
				["IcePrison"] = 454786,
				["ShatteringBone"] = 377640,
				["VampiricAura"] = 434100,
				["WaveofSouls"] = 439851,
				["ReapersMark"] = 439843,
				["BloodBoil"] = 50842,
				["Exterminate"] = 441378,
				["ExpellingShield"] = 439948,
				["MindFreeze"] = 47528,
				["DeathsAdvance"] = 48265,
				["UmbilicusEternus"] = 391517,
				["IcyTalons"] = 194878,
				["BloodSoakedGround"] = 434033,
				["InciteTerror"] = 434151,
				["AntiMagicShell"] = 48707,
				["ArmorSkills"] = 76282,
				["Bonestorm"] = 194844,
				["GrimReaper"] = 434905,
				["BloodFortification"] = 374721,
				["VestigialShell"] = 454851,
				["Tombstone"] = 219809,
				["CrimsonScourge"] = 81136,
				["VampiricBlood"] = 55233,
				["Blooddrinker"] = 206931,
				["DeathsCaress"] = 195292,
				["PathofFrost"] = 3714,
				["Lichborne"] = 49039,
				["WitherAway"] = 441894,
				["DeathGate"] = 50977,
				["VisceralStrength"] = 434157,
				["CleavingStrikes"] = 316916,
				["UnholyGround"] = 374265,
				["PactoftheSanlayn"] = 434261,
				["DarkCommand"] = 56222,
				["DeathandDecay"] = 43265,
				["ChainsofIce"] = 45524,
				["InsidiousChill"] = 391566,
				["FoulBulwark"] = 206974,
				["Brittle"] = 374504,
				["MountUp"] = 78633,
				["BloodyFortitude"] = 434136,
				["HastyHearth"] = 83944,
				["LeechingStrike"] = 377629,
				["ControlUndead"] = 111673,
				["MarkofBlood"] = 206940,
				["RelishinBlood"] = 317610,
				["ImprovedVampiricBlood"] = 317133,
				["SacrificialPact"] = 327574,
				["InsatiableBlade"] = 377637,
				["DeathGrip"] = 49576,
				["PainfulDeath"] = 443564,
				["DeathStrike"] = 49998,
				["InflictionofSorrow"] = 434143,
				["FrenziedBloodthirst"] = 434075,
				["RuneforgedSpurs"] = 326512,
				["ArcaneAffinity"] = 28877,
				["RaiseAlly"] = 61999,
				["AntiMagicZone"] = 51052,
				["Consumption"] = 274156,
				["VindicaarMatrixCrystal"] = 251463,
				["Purgatory"] = 114556,
				["SwiftEnd"] = 443560,
				["Heartbreaker"] = 221536,
				["MasterRiding"] = 90265,
				["MobileBanking"] = 83958,
				["RunicProtection"] = 454788,
				["RaiseDead"] = 46585,
				["RapidDecomposition"] = 194662,
				["SanguineGround"] = 391458,
				["RuneStrike"] = 316239,
				["SoulReaper"] = 343294,
				["Suppression"] = 374049,
				["Languages"] = 79748,
				["VeteranoftheThirdWar"] = 48263,
				["Voracious"] = 273953,
				["Assimilation"] = 374383,
				["Ossuary"] = 219786,
				["NullMagic"] = 454842,
				["BloodFever"] = 440002,
				["ArcaneResistance"] = 822,
				["DeathCoil"] = 47541,
				["BloodScent"] = 374030,
				["ForgeborneReveries"] = 326514,
				["Osmosis"] = 454835,
				["Bloodshot"] = 391398,
				["DeathsMessenger"] = 437122,
				["DancingRuneWeapon"] = 49028,
				["GorefiendsGrasp"] = 108199,
				["RuneTap"] = 194679,
				["AutoAttack"] = 6603,
				["Runeforging"] = 53428,
				["RunicAttenuation"] = 207104,
			},
		},
		["Hunter"] = {
			["Marksmanship"] = {
				["LunarStorm"] = 450385,
				["Scrappy"] = 459533,
				["ImplosiveTrap"] = 462031,
				["ArcaneTorrent"] = 80483,
				["SmallGameHunter"] = 459802,
				["WildernessMedicine"] = 343242,
				["TerritorialInstincts"] = 459507,
				["AimedShot"] = 19434,
				["LegacyoftheWindrunners"] = 406425,
				["ScareBeast"] = 1513,
				["MasterMarksman"] = 260309,
				["BlackArrow"] = 430703,
				["ReleaseandReload"] = 450376,
				["TrickShots"] = 257621,
				["TarCoatedBindings"] = 459460,
				["ArcaneShot"] = 185358,
				["Posthaste"] = 109215,
				["Barrage"] = 120360,
				["Streamline"] = 260367,
				["Deathblow"] = 378769,
				["TheQuickandtheDead"] = 83950,
				["MultiShot"] = 257620,
				["DarknessCalls"] = 430722,
				["WitheringFire"] = 430715,
				["Salvo"] = 400456,
				["Pathfinding"] = 378002,
				["Camouflage"] = 199483,
				["DevilsaurTranquilizer"] = 459991,
				["Intimidation"] = 19577,
				["PaddedArmor"] = 459450,
				["DeathShade"] = 430711,
				["ShadowSurge"] = 430714,
				["BattleforAzerothPathfinder"] = 278833,
				["RoarofSacrifice"] = 53480,
				["InvigoratingPulse"] = 450379,
				["FreezingTrap"] = 187650,
				["BrokenIslesPathfinder"] = 233368,
				["UnerringVision"] = 386878,
				["LoneSurvivor"] = 388039,
				["ImprovedSteadyShot"] = 321018,
				["BlackrockMunitions"] = 462036,
				["KillerAccuracy"] = 378765,
				["CatchOut"] = 451516,
				["LightAmmo"] = 378913,
				["BornToBeWild"] = 266921,
				["GuildMail"] = 83951,
				["Sentinel"] = 450369,
				["BindingShot"] = 109248,
				["MomentofOpportunity"] = 459488,
				["EagletalonsTrueFocus"] = 389449,
				["CounterShot"] = 147362,
				["NightHunter"] = 378766,
				["RejuvenatingWind"] = 385539,
				["FeignDeath"] = 5384,
				["KindlingFlare"] = 459506,
				["SentinelPrecision"] = 450375,
				["HydrasBite"] = 260241,
				["ExplosiveShot"] = 212431,
				["ShadowHounds"] = 430707,
				["PrimalRage"] = 272678,
				["UnnaturalCauses"] = 459527,
				["BindingShackles"] = 321468,
				["PlayDead"] = 209997,
				["WailingArrow"] = 459806,
				["IntheRhythm"] = 407404,
				["NoHardFeelings"] = 459546,
				["ImprovedKillShot"] = 343248,
				["DontLookBack"] = 450373,
				["ConcussiveShot"] = 5116,
				["ScatterShot"] = 213691,
				["MobileBanking"] = 83958,
				["CrackShot"] = 321293,
				["Readiness"] = 389865,
				["EyesClosed"] = 450381,
				["ExtrapolatedShots"] = 450374,
				["Misdirection"] = 34477,
				["TranquilizingShot"] = 19801,
				["DisruptiveRounds"] = 343244,
				["EmergencySalve"] = 459517,
				["ImprovedTraps"] = 343247,
				["WingClip"] = 195645,
				["MasterySniperTraining"] = 193468,
				["Overwatch"] = 450384,
				["TriggerFinger"] = 459534,
				["SteadyShot"] = 56641,
				["RazorFragments"] = 384790,
				["CallingtheShots"] = 260404,
				["Exhilaration"] = 109304,
				["GhillieSuit"] = 459466,
				["HuntersMark"] = 257284,
				["Flare"] = 1543,
				["Fetch"] = 125050,
				["SerratedTips"] = 459502,
				["SymphonicArsenal"] = 450383,
				["EagleEye"] = 6197,
				["KillZone"] = 459921,
				["FocusedAim"] = 378767,
				["PreciseShots"] = 260240,
				["DarkEmpowerment"] = 430718,
				["AspectoftheTurtle"] = 186265,
				["Entrapment"] = 393344,
				["WeaponSkills"] = 76249,
				["AspectoftheCheetah"] = 186257,
				["MountUp"] = 78633,
				["SerpentstalkersTrickery"] = 378888,
				["KillShot"] = 53351,
				["MasterRiding"] = 90265,
				["SteadyFocus"] = 193533,
				["KeenEyesight"] = 378004,
				["Trailblazer"] = 199921,
				["HastyHearth"] = 83944,
				["ArmorSkills"] = 76250,
				["Bulletstorm"] = 389019,
				["Bullseye"] = 204089,
				["ArcaneResistance"] = 822,
				["ReviveBattlePets"] = 125439,
				["TarTrap"] = 187698,
				["Overshadow"] = 430716,
				["ArcaneAcuity"] = 154742,
				["VindicaarMatrixCrystal"] = 251463,
				["ArcaneAffinity"] = 28877,
				["AutoShot"] = 75,
				["ChimaeraShot"] = 342049,
				["Sideline"] = 450378,
				["LockandLoad"] = 194595,
				["LoneWolf"] = 155228,
				["SentinelWatch"] = 451546,
				["Volley"] = 260243,
				["CarefulAim"] = 260228,
				["ScoutsInstincts"] = 459455,
				["SmokeScreen"] = 430709,
				["HuntersAvoidance"] = 384799,
				["TacticalReload"] = 400472,
				["SurvivaloftheFittest"] = 264735,
				["RapidFireBarrage"] = 459800,
				["SpecializedArsenal"] = 459542,
				["EmbracetheShadows"] = 430704,
				["Languages"] = 79748,
				["BurstingShot"] = 186387,
				["GraveReaper"] = 430719,
				["SurgingShots"] = 391559,
				["Disengage"] = 781,
				["ShadowErasure"] = 430720,
				["Trueshot"] = 288613,
				["HighExplosiveTrap"] = 236776,
				["PenetratingShots"] = 459783,
				["KodoTranquilizer"] = 459983,
				["EyesoftheBeast"] = 321297,
				["CrescentSteel"] = 451530,
				["QuickLoad"] = 378771,
				["ShadowLash"] = 430717,
				["DarkChains"] = 430712,
				["RapidFire"] = 257044,
				["NaturalMending"] = 270581,
				["AutoAttack"] = 6603,
				["HeavyAmmo"] = 378910,
				["FantheHammer"] = 459794,
			},
			["Beast Mastery"] = {
				["Scrappy"] = 459533,
				["ImplosiveTrap"] = 462031,
				["ArcaneTorrent"] = 80483,
				["BeastCleave"] = 115939,
				["WildernessMedicine"] = 343242,
				["ShowerofBlood"] = 459729,
				["TerritorialInstincts"] = 459507,
				["MasteryMasterofBeasts"] = 76657,
				["ScareBeast"] = 1513,
				["BlackArrow"] = 430703,
				["PackCoordination"] = 445505,
				["GofortheThroat"] = 459550,
				["PiercingFangs"] = 392053,
				["HuntersMark"] = 257284,
				["TarCoatedBindings"] = 459460,
				["ArcaneShot"] = 185358,
				["Posthaste"] = 109215,
				["SmokeScreen"] = 430709,
				["MasterHandler"] = 424558,
				["TheQuickandtheDead"] = 83950,
				["MultiShot"] = 2643,
				["DarknessCalls"] = 430722,
				["WitheringFire"] = 430715,
				["SpecializedArsenal"] = 459542,
				["ScatteredPrey"] = 445768,
				["WildInstincts"] = 378442,
				["Camouflage"] = 199483,
				["DevilsaurTranquilizer"] = 459991,
				["Intimidation"] = 19577,
				["PaddedArmor"] = 459450,
				["DeathShade"] = 430711,
				["ShadowSurge"] = 430714,
				["BattleforAzerothPathfinder"] = 278833,
				["RoarofSacrifice"] = 53480,
				["KillCommand"] = 34026,
				["Savagery"] = 424557,
				["ExplosiveVenom"] = 459693,
				["KillerCobra"] = 199532,
				["LoneSurvivor"] = 388039,
				["BlackrockMunitions"] = 462036,
				["AnimalCompanion"] = 267116,
				["VenomsBite"] = 459565,
				["Stomp"] = 199530,
				["NaturalMending"] = 270581,
				["BornToBeWild"] = 266921,
				["GuildMail"] = 83951,
				["SurvivaloftheFittest"] = 264735,
				["BindingShot"] = 109248,
				["TirelessHunt"] = 445701,
				["ImprovedKillCommand"] = 378010,
				["CorneredPrey"] = 445702,
				["MomentofOpportunity"] = 459488,
				["CounterShot"] = 147362,
				["BarbedWrath"] = 231548,
				["HuntmastersCall"] = 459730,
				["FeignDeath"] = 5384,
				["KindlingFlare"] = 459506,
				["KodoTranquilizer"] = 459983,
				["HuntersPrey"] = 378210,
				["CobraSenses"] = 378244,
				["ShadowHounds"] = 430707,
				["BrutalCompanion"] = 386870,
				["UnnaturalCauses"] = 459527,
				["BindingShackles"] = 321468,
				["PlayDead"] = 209997,
				["WildCall"] = 185789,
				["NoHardFeelings"] = 459546,
				["ImprovedKillShot"] = 343248,
				["ConcussiveShot"] = 5116,
				["ScatterShot"] = 213691,
				["MobileBanking"] = 83958,
				["ThrilloftheHunt"] = 257944,
				["DireCommand"] = 378743,
				["Flare"] = 1543,
				["ScentofBlood"] = 193532,
				["TranquilizingShot"] = 19801,
				["AMurderofCrows"] = 459760,
				["DisruptiveRounds"] = 343244,
				["EmergencySalve"] = 459517,
				["ExoticBeasts"] = 53270,
				["SteadyShot"] = 56641,
				["FreezingTrap"] = 187650,
				["ImprovedTraps"] = 343247,
				["WingClip"] = 195645,
				["Fetch"] = 125050,
				["KillerInstinct"] = 273887,
				["TriggerFinger"] = 459534,
				["QuickLoad"] = 378771,
				["HastyHearth"] = 83944,
				["EagleEye"] = 6197,
				["Exhilaration"] = 109304,
				["GhillieSuit"] = 459466,
				["KillCleave"] = 378207,
				["Disengage"] = 781,
				["ArcaneResistance"] = 822,
				["SerratedTips"] = 459502,
				["AspectoftheTurtle"] = 186265,
				["ArmorSkills"] = 76250,
				["WeaponSkills"] = 76249,
				["MountUp"] = 78633,
				["PackAssault"] = 445721,
				["DarkEmpowerment"] = 430718,
				["Misdirection"] = 34477,
				["Entrapment"] = 393344,
				["BrokenIslesPathfinder"] = 233368,
				["AspectoftheCheetah"] = 186257,
				["CommandPet"] = 272651,
				["ArcaneAffinity"] = 28877,
				["KillShot"] = 53351,
				["ArcaneAcuity"] = 154742,
				["CalloftheWild"] = 359844,
				["KeenEyesight"] = 378004,
				["Trailblazer"] = 199921,
				["ReviveBattlePets"] = 125439,
				["HowlofthePack"] = 445707,
				["CobraShot"] = 193455,
				["AutoShot"] = 75,
				["Bloodshed"] = 321530,
				["CoveringFire"] = 445715,
				["DarkChains"] = 430712,
				["Overshadow"] = 430716,
				["Laceration"] = 459552,
				["CulltheHerd"] = 445717,
				["PackTactics"] = 321014,
				["VenomousBite"] = 459667,
				["BarbedShot"] = 217200,
				["WildAttacks"] = 445708,
				["VindicaarMatrixCrystal"] = 251463,
				["FuriousAssault"] = 445699,
				["DenRecovery"] = 445710,
				["ViciousHunt"] = 445404,
				["ScoutsInstincts"] = 459455,
				["KindredSpirits"] = 56315,
				["HuntersAvoidance"] = 384799,
				["WarOrders"] = 393933,
				["DireFrenzy"] = 385810,
				["ExplosiveShot"] = 212431,
				["MasterRiding"] = 90265,
				["Barrage"] = 120360,
				["BeastofOpportunity"] = 445700,
				["Languages"] = 79748,
				["BurstingShot"] = 186387,
				["GraveReaper"] = 430719,
				["BestialWrath"] = 19574,
				["DireBeast"] = 120679,
				["ShadowErasure"] = 430720,
				["BloodyFrenzy"] = 407412,
				["HighExplosiveTrap"] = 236776,
				["AspectoftheBeast"] = 191384,
				["EmbracetheShadows"] = 430704,
				["EyesoftheBeast"] = 321297,
				["FrenziedTear"] = 445696,
				["Pathfinding"] = 378002,
				["ShadowLash"] = 430717,
				["TarTrap"] = 187698,
				["AlphaPredator"] = 269737,
				["RejuvenatingWind"] = 385539,
				["AutoAttack"] = 6603,
				["BasiliskCollar"] = 459571,
				["TrainingExpert"] = 378209,
			},
			["Survival"] = {
				["LunarStorm"] = 450385,
				["FuriousAssault"] = 445699,
				["ImplosiveTrap"] = 462031,
				["ArcaneTorrent"] = 80483,
				["WildernessMedicine"] = 343242,
				["TerritorialInstincts"] = 459507,
				["ImprovedWildfireBomb"] = 321290,
				["ScareBeast"] = 1513,
				["PackCoordination"] = 445505,
				["ReleaseandReload"] = 450376,
				["HuntersMark"] = 257284,
				["TarCoatedBindings"] = 459460,
				["ArcaneShot"] = 185358,
				["Posthaste"] = 109215,
				["RuthlessMarauder"] = 385718,
				["WildfireInfusion"] = 460198,
				["CoordinatedAssault"] = 360952,
				["TheQuickandtheDead"] = 83950,
				["KillerCompanion"] = 378955,
				["Pathfinding"] = 378002,
				["ScatteredPrey"] = 445768,
				["OutlandVenom"] = 459939,
				["Camouflage"] = 199483,
				["DevilsaurTranquilizer"] = 459991,
				["RelentlessPrimalFerocity"] = 459922,
				["Intimidation"] = 19577,
				["PaddedArmor"] = 459450,
				["SymphonicArsenal"] = 450383,
				["FlankingStrike"] = 269751,
				["RoarofSacrifice"] = 53480,
				["SymbioticAdrenaline"] = 459875,
				["KillCommand"] = 259489,
				["FreezingTrap"] = 187650,
				["BrokenIslesPathfinder"] = 233368,
				["LoneSurvivor"] = 388039,
				["BlackrockMunitions"] = 462036,
				["SicEm"] = 459920,
				["CatchOut"] = 451516,
				["BornToBeWild"] = 266921,
				["GuildMail"] = 83951,
				["Sentinel"] = 450369,
				["BindingShot"] = 109248,
				["TirelessHunt"] = 445701,
				["CorneredPrey"] = 445702,
				["MomentofOpportunity"] = 459488,
				["RejuvenatingWind"] = 385539,
				["FeignDeath"] = 5384,
				["BloodyClaws"] = 385737,
				["GuerrillaTactics"] = 264332,
				["Bombardier"] = 389880,
				["SentinelPrecision"] = 450375,
				["MasterySpiritBond"] = 263135,
				["FlankersAdvantage"] = 459964,
				["ExplosiveShot"] = 212431,
				["SteadyShot"] = 56641,
				["Harpoon"] = 190925,
				["ExposedFlank"] = 459861,
				["UnnaturalCauses"] = 459527,
				["BindingShackles"] = 321468,
				["PlayDead"] = 209997,
				["NoHardFeelings"] = 459546,
				["ImprovedKillShot"] = 343248,
				["DontLookBack"] = 450373,
				["SweepingSpear"] = 378950,
				["ConcussiveShot"] = 5116,
				["ScatterShot"] = 213691,
				["MobileBanking"] = 83958,
				["ScoutsInstincts"] = 459455,
				["Bloodseeker"] = 260248,
				["TacticalAdvantage"] = 378951,
				["VipersVenom"] = 268501,
				["ExtrapolatedShots"] = 450374,
				["GrenadeJuggler"] = 459843,
				["TranquilizingShot"] = 19801,
				["DisruptiveRounds"] = 343244,
				["EmergencySalve"] = 459517,
				["AspectoftheEagle"] = 186289,
				["ImprovedTraps"] = 343247,
				["WingClip"] = 195645,
				["Flare"] = 1543,
				["Overwatch"] = 450384,
				["TriggerFinger"] = 459534,
				["ContagiousReagents"] = 459741,
				["HastyHearth"] = 83944,
				["Fetch"] = 125050,
				["Exhilaration"] = 109304,
				["GhillieSuit"] = 459466,
				["Scrappy"] = 459533,
				["EagleEye"] = 6197,
				["KodoTranquilizer"] = 459983,
				["SerratedTips"] = 459502,
				["BattleforAzerothPathfinder"] = 278833,
				["AspectoftheTurtle"] = 186265,
				["FrenziedTear"] = 445696,
				["WeaponSkills"] = 76249,
				["QuickShot"] = 378940,
				["MountUp"] = 78633,
				["Misdirection"] = 34477,
				["Entrapment"] = 393344,
				["Muzzle"] = 187707,
				["AspectoftheCheetah"] = 186257,
				["CommandPet"] = 272651,
				["ArmorSkills"] = 76250,
				["KillShot"] = 320976,
				["Spearhead"] = 360966,
				["ArcaneResistance"] = 822,
				["KeenEyesight"] = 378004,
				["Trailblazer"] = 199921,
				["AutoShot"] = 75,
				["HowlofthePack"] = 445707,
				["ArcaneAcuity"] = 154742,
				["DenRecovery"] = 445710,
				["ReviveBattlePets"] = 125439,
				["CoveringFire"] = 445715,
				["TarTrap"] = 187698,
				["ViciousHunt"] = 445404,
				["SentinelWatch"] = 451546,
				["CulltheHerd"] = 445717,
				["ArcaneAffinity"] = 28877,
				["FrenzyStrikes"] = 294029,
				["HighExplosiveTrap"] = 236776,
				["Sideline"] = 450378,
				["VindicaarMatrixCrystal"] = 251463,
				["PackAssault"] = 445721,
				["Lunge"] = 378934,
				["Ranger"] = 385695,
				["EyesClosed"] = 450381,
				["KindlingFlare"] = 459506,
				["HuntersAvoidance"] = 384799,
				["SurvivaloftheFittest"] = 264735,
				["SpecializedArsenal"] = 459542,
				["ExplosivesExpert"] = 378937,
				["MasterRiding"] = 90265,
				["MongooseBite"] = 259387,
				["BeastofOpportunity"] = 445700,
				["Languages"] = 79748,
				["BurstingShot"] = 186387,
				["QuickLoad"] = 378771,
				["SulfurLinedPockets"] = 459828,
				["Disengage"] = 781,
				["CrescentSteel"] = 451530,
				["InvigoratingPulse"] = 450379,
				["RaptorStrike"] = 186270,
				["WildfireBomb"] = 259495,
				["DeadlyDuo"] = 378962,
				["EyesoftheBeast"] = 321297,
				["Butchery"] = 212436,
				["FuryoftheEagle"] = 203415,
				["NaturalMending"] = 270581,
				["TermsofEngagement"] = 265895,
				["AlphaPredator"] = 269737,
				["WildAttacks"] = 445708,
				["AutoAttack"] = 6603,
				["MercilessBlows"] = 459868,
				["TipoftheSpear"] = 260285,
			},
		},
		["Evoker"] = {
			["Devastation"] = {
				["FireBreath"] = 357208,
				["ThreadsofFate"] = 431715,
				["TwinGuardian"] = 370888,
				["ArcaneIntensity"] = 375618,
				["PotentMana"] = 418101,
				["Tailwind"] = 375556,
				["DivertedPower"] = 441219,
				["EssenceAttunement"] = 375722,
				["ProtractedTalons"] = 369909,
				["GoldenOpportunity"] = 432004,
				["ChargedBlast"] = 370455,
				["PowerSwell"] = 370839,
				["SpatialParadox"] = 406732,
				["ExpandedLungs"] = 444845,
				["MightoftheBlackDragonflight"] = 441705,
				["ObsidianBulwark"] = 375406,
				["Temporality"] = 431873,
				["ConsumeFlame"] = 444088,
				["Tyranny"] = 376888,
				["Iridescence"] = 370867,
				["ScorchingEmbers"] = 370819,
				["TheQuickandtheDead"] = 83950,
				["Enkindle"] = 444016,
				["ImposingPresence"] = 371016,
				["PermeatingChill"] = 370897,
				["DeepBreath"] = 357210,
				["ChosenIdentity"] = 360022,
				["MasterofDestiny"] = 431840,
				["Firestorm"] = 368847,
				["TitanicWrath"] = 386272,
				["SleepWalk"] = 360806,
				["Unravel"] = 368432,
				["EventHorizon"] = 411164,
				["BattleforAzerothPathfinder"] = 278833,
				["RubyEssenceBurst"] = 376872,
				["Overawe"] = 374346,
				["BrokenIslesPathfinder"] = 233368,
				["EternitysSpan"] = 375757,
				["Exuberance"] = 375542,
				["AzureEssenceBurst"] = 375721,
				["TerroroftheSkies"] = 371032,
				["VerdantEmbrace"] = 360995,
				["TitanicPrecision"] = 445625,
				["ReviveBattlePets"] = 125439,
				["InnateMagic"] = 375520,
				["Engulf"] = 443328,
				["WeaponSkills"] = 352372,
				["BountifulBloom"] = 370886,
				["ExtendedFlight"] = 375517,
				["AerialMastery"] = 365933,
				["Volatility"] = 369089,
				["OppressingRoar"] = 372048,
				["Catalyze"] = 386283,
				["EmeraldBlossom"] = 355913,
				["FontofMagic"] = 411212,
				["ScarletAdaptation"] = 372469,
				["EngulfingBlaze"] = 370837,
				["Return"] = 361227,
				["TemporalBurst"] = 431695,
				["Quell"] = 351338,
				["InstabilityMatrix"] = 431484,
				["FeedtheFlames"] = 369846,
				["ImminentDestruction"] = 370781,
				["SourceofMagic"] = 369459,
				["TailSwipe"] = 368970,
				["Causality"] = 375777,
				["Zephyr"] = 374227,
				["RegenerativeMagic"] = 387787,
				["AttunedtotheDream"] = 376930,
				["WingBuffet"] = 357214,
				["Dragonrage"] = 375087,
				["Snapfire"] = 370783,
				["HoardedPower"] = 375796,
				["OnyxLegacy"] = 386348,
				["MobileBanking"] = 83958,
				["Bombardments"] = 434300,
				["AncientFlame"] = 369990,
				["InnerRadiance"] = 386405,
				["WallopingBlow"] = 387341,
				["Burnout"] = 375801,
				["EyeofInfinity"] = 411165,
				["DraconicLegacy"] = 376166,
				["ArmorSkills"] = 366522,
				["FociofLife"] = 375574,
				["SpellweaversDominance"] = 370845,
				["LivingFlame"] = 361469,
				["Wingleader"] = 441206,
				["Recall"] = 371806,
				["AutoAttack"] = 6603,
				["FantheFlames"] = 444318,
				["PowerNexus"] = 369908,
				["Rescue"] = 370665,
				["ExtendedBattle"] = 441212,
				["EssenceBurst"] = 359565,
				["DraconicInstincts"] = 445958,
				["TemperedScales"] = 396571,
				["Lifecinders"] = 444322,
				["HastyHearth"] = 83944,
				["NaturalConvergence"] = 369913,
				["Landslide"] = 358385,
				["Slipstream"] = 441257,
				["HeatWave"] = 375725,
				["FireWithin"] = 375577,
				["HardenedScales"] = 441180,
				["Pyre"] = 357211,
				["FuryoftheAspects"] = 390386,
				["RenewingBlaze"] = 374348,
				["ObsidianScales"] = 363916,
				["UnrelentingSiege"] = 441246,
				["RubyEmbers"] = 365937,
				["Primacy"] = 431657,
				["AerialHalt"] = 403216,
				["DenseEnergy"] = 370962,
				["TravelingFlame"] = 444140,
				["ChronoFlame"] = 431442,
				["InstinctiveArcana"] = 376164,
				["MassDisintegrate"] = 436335,
				["Reverberations"] = 431615,
				["Trailblazer"] = 444849,
				["MasterRiding"] = 90265,
				["NimbleFlyer"] = 441253,
				["EternitySurge"] = 359073,
				["MeltArmor"] = 441176,
				["MotesofAcceleration"] = 432008,
				["BurningAdrenaline"] = 444020,
				["ForgerofMountains"] = 375528,
				["DiscerningEye"] = 366489,
				["TimeSpiral"] = 374968,
				["Panacea"] = 387761,
				["LayWaste"] = 371034,
				["Glide"] = 358733,
				["Animosity"] = 375797,
				["BlastFurnace"] = 375510,
				["Maneuverability"] = 433871,
				["Enkindled"] = 375554,
				["ArcaneVigor"] = 386342,
				["LushGrowth"] = 375561,
				["ClobberingSweep"] = 375443,
				["CauterizingFlame"] = 374251,
				["Doubletime"] = 431874,
				["ShapeofFlame"] = 445074,
				["TiptheScales"] = 370553,
				["Warp"] = 429483,
				["ConduitofFlame"] = 444843,
				["Onslaught"] = 441245,
				["MenacingPresence"] = 441181,
				["Soar"] = 369536,
				["TimeConvergence"] = 431984,
				["Scintillation"] = 370821,
				["Languages"] = 362634,
				["RedHot"] = 444081,
				["Expunge"] = 365585,
				["FocusingIris"] = 386336,
				["HonedAggression"] = 371038,
				["LeapingFlames"] = 369939,
				["Visage"] = 351239,
				["Awakened"] = 365575,
				["GuildMail"] = 83951,
				["MountUp"] = 78633,
				["Afterimage"] = 431875,
				["ShatteringStar"] = 370452,
				["BlessingoftheBronze"] = 364342,
				["InherentResistance"] = 375544,
				["Hover"] = 358267,
				["HeavyWingbeats"] = 368838,
				["EnergizingFlame"] = 400006,
				["AzureStrike"] = 362969,
				["Disintegrate"] = 356995,
				["MasteryGiantkiller"] = 362980,
			},
			["Augmentation"] = {
				["FireBreath"] = 382266,
				["ThreadsofFate"] = 431715,
				["StretchTime"] = 410352,
				["MotesofPossibility"] = 409267,
				["TwinGuardian"] = 370888,
				["PotentMana"] = 418101,
				["Tailwind"] = 375556,
				["DivertedPower"] = 441219,
				["EssenceAttunement"] = 375722,
				["ProtractedTalons"] = 369909,
				["GoldenOpportunity"] = 432004,
				["SpatialParadox"] = 406732,
				["Prescience"] = 409311,
				["BlastFurnace"] = 375510,
				["MightoftheBlackDragonflight"] = 441705,
				["PupilofAlexstrasza"] = 407814,
				["ObsidianBulwark"] = 375406,
				["Temporality"] = 431873,
				["BlisteringScales"] = 360827,
				["TheQuickandtheDead"] = 83950,
				["MassEruption"] = 438587,
				["ImposingPresence"] = 371016,
				["PermeatingChill"] = 370897,
				["MomentumShift"] = 408004,
				["DeepBreath"] = 357210,
				["ChosenIdentity"] = 360022,
				["MasterofDestiny"] = 431840,
				["NourishingSands"] = 406041,
				["InterwovenThreads"] = 412713,
				["EssenceBurst"] = 396187,
				["SleepWalk"] = 360806,
				["ArcaneReach"] = 454983,
				["Unravel"] = 368432,
				["LeapingFlames"] = 369939,
				["FateMirror"] = 412774,
				["Visage"] = 351239,
				["Overawe"] = 374346,
				["BrokenIslesPathfinder"] = 233368,
				["Overlord"] = 410260,
				["BreathofEons"] = 403631,
				["TerroroftheSkies"] = 371032,
				["VerdantEmbrace"] = 360995,
				["ReviveBattlePets"] = 125439,
				["InnateMagic"] = 375520,
				["Accretion"] = 407876,
				["WeaponSkills"] = 352372,
				["Volcanism"] = 406904,
				["ChronoWard"] = 409676,
				["ExtendedFlight"] = 375517,
				["AerialMastery"] = 365933,
				["OppressingRoar"] = 372048,
				["EmeraldBlossom"] = 355913,
				["FontofMagic"] = 408083,
				["RicochetingPyroclast"] = 406659,
				["Return"] = 361227,
				["TemporalBurst"] = 431695,
				["Quell"] = 351338,
				["InstabilityMatrix"] = 431484,
				["UnyieldingDomain"] = 412733,
				["TomorrowToday"] = 412723,
				["Anachronism"] = 407869,
				["Timelessness"] = 412710,
				["SourceofMagic"] = 369459,
				["TailSwipe"] = 368970,
				["AspectsFavor"] = 407243,
				["Zephyr"] = 374227,
				["RegenerativeMagic"] = 387787,
				["AttunedtotheDream"] = 376930,
				["WingBuffet"] = 357214,
				["BronzeAttunement"] = 403265,
				["HoardedPower"] = 375796,
				["MobileBanking"] = 83958,
				["Bombardments"] = 434300,
				["AncientFlame"] = 369990,
				["SymbioticBloom"] = 410685,
				["WallopingBlow"] = 387341,
				["ScarletAdaptation"] = 372469,
				["Disintegrate"] = 356995,
				["AutoAttack"] = 6603,
				["DraconicLegacy"] = 376166,
				["ArmorSkills"] = 366522,
				["FociofLife"] = 375574,
				["TemperedScales"] = 396571,
				["PowerNexus"] = 369908,
				["EnergizingFlame"] = 400006,
				["RumblingEarth"] = 459120,
				["Recall"] = 371806,
				["DefyFate"] = 404195,
				["Hover"] = 358267,
				["BlackAttunement"] = 403264,
				["MountUp"] = 78633,
				["ExtendedBattle"] = 441212,
				["ProlongLife"] = 410687,
				["Exuberance"] = 375542,
				["EchoingStrike"] = 410784,
				["DreamofSpring"] = 414969,
				["HastyHearth"] = 83944,
				["Panacea"] = 387761,
				["Landslide"] = 358385,
				["Slipstream"] = 441257,
				["PerilousFate"] = 410253,
				["NaturalConvergence"] = 369913,
				["NimbleFlyer"] = 441253,
				["FireWithin"] = 375577,
				["FuryoftheAspects"] = 390386,
				["RenewingBlaze"] = 374348,
				["ObsidianScales"] = 363916,
				["Rescue"] = 370665,
				["ImminentDestruction"] = 459537,
				["Primacy"] = 431657,
				["ForgerofMountains"] = 375528,
				["CloseasClutchmates"] = 396043,
				["HardenedScales"] = 441180,
				["TimeConvergence"] = 431984,
				["InstinctiveArcana"] = 376164,
				["BestowWeyrnstone"] = 408233,
				["SandsofTime"] = 395153,
				["Soar"] = 369536,
				["SeismicSlam"] = 408543,
				["Eruption"] = 395160,
				["UnrelentingSiege"] = 441246,
				["MeltArmor"] = 441176,
				["InnerRadiance"] = 386405,
				["DiscerningEye"] = 366489,
				["Onslaught"] = 441245,
				["Warp"] = 429483,
				["TimeSpiral"] = 374968,
				["PlottheFuture"] = 407866,
				["RegenerativeChitin"] = 406907,
				["Glide"] = 358733,
				["Upheaval"] = 408092,
				["IgnitionRush"] = 408775,
				["Maneuverability"] = 433871,
				["Enkindled"] = 375554,
				["LushGrowth"] = 375561,
				["MoltenEmbers"] = 459725,
				["TiptheScales"] = 370553,
				["CauterizingFlame"] = 374251,
				["Doubletime"] = 431874,
				["SensePower"] = 361021,
				["MenacingPresence"] = 441181,
				["InfernosBlessing"] = 410261,
				["ChronoFlame"] = 431442,
				["ClobberingSweep"] = 375443,
				["BountifulBloom"] = 370886,
				["MasterRiding"] = 90265,
				["MotesofAcceleration"] = 432008,
				["ReactiveHide"] = 409329,
				["Languages"] = 362634,
				["Reverberations"] = 431615,
				["Expunge"] = 365585,
				["AerialHalt"] = 403216,
				["DraconicAttunements"] = 403208,
				["TimeSkip"] = 404977,
				["Awakened"] = 365575,
				["BattleforAzerothPathfinder"] = 278833,
				["GuildMail"] = 83951,
				["EbonMight"] = 395152,
				["Afterimage"] = 431875,
				["MoltenBlood"] = 410643,
				["BlessingoftheBronze"] = 364342,
				["InherentResistance"] = 375544,
				["LivingFlame"] = 361469,
				["HeavyWingbeats"] = 368838,
				["TectonicLocus"] = 408002,
				["AzureStrike"] = 362969,
				["Wingleader"] = 441206,
				["MasteryTimewalker"] = 406380,
			},
			["Preservation"] = {
				["DreamBreath"] = 382614,
				["ThreadsofFate"] = 431715,
				["TwinGuardian"] = 370888,
				["ClobberingSweep"] = 375443,
				["GoldenHour"] = 378196,
				["Tailwind"] = 375556,
				["DivertedPower"] = 441219,
				["EssenceAttunement"] = 375722,
				["ProtractedTalons"] = 369909,
				["GoldenOpportunity"] = 432004,
				["SpatialParadox"] = 406732,
				["BlastFurnace"] = 375510,
				["ExhilaratingBurst"] = 377100,
				["MightoftheBlackDragonflight"] = 441705,
				["ObsidianBulwark"] = 375406,
				["Temporality"] = 431873,
				["ConsumeFlame"] = 444088,
				["TheQuickandtheDead"] = 83950,
				["Enkindle"] = 444016,
				["Dreamwalker"] = 377082,
				["UnrelentingSiege"] = 441246,
				["SpiritualClarity"] = 376150,
				["PermeatingChill"] = 370897,
				["DeepBreath"] = 357210,
				["ChosenIdentity"] = 360022,
				["MasterofDestiny"] = 431840,
				["EssenceBurst"] = 369297,
				["SleepWalk"] = 360806,
				["Unravel"] = 368432,
				["LeapingFlames"] = 369939,
				["BattleforAzerothPathfinder"] = 278833,
				["Empath"] = 376138,
				["Visage"] = 351239,
				["Overawe"] = 374346,
				["BrokenIslesPathfinder"] = 233368,
				["NozdormusTeachings"] = 376237,
				["Exuberance"] = 375542,
				["ResonatingSphere"] = 376236,
				["TerroroftheSkies"] = 371032,
				["VerdantEmbrace"] = 360995,
				["TitanicPrecision"] = 445625,
				["ReviveBattlePets"] = 125439,
				["InnateMagic"] = 375520,
				["Engulf"] = 443328,
				["WeaponSkills"] = 352372,
				["BountifulBloom"] = 370886,
				["ExtendedFlight"] = 375517,
				["AerialMastery"] = 365933,
				["OppressingRoar"] = 372048,
				["TravelingFlame"] = 444140,
				["EmeraldBlossom"] = 355913,
				["FontofMagic"] = 375783,
				["ScarletAdaptation"] = 372469,
				["ConduitofFlame"] = 444843,
				["Return"] = 361227,
				["TemporalBurst"] = 431695,
				["Quell"] = 351338,
				["InstabilityMatrix"] = 431484,
				["CycleofLife"] = 371832,
				["FlutteringSeedlings"] = 359793,
				["HardenedScales"] = 441180,
				["TemporalAnomaly"] = 373861,
				["DelayHarm"] = 376207,
				["SourceofMagic"] = 369459,
				["TailSwipe"] = 368970,
				["Erasure"] = 376210,
				["Zephyr"] = 374227,
				["RegenerativeMagic"] = 387787,
				["AttunedtotheDream"] = 376930,
				["WingBuffet"] = 357214,
				["EmeraldCommunion"] = 370960,
				["TimelessMagic"] = 376240,
				["Lifespark"] = 443177,
				["MobileBanking"] = 83958,
				["Bombardments"] = 434300,
				["Lifebind"] = 373270,
				["FieldofDreams"] = 370062,
				["AncientFlame"] = 369990,
				["Wingleader"] = 441206,
				["LivingFlame"] = 361469,
				["WallopingBlow"] = 387341,
				["TimeLord"] = 372527,
				["AutoAttack"] = 6603,
				["PotentMana"] = 418101,
				["DraconicLegacy"] = 376166,
				["ArmorSkills"] = 366522,
				["FociofLife"] = 375574,
				["FireBreath"] = 382266,
				["JustinTime"] = 376204,
				["RenewingBreath"] = 371257,
				["BlessingoftheBronze"] = 364342,
				["Recall"] = 371806,
				["ExpandedLungs"] = 444845,
				["Lifecinders"] = 444322,
				["TemporalArtificer"] = 381922,
				["EnergyLoop"] = 372233,
				["ExtendedBattle"] = 441212,
				["LifeGiversFlame"] = 371426,
				["DraconicInstincts"] = 445958,
				["GuildMail"] = 83951,
				["LifeforceMender"] = 376179,
				["HastyHearth"] = 83944,
				["NaturalConvergence"] = 369913,
				["Landslide"] = 358385,
				["Slipstream"] = 441257,
				["TemporalCompression"] = 362874,
				["PowerNexus"] = 369908,
				["ChronoFlame"] = 431442,
				["FireWithin"] = 375577,
				["FuryoftheAspects"] = 390386,
				["RenewingBlaze"] = 374348,
				["ObsidianScales"] = 363916,
				["Awakened"] = 365575,
				["Stasis"] = 370537,
				["Primacy"] = 431657,
				["DiscerningEye"] = 366489,
				["NimbleFlyer"] = 441253,
				["Echo"] = 364343,
				["MasterRiding"] = 90265,
				["InstinctiveArcana"] = 376164,
				["Ouroboros"] = 381921,
				["Reverberations"] = 431615,
				["RushofVitality"] = 377086,
				["MotesofAcceleration"] = 432008,
				["TimeDilation"] = 357170,
				["Trailblazer"] = 444849,
				["MeltArmor"] = 441176,
				["Soar"] = 369536,
				["BurningAdrenaline"] = 444020,
				["Onslaught"] = 441245,
				["Warp"] = 429483,
				["TimeSpiral"] = 374968,
				["Rescue"] = 370665,
				["LushGrowth"] = 375561,
				["Glide"] = 358733,
				["Naturalize"] = 360823,
				["DreamFlight"] = 359816,
				["Maneuverability"] = 433871,
				["Enkindled"] = 375554,
				["ShapeofFlame"] = 445074,
				["GracePeriod"] = 376239,
				["Rewind"] = 363534,
				["CauterizingFlame"] = 374251,
				["Doubletime"] = 431874,
				["Punctuality"] = 371270,
				["SparkofInsight"] = 377099,
				["TiptheScales"] = 370553,
				["Reversion"] = 366155,
				["FlowState"] = 385696,
				["MenacingPresence"] = 441181,
				["ForgerofMountains"] = 375528,
				["TimeConvergence"] = 431984,
				["FantheFlames"] = 444318,
				["Languages"] = 362634,
				["RedHot"] = 444081,
				["Expunge"] = 365585,
				["Panacea"] = 387761,
				["AerialHalt"] = 403216,
				["TimeofNeed"] = 368412,
				["MasteryLifeBinder"] = 363510,
				["CallofYsera"] = 373834,
				["Spiritbloom"] = 382731,
				["TitansGift"] = 443264,
				["Afterimage"] = 431875,
				["MountUp"] = 78633,
				["EnergizingFlame"] = 400006,
				["InherentResistance"] = 375544,
				["TemperedScales"] = 396571,
				["HeavyWingbeats"] = 368838,
				["Hover"] = 358267,
				["AzureStrike"] = 362969,
				["Disintegrate"] = 356995,
				["MassReturn"] = 361178,
			},
		},
		["Priest"] = {
			["Shadow"] = {
				["PowerSurge"] = 453109,
				["EmbracetheShadow"] = 451569,
				["ArcaneTorrent"] = 232633,
				["DarkEvangelism"] = 391095,
				["PerfectedForm"] = 453917,
				["WordsofthePious"] = 377438,
				["InescapableTorment"] = 373427,
				["TormentedSpirits"] = 391284,
				["SurgeofInsanity"] = 391399,
				["AuspiciousSpirits"] = 155271,
				["Hallucinations"] = 280752,
				["Voidheart"] = 449880,
				["ArcaneAcuity"] = 154742,
				["AngelicFeather"] = 121536,
				["DarkAscension"] = 391109,
				["DispelMagic"] = 528,
				["TwistofFate"] = 390972,
				["BindingHeals"] = 368275,
				["ImprovedFade"] = 390670,
				["VampiricEmbrace"] = 15286,
				["Shadowform"] = 232698,
				["Deathspeaker"] = 392507,
				["IdolofCThun"] = 377349,
				["MindSoothe"] = 453,
				["ResonantEnergy"] = 453845,
				["UnfurlingDarkness"] = 341273,
				["DeathandMadness"] = 321291,
				["DarkeningHorizon"] = 449912,
				["VoidEmpowerment"] = 450138,
				["VoidBlast"] = 450405,
				["DivineHalo"] = 449806,
				["PurifyDisease"] = 213634,
				["MentalAgility"] = 341167,
				["ShadowyInsight"] = 375888,
				["TwinsoftheSunPriestess"] = 373466,
				["BrokenIslesPathfinder"] = 233368,
				["ShadowWordPain"] = 589,
				["PowerInfusion"] = 10060,
				["EnergyCompression"] = 449874,
				["DominateMind"] = 205364,
				["ReviveBattlePets"] = 125439,
				["Inspiration"] = 390676,
				["GuildMail"] = 83951,
				["MountUp"] = 78633,
				["WeaponSkills"] = 76301,
				["LightsInspiration"] = 373450,
				["WhisperingShadows"] = 406777,
				["Voidwraith"] = 451234,
				["LeapofFaith"] = 73325,
				["MindFlay"] = 15407,
				["IdolofNZoth"] = 373280,
				["PowerWordLife"] = 373481,
				["MindMelt"] = 391090,
				["IdolofYShaarj"] = 373310,
				["Apathy"] = 390668,
				["PsychicScream"] = 8122,
				["PsychicHorror"] = 64044,
				["MovewithGrace"] = 390620,
				["AncientMadness"] = 341240,
				["SurgeofLight"] = 109186,
				["BodyandSoul"] = 64129,
				["PsychicVoice"] = 196704,
				["DarkEnergy"] = 451018,
				["Renew"] = 139,
				["PrayerofMending"] = 33076,
				["DistortedReality"] = 409044,
				["HeightenedAlteration"] = 453729,
				["ConcentratedInfusion"] = 453844,
				["VoidTendrils"] = 108920,
				["MindControl"] = 605,
				["PowerWordShield"] = 17,
				["VoidLeech"] = 451311,
				["IdolofYoggSaron"] = 373273,
				["MindSpike"] = 73510,
				["MindsEye"] = 407470,
				["ProtectiveLight"] = 193063,
				["Manipulation"] = 459985,
				["MentalFortitude"] = 377065,
				["Resurrection"] = 2006,
				["ScreamsoftheVoid"] = 375767,
				["Mindbender"] = 200174,
				["NoEscape"] = 451204,
				["MassDispel"] = 32375,
				["MasteryShadowWeaving"] = 343690,
				["EssenceDevourer"] = 415479,
				["ShadowWordDeath"] = 32379,
				["Voidform"] = 228264,
				["Voidtouched"] = 407430,
				["Benevolence"] = 415416,
				["ImprovedFlashHeal"] = 393870,
				["SanguineTeachings"] = 373218,
				["Rhapsody"] = 390622,
				["LastWord"] = 263716,
				["FocusedMending"] = 372354,
				["ManifestedPower"] = 453783,
				["TranslucentImage"] = 373446,
				["ShackleUndead"] = 9484,
				["VoidShift"] = 108968,
				["FromDarknessComesLight"] = 390615,
				["BlessedRecovery"] = 390767,
				["EmpoweredSurges"] = 453799,
				["PsychicLink"] = 199484,
				["Malediction"] = 373221,
				["DevourMatter"] = 451840,
				["MindDevourer"] = 373202,
				["HastyHearth"] = 83944,
				["VoidInfusion"] = 450612,
				["BattleforAzerothPathfinder"] = 278833,
				["ArmorSkills"] = 76279,
				["SheerTerror"] = 390919,
				["MobileBanking"] = 83958,
				["SustainedPotency"] = 454001,
				["DepthofShadows"] = 451308,
				["Fade"] = 586,
				["Sanlayn"] = 199855,
				["WordofSupremacy"] = 453726,
				["DevouringPlague"] = 335467,
				["ShadowCrash"] = 205385,
				["DivineStar"] = 122121,
				["Languages"] = 79748,
				["MentalDecay"] = 375994,
				["InsidiousIre"] = 373212,
				["Mastermind"] = 391151,
				["VoidEruption"] = 228260,
				["Levitate"] = 1706,
				["FlashHeal"] = 2061,
				["Halo"] = 120644,
				["Intangibility"] = 288733,
				["ShadowyApparitions"] = 341491,
				["PhantasmalPathogen"] = 407469,
				["ShockPulse"] = 453852,
				["AngelsMercy"] = 238100,
				["EnergyCycle"] = 453828,
				["ArcaneAffinity"] = 28877,
				["AngelicBulwark"] = 108945,
				["HolyNova"] = 132157,
				["InnerQuietus"] = 448278,
				["VindicaarMatrixCrystal"] = 251463,
				["UnwaveringWill"] = 373456,
				["VoidBolt"] = 228266,
				["PetrifyingScream"] = 55676,
				["PowerWordFortitude"] = 21562,
				["PhantomReach"] = 459559,
				["Silence"] = 15487,
				["ThroesofPain"] = 377422,
				["CollapsingVoid"] = 448403,
				["Shoot"] = 5019,
				["MasterRiding"] = 90265,
				["ThoughtHarvester"] = 406788,
				["CauterizingShadows"] = 459990,
				["VampiricTouch"] = 34914,
				["CrystallineReflection"] = 373457,
				["FocusedWill"] = 45243,
				["Dispersion"] = 47585,
				["IncessantScreams"] = 453918,
				["MindBlast"] = 8092,
				["Misery"] = 238558,
				["ArcaneResistance"] = 822,
				["MaddeningTouch"] = 391228,
				["TheQuickandtheDead"] = 83950,
				["DesperatePrayer"] = 19236,
				["EntropicRift"] = 447444,
				["Phantasm"] = 108942,
				["VoidTorrent"] = 263165,
				["VoidShield"] = 280749,
				["MindVision"] = 2096,
				["Shadowfiend"] = 34433,
				["AutoAttack"] = 6603,
				["TitheEvasion"] = 373223,
				["SpellWarding"] = 390667,
			},
			["Holy"] = {
				["PowerSurge"] = 453109,
				["Pontifex"] = 390980,
				["GuardianAngel"] = 200209,
				["ArcaneTorrent"] = 232633,
				["PerfectedForm"] = 453917,
				["WordsofthePious"] = 377438,
				["MasteryEchoofLight"] = 77485,
				["ThroesofPain"] = 377422,
				["Clairvoyance"] = 428940,
				["DivineFeathers"] = 440670,
				["SanctifiedPrayers"] = 196489,
				["ArcaneAcuity"] = 154742,
				["EssenceDevourer"] = 415479,
				["Benevolence"] = 415416,
				["SustainedPotency"] = 454001,
				["TwistofFate"] = 390972,
				["PrismaticEchoes"] = 390967,
				["Rhapsody"] = 390622,
				["MiraculousRecovery"] = 440674,
				["ImprovedFade"] = 390670,
				["VampiricEmbrace"] = 15286,
				["Lightwell"] = 372835,
				["ResonantEnergy"] = 453845,
				["DeathandMadness"] = 321291,
				["Enlightenment"] = 193155,
				["Afterlife"] = 196707,
				["Lightweaver"] = 390992,
				["DivineHalo"] = 449806,
				["GalesofSong"] = 372370,
				["TrailofLight"] = 200128,
				["BattleforAzerothPathfinder"] = 278833,
				["GuardianSpirit"] = 47788,
				["MentalAgility"] = 341167,
				["TwinsoftheSunPriestess"] = 373466,
				["BrokenIslesPathfinder"] = 233368,
				["ShadowWordPain"] = 589,
				["PowerInfusion"] = 10060,
				["AnsweredPrayers"] = 391387,
				["EnergyCompression"] = 449874,
				["RevitalizingPrayers"] = 391208,
				["UnwaveringWill"] = 373456,
				["ReviveBattlePets"] = 125439,
				["Fatebender"] = 440743,
				["Inspiration"] = 390676,
				["GuildMail"] = 83951,
				["PrayerofHealing"] = 596,
				["MountUp"] = 78633,
				["WeaponSkills"] = 76301,
				["HolyWordChastise"] = 88625,
				["CosmicRipple"] = 238136,
				["LeapofFaith"] = 73325,
				["WordofSupremacy"] = 453726,
				["Epiphany"] = 414553,
				["PowerWordLife"] = 373481,
				["MiracleWorker"] = 235587,
				["GuardiansoftheLight"] = 196437,
				["EverlastingLight"] = 391161,
				["Apathy"] = 390668,
				["PerfectVision"] = 440661,
				["PsychicScream"] = 8122,
				["DivineService"] = 391233,
				["AssuredSafety"] = 440766,
				["MovewithGrace"] = 390620,
				["PrayerfulLitany"] = 391209,
				["SurgeofLight"] = 109186,
				["BodyandSoul"] = 64129,
				["PsychicVoice"] = 196704,
				["Renew"] = 139,
				["PrayerofMending"] = 33076,
				["CauterizingShadows"] = 459990,
				["PreemptiveCare"] = 440671,
				["ConcentratedInfusion"] = 453844,
				["VoidTendrils"] = 108920,
				["MindControl"] = 605,
				["PowerWordShield"] = 17,
				["HolyMending"] = 391154,
				["ProtectiveLight"] = 193063,
				["SavetheDay"] = 440669,
				["AngelicBulwark"] = 108945,
				["DivineHymn"] = 64843,
				["Resurrection"] = 2006,
				["FocusedWill"] = 45243,
				["LightoftheNaaru"] = 196985,
				["Heal"] = 2060,
				["SymbolofHope"] = 64901,
				["Orison"] = 390947,
				["DivineImage"] = 392988,
				["MassDispel"] = 32375,
				["Manipulation"] = 459985,
				["AngelicFeather"] = 121536,
				["ShadowWordDeath"] = 32379,
				["MassResurrection"] = 212036,
				["SanguineTeachings"] = 373218,
				["ForeseenCircumstances"] = 440738,
				["ImprovedFlashHeal"] = 393870,
				["MindVision"] = 2096,
				["HealingChorus"] = 390881,
				["SpiritofRedemption"] = 20711,
				["FocusedMending"] = 372354,
				["DominateMind"] = 205364,
				["TranslucentImage"] = 373446,
				["Apotheosis"] = 200183,
				["VoidShift"] = 108968,
				["FromDarknessComesLight"] = 390615,
				["BlessedRecovery"] = 390767,
				["DesperatePrayer"] = 19236,
				["PrayerCircle"] = 321377,
				["ImprovedPurify"] = 390632,
				["HastyHearth"] = 83944,
				["HolyWordSalvation"] = 265202,
				["ResonantWords"] = 372309,
				["VoidShield"] = 280749,
				["EmpyrealBlaze"] = 372616,
				["MobileBanking"] = 83958,
				["ManifestedPower"] = 453783,
				["Censure"] = 200199,
				["PreventiveMeasures"] = 440662,
				["CrisisManagement"] = 390954,
				["Fade"] = 586,
				["Sanlayn"] = 199855,
				["DispelMagic"] = 528,
				["ProphetsWill"] = 433905,
				["DivineWord"] = 372760,
				["DivineStar"] = 110744,
				["DesperateTimes"] = 391381,
				["DesperateMeasures"] = 458718,
				["Benediction"] = 193157,
				["Levitate"] = 1706,
				["FlashHeal"] = 2061,
				["PrayersoftheVirtuous"] = 390977,
				["SayYourPrayers"] = 391186,
				["Halo"] = 120517,
				["ShockPulse"] = 453852,
				["ShackleUndead"] = 9484,
				["HolyNova"] = 132157,
				["HeightenedAlteration"] = 453729,
				["AngelsMercy"] = 238100,
				["VoiceofHarmony"] = 390994,
				["ArcaneAffinity"] = 28877,
				["BurningVehemence"] = 372307,
				["RenewedFaith"] = 341997,
				["Premonition"] = 428924,
				["VindicaarMatrixCrystal"] = 251463,
				["Smite"] = 585,
				["EnergyCycle"] = 453828,
				["PetrifyingScream"] = 55676,
				["PowerWordFortitude"] = 21562,
				["PhantomReach"] = 459559,
				["WasteNoTime"] = 440681,
				["Purify"] = 527,
				["LightsInspiration"] = 373450,
				["Shoot"] = 5019,
				["MasterRiding"] = 90265,
				["EmpoweredSurges"] = 453799,
				["BindingHeals"] = 368275,
				["Languages"] = 79748,
				["CrystallineReflection"] = 373457,
				["Serendipity"] = 63733,
				["HolyWordSanctify"] = 34861,
				["IncessantScreams"] = 453918,
				["DivineProvidence"] = 440742,
				["ArmorSkills"] = 76279,
				["ArcaneResistance"] = 822,
				["SheerTerror"] = 390919,
				["TheQuickandtheDead"] = 83950,
				["CircleofHealing"] = 204883,
				["Shadowfiend"] = 34433,
				["Phantasm"] = 108942,
				["HolyFire"] = 14914,
				["MindSoothe"] = 453,
				["Restitution"] = 391124,
				["HolyWordSerenity"] = 2050,
				["AutoAttack"] = 6603,
				["TitheEvasion"] = 373223,
				["SpellWarding"] = 390667,
			},
			["Discipline"] = {
				["EmbracetheShadow"] = 451569,
				["ArcaneTorrent"] = 232633,
				["EnduringLuminescence"] = 390685,
				["DevourMatter"] = 451840,
				["InescapableTorment"] = 373427,
				["ThroesofPain"] = 377422,
				["ShadowCovenant"] = 314867,
				["ProtectoroftheFrail"] = 373035,
				["Clairvoyance"] = 428940,
				["DivineFeathers"] = 440670,
				["Voidheart"] = 449880,
				["AegisofWrath"] = 238135,
				["ArcaneAcuity"] = 154742,
				["AngelicFeather"] = 121536,
				["Benevolence"] = 415416,
				["DispelMagic"] = 528,
				["TwistofFate"] = 390972,
				["Rhapsody"] = 390622,
				["BlazeofLight"] = 215768,
				["ImprovedFade"] = 390670,
				["VampiricEmbrace"] = 15286,
				["Premonition"] = 428924,
				["PainSuppression"] = 33206,
				["TrainofThought"] = 390693,
				["VoidShield"] = 280749,
				["DarkeningHorizon"] = 449912,
				["VoidEmpowerment"] = 450138,
				["PreventiveMeasures"] = 440662,
				["BattleforAzerothPathfinder"] = 278833,
				["Evangelism"] = 246287,
				["MentalAgility"] = 341167,
				["MaliciousIntent"] = 372969,
				["BrokenIslesPathfinder"] = 233368,
				["ShadowWordPain"] = 589,
				["PowerInfusion"] = 10060,
				["FocusedWill"] = 45243,
				["UnwaveringWill"] = 373456,
				["ReviveBattlePets"] = 125439,
				["Fatebender"] = 440743,
				["Inspiration"] = 390676,
				["GuildMail"] = 83951,
				["MountUp"] = 78633,
				["WeaponSkills"] = 76301,
				["LightsInspiration"] = 373450,
				["Voidwraith"] = 451234,
				["PainfulPunishment"] = 390686,
				["PowerWordLife"] = 373481,
				["PurgetheWicked"] = 204197,
				["Apathy"] = 390668,
				["HeavensWrath"] = 421558,
				["PsychicScream"] = 8122,
				["AssuredSafety"] = 440766,
				["MovewithGrace"] = 390620,
				["Penance"] = 47540,
				["SurgeofLight"] = 109186,
				["DivineAegis"] = 47515,
				["PsychicVoice"] = 196704,
				["DarkEnergy"] = 451018,
				["Renew"] = 139,
				["PrayerofMending"] = 33076,
				["CauterizingShadows"] = 459990,
				["PreemptiveCare"] = 440671,
				["DarkIndulgence"] = 372972,
				["VoidTendrils"] = 108920,
				["PainandSuffering"] = 390689,
				["MindControl"] = 605,
				["PowerWordShield"] = 17,
				["VoidLeech"] = 451311,
				["AbyssalReverie"] = 373054,
				["LuminousBarrier"] = 271466,
				["ProtectiveLight"] = 193063,
				["SavetheDay"] = 440669,
				["AngelicBulwark"] = 108945,
				["MindSoothe"] = 453,
				["BodyandSoul"] = 64129,
				["LightsPromise"] = 322115,
				["RevelinPurity"] = 373003,
				["Resurrection"] = 2006,
				["Schism"] = 424509,
				["Mindbender"] = 123040,
				["DominateMind"] = 205364,
				["TheQuickandtheDead"] = 83950,
				["MiraculousRecovery"] = 440674,
				["NoEscape"] = 451204,
				["MassDispel"] = 32375,
				["DivineProvidence"] = 440742,
				["MindVision"] = 2096,
				["ShadowWordDeath"] = 32379,
				["MassResurrection"] = 212036,
				["MasteryGrace"] = 271534,
				["ForeseenCircumstances"] = 440738,
				["ImprovedFlashHeal"] = 393870,
				["SanguineTeachings"] = 373218,
				["BorrowedTime"] = 390691,
				["FocusedMending"] = 372354,
				["SheerTerror"] = 390919,
				["SinsoftheMany"] = 280391,
				["TranslucentImage"] = 373446,
				["ShackleUndead"] = 9484,
				["VoidShift"] = 108968,
				["FromDarknessComesLight"] = 390615,
				["BlessedRecovery"] = 390767,
				["ImprovedPurify"] = 390632,
				["PoweroftheDarkSide"] = 198068,
				["UltimatePenitence"] = 421453,
				["Lenience"] = 238063,
				["Atonement"] = 81749,
				["Castigation"] = 193134,
				["VoidInfusion"] = 450612,
				["DepthofShadows"] = 451308,
				["PerfectVision"] = 440661,
				["Rapture"] = 47536,
				["Expiation"] = 390832,
				["CollapsingVoid"] = 448403,
				["BrightPupil"] = 390684,
				["Fade"] = 586,
				["Sanlayn"] = 199855,
				["BindingHeals"] = 368275,
				["ProphetsWill"] = 433905,
				["PowerWordRadiance"] = 194509,
				["DivineStar"] = 110744,
				["DeathandMadness"] = 321291,
				["DesperateMeasures"] = 458718,
				["HarshDiscipline"] = 373180,
				["Purify"] = 527,
				["FlashHeal"] = 2061,
				["Levitate"] = 1706,
				["WealandWoe"] = 390786,
				["Halo"] = 120517,
				["LeapofFaith"] = 73325,
				["Sanctuary"] = 231682,
				["HolyNova"] = 132157,
				["ShieldDiscipline"] = 197045,
				["AngelsMercy"] = 238100,
				["ArcaneAffinity"] = 28877,
				["Smite"] = 585,
				["VoidSummoner"] = 390770,
				["Contrition"] = 197419,
				["PainTransformation"] = 372991,
				["InnerQuietus"] = 448278,
				["VindicaarMatrixCrystal"] = 251463,
				["EssenceDevourer"] = 415479,
				["PetrifyingScream"] = 55676,
				["PowerWordFortitude"] = 21562,
				["PhantomReach"] = 459559,
				["WasteNoTime"] = 440681,
				["Indemnity"] = 373049,
				["OverloadedwithLight"] = 421557,
				["Shoot"] = 5019,
				["MasterRiding"] = 90265,
				["Exaltation"] = 373042,
				["WordsofthePious"] = 377438,
				["Languages"] = 79748,
				["CrystallineReflection"] = 373457,
				["PowerWordBarrier"] = 62618,
				["TwilightEquilibrium"] = 390705,
				["VoidBlast"] = 450405,
				["MindBlast"] = 8092,
				["MobileBanking"] = 83958,
				["ArcaneResistance"] = 822,
				["ArmorSkills"] = 76279,
				["HastyHearth"] = 83944,
				["TwilightCorruption"] = 373065,
				["EntropicRift"] = 447444,
				["Phantasm"] = 108942,
				["Manipulation"] = 459985,
				["TwinsoftheSunPriestess"] = 373466,
				["DesperatePrayer"] = 19236,
				["Shadowfiend"] = 34433,
				["AutoAttack"] = 6603,
				["TitheEvasion"] = 373223,
				["SpellWarding"] = 390667,
			},
		},
	}
	local className, classFilename, classId = UnitClass("player")
	local currentSpec = GetSpecialization()
	local id, name, description, icon, background, role = GetSpecializationInfo(currentSpec)
	MaxDps.SpellTable = MaxDpsSpellTable[idtoclass[classId]][idtospec[id]]
	--MaxDps.SpellInfoTable = {}
end

function MaxDps:UNIT_ENTERED_VEHICLE(_, unit)
	if unit == 'player' and self.rotationEnabled then
		self:DisableRotation()
	end
end

function MaxDps:UNIT_EXITED_VEHICLE(_, unit)
	if unit == 'player' then
		self:InitRotations()
		self:EnableRotation()
	end
end

function MaxDps:PLAYER_TARGET_CHANGED()
	if self.rotationEnabled then
		if UnitIsFriend('player', 'target') then
			return
		else
			self:InvokeNextSpell()
		end
	end
end

function MaxDps:PLAYER_REGEN_DISABLED()
	if self.db.global.onCombatEnter and not self.rotationEnabled then
		self:Print(self.Colors.Success .. 'Auto enable on combat!', "info")
		self:InitRotations()
		self:EnableRotation()
	end
end

function MaxDps:PLAYER_REGEN_ENABLED()
	self:DisableRotation()
end

function MaxDps:ButtonFetch()
	if self.rotationEnabled then
		if self.fetchTimer then
			self:CancelTimer(self.fetchTimer)
		end
		self.fetchTimer = self:ScheduleTimer('Fetch', 0.5)
	end
end

function MaxDps:PrepareFrameData()
	if not self.FrameData then
		self.FrameData = {
			cooldown  = self.PlayerCooldowns,
			activeDot = self.ActiveDots
		}
	end

	self.FrameData.timeShift, self.FrameData.currentSpell, self.FrameData.gcdRemains = MaxDps:EndCast()
	self.FrameData.gcd = self:GlobalCooldown()
	self.FrameData.buff, self.FrameData.debuff = MaxDps:CollectAuras()
	self.FrameData.talents = self.PlayerTalents
	self.FrameData.azerite = self.AzeriteTraits
	self.FrameData.essences = self.AzeriteEssences
	self.FrameData.covenant = self.CovenantInfo
	self.FrameData.runeforge = self.LegendaryBonusIds
	self.FrameData.spellHistory = self.spellHistory
	self.FrameData.timeToDie = self:GetTimeToDie()
end

function MaxDps:InvokeNextSpell()
	-- invoke spell check
	local oldSkill = self.Spell

	self:PrepareFrameData()

	self:GlowConsumables()

	-- Removed backward compatibility
	self.Spell = self:NextSpell()

	if (oldSkill ~= self.Spell or oldSkill == nil) and self.Spell ~= nil then
		self:GlowNextSpell(self.Spell)
		if WeakAuras then
			WeakAuras.ScanEvents('MAXDPS_SPELL_UPDATE', self.Spell)
		end
	end

	if self.Spell == nil and oldSkill ~= nil then
		self:GlowClear()
		if WeakAuras then
			WeakAuras.ScanEvents('MAXDPS_SPELL_UPDATE', nil)
		end
	end
end

function MaxDps:InitRotations()
	self:Print(self.Colors.Info .. 'Initializing rotations', "info")
	self:CountTier()

	local _, _, classId = UnitClass('player')
	local spec = GetSpecialization()
	self.ClassId = classId
	self.Spec = spec

	if not self.Custom then
		self.Custom = self:GetModule('Custom')
	end

	self.Custom:LoadCustomRotations()
	local customRotation = self.Custom:GetCustomRotation(classId, spec)

	if customRotation then
		self.NextSpell = customRotation.fn

		self:Print(self.Colors.Success .. 'Loaded Custom Rotation: ' .. customRotation.name, "info")
	else
		self:LoadModule()
	end
end

function MaxDps:LoadModule()
	if self.Classes[self.ClassId] == nil then
		self:Print(self.Colors.Error .. 'Invalid player class, please contact author of addon.', "error")
		return
	end

	local className = self.Classes[self.ClassId]
	local module = 'MaxDps_' .. className
	local _, _, _, _, reason = GetAddOnInfo(module)

	if IsAddOnLoaded(module) then
		self:EnableRotationModule(className)
		return
	end

	if reason == 'MISSING' or reason == 'DISABLED' then
		self:Print(self.Colors.Error .. 'Could not find class module ' .. module .. ', reason: ' .. reason, "error")
		self:Print(self.Colors.Error .. 'Make sure to install class module or create custom rotation', "error")
		self:Print(self.Colors.Error .. 'Missing addon: ' .. module, "error")
		return
	end

	LoadAddOn(module)

	self:InitTTD()
	self:EnableRotationModule(className)
end

function MaxDps:EnableRotationModule(className)
	local loaded = self:EnableModule(className)

	if not loaded then
		self:Print(self.Colors.Error .. 'Could not find load module ' .. className .. ', reason: OUTDATED', "error")
	else
		self:Print(self.Colors.Info .. 'Finished Loading class module', "info")
	end
end
